"use strict";var Xu=Object.create;var Ut=Object.defineProperty;var Zu=Object.getOwnPropertyDescriptor;var ec=Object.getOwnPropertyNames;var tc=Object.getPrototypeOf,nc=Object.prototype.hasOwnProperty;var M=(e,t)=>()=>(t||e((t={exports:{}}).exports,t),t.exports),rc=(e,t)=>{for(var n in t)Ut(e,n,{get:t[n],enumerable:!0})},Dr=(e,t,n,r)=>{if(t&&typeof t=="object"||typeof t=="function")for(let i of ec(t))!nc.call(e,i)&&i!==n&&Ut(e,i,{get:()=>t[i],enumerable:!(r=Zu(t,i))||r.enumerable});return e};var me=(e,t,n)=>(n=e!=null?Xu(tc(e)):{},Dr(t||!e||!e.__esModule?Ut(n,"default",{value:e,enumerable:!0}):n,e)),ic=e=>Dr(Ut({},"__esModule",{value:!0}),e);var jr=M(Hr=>{(()=>{var e={46:(o,s)=>{"use strict";Object.defineProperty(s,"__esModule",{value:!0}),s.default=function(a,u,{signal:l}={}){return new Promise(((c,p)=>{function f(){l?.removeEventListener("abort",f),a.removeListener(u,m),a.removeListener("error",h)}function m(...y){f(),c(y)}function h(y){f(),p(y)}l?.addEventListener("abort",f),a.on(u,m),a.on("error",h)}))}},54:function(o,s,a){"use strict";var u=this&&this.__importDefault||function(y){return y&&y.__esModule?y:{default:y}};let l=a(361),c=u(a(374)),p=u(a(304)),f=c.default("agent-base");function m(){let{stack:y}=new Error;return typeof y=="string"&&y.split(`
`).some((k=>k.indexOf("(https.js:")!==-1||k.indexOf("node:https:")!==-1))}function h(y,k){return new h.Agent(y,k)}(function(y){class k extends l.EventEmitter{constructor(R,E){super();let _=E;typeof R=="function"?this.callback=R:R&&(_=R),this.timeout=null,_&&typeof _.timeout=="number"&&(this.timeout=_.timeout),this.maxFreeSockets=1,this.maxSockets=1,this.maxTotalSockets=1/0,this.sockets={},this.freeSockets={},this.requests={},this.options={}}get defaultPort(){return typeof this.explicitDefaultPort=="number"?this.explicitDefaultPort:m()?443:80}set defaultPort(R){this.explicitDefaultPort=R}get protocol(){return typeof this.explicitProtocol=="string"?this.explicitProtocol:m()?"https:":"http:"}set protocol(R){this.explicitProtocol=R}callback(R,E,_){throw new Error('"agent-base" has no default implementation, you must subclass and override `callback()`')}addRequest(R,E){let _=Object.assign({},E);typeof _.secureEndpoint!="boolean"&&(_.secureEndpoint=m()),_.host==null&&(_.host="localhost"),_.port==null&&(_.port=_.secureEndpoint?443:80),_.protocol==null&&(_.protocol=_.secureEndpoint?"https:":"http:"),_.host&&_.path&&delete _.path,delete _.agent,delete _.hostname,delete _._defaultAgent,delete _.defaultPort,delete _.createConnection,R._last=!0,R.shouldKeepAlive=!1;let P=!1,L=null,S=_.timeout||this.timeout,v=g=>{R._hadError||(R.emit("error",g),R._hadError=!0)},b=()=>{L=null,P=!0;let g=new Error(`A "socket" was not created for HTTP request before ${S}ms`);g.code="ETIMEOUT",v(g)},O=g=>{P||(L!==null&&(clearTimeout(L),L=null),v(g))},d=g=>{if(P)return;if(L!=null&&(clearTimeout(L),L=null),A=g,!!A&&typeof A.addRequest=="function")return f("Callback returned another Agent instance %o",g.constructor.name),void g.addRequest(R,_);var A;if(g)return g.once("free",(()=>{this.freeSocket(g,_)})),void R.onSocket(g);let T=new Error(`no Duplex stream was returned to agent-base for \`${R.method} ${R.path}\``);v(T)};if(typeof this.callback=="function"){this.promisifiedCallback||(this.callback.length>=3?(f("Converting legacy callback function to promise"),this.promisifiedCallback=p.default(this.callback)):this.promisifiedCallback=this.callback),typeof S=="number"&&S>0&&(L=setTimeout(b,S)),"port"in _&&typeof _.port!="number"&&(_.port=Number(_.port));try{f("Resolving socket for %o request: %o",_.protocol,`${R.method} ${R.path}`),Promise.resolve(this.promisifiedCallback(R,_)).then(d,O)}catch(g){Promise.reject(g).catch(O)}}else v(new Error("`callback` is not defined"))}freeSocket(R,E){f("Freeing socket %o %o",R.constructor.name,E),R.destroy()}destroy(){f("Destroying agent %o",this.constructor.name)}}y.Agent=k,y.prototype=y.Agent.prototype})(h||(h={})),o.exports=h},304:(o,s)=>{"use strict";Object.defineProperty(s,"__esModule",{value:!0}),s.default=function(a){return function(u,l){return new Promise(((c,p)=>{a.call(this,u,l,((f,m)=>{f?p(f):c(m)}))}))}}},370:function(o,s,a){"use strict";var u=this&&this.__awaiter||function(R,E,_,P){return new(_||(_=Promise))((function(L,S){function v(d){try{O(P.next(d))}catch(g){S(g)}}function b(d){try{O(P.throw(d))}catch(g){S(g)}}function O(d){var g;d.done?L(d.value):(g=d.value,g instanceof _?g:new _((function(A){A(g)}))).then(v,b)}O((P=P.apply(R,E||[])).next())}))},l=this&&this.__importDefault||function(R){return R&&R.__esModule?R:{default:R}};Object.defineProperty(s,"__esModule",{value:!0});let c=l(a(808)),p=l(a(404)),f=l(a(310)),m=l(a(374)),h=l(a(46)),y=a(54),k=(0,m.default)("http-proxy-agent");class C extends y.Agent{constructor(E){let _;if(_=typeof E=="string"?f.default.parse(E):E,!_)throw new Error("an HTTP(S) proxy server `host` and `port` must be specified!");k("Creating new HttpProxyAgent instance: %o",_),super(_);let P=Object.assign({},_);var L;this.secureProxy=_.secureProxy||typeof(L=P.protocol)=="string"&&/^https:?$/i.test(L),P.host=P.hostname||P.host,typeof P.port=="string"&&(P.port=parseInt(P.port,10)),!P.port&&P.host&&(P.port=this.secureProxy?443:80),P.host&&P.path&&(delete P.path,delete P.pathname),this.proxy=P}callback(E,_){return u(this,void 0,void 0,(function*(){let{proxy:P,secureProxy:L}=this,S=f.default.parse(E.path),v;if(S.protocol||(S.protocol="http:"),S.hostname||(S.hostname=_.hostname||_.host||null),S.port==null&&(_.port,1)&&(S.port=String(_.port)),S.port==="80"&&(S.port=""),E.path=f.default.format(S),P.auth&&E.setHeader("Proxy-Authorization",`Basic ${Buffer.from(P.auth).toString("base64")}`),L?(k("Creating `tls.Socket`: %o",P),v=p.default.connect(P)):(k("Creating `net.Socket`: %o",P),v=c.default.connect(P)),E._header){let b,O;k("Regenerating stored HTTP header string for request"),E._header=null,E._implicitHeader(),E.output&&E.output.length>0?(k("Patching connection write() output buffer with updated header"),b=E.output[0],O=b.indexOf(`\r
\r
`)+4,E.output[0]=E._header+b.substring(O),k("Output buffer: %o",E.output)):E.outputData&&E.outputData.length>0&&(k("Patching connection write() output buffer with updated header"),b=E.outputData[0].data,O=b.indexOf(`\r
\r
`)+4,E.outputData[0].data=E._header+b.substring(O),k("Output buffer: %o",E.outputData[0].data))}return yield(0,h.default)(v,"connect"),v}))}}s.default=C},201:function(o,s,a){"use strict";let u=(this&&this.__importDefault||function(c){return c&&c.__esModule?c:{default:c}})(a(370));function l(c){return new u.default(c)}(function(c){c.HttpProxyAgent=u.default,c.prototype=u.default.prototype})(l||(l={})),o.exports=l},146:function(o,s,a){"use strict";var u=this&&this.__awaiter||function(_,P,L,S){return new(L||(L=Promise))((function(v,b){function O(A){try{g(S.next(A))}catch(T){b(T)}}function d(A){try{g(S.throw(A))}catch(T){b(T)}}function g(A){var T;A.done?v(A.value):(T=A.value,T instanceof L?T:new L((function(x){x(T)}))).then(O,d)}g((S=S.apply(_,P||[])).next())}))},l=this&&this.__importDefault||function(_){return _&&_.__esModule?_:{default:_}};Object.defineProperty(s,"__esModule",{value:!0});let c=l(a(808)),p=l(a(404)),f=l(a(310)),m=l(a(491)),h=l(a(374)),y=a(54),k=l(a(829)),C=h.default("https-proxy-agent:agent");class R extends y.Agent{constructor(P){let L;if(L=typeof P=="string"?f.default.parse(P):P,!L)throw new Error("an HTTP(S) proxy server `host` and `port` must be specified!");C("creating new HttpsProxyAgent instance: %o",L),super(L);let S=Object.assign({},L);var v;this.secureProxy=L.secureProxy||typeof(v=S.protocol)=="string"&&/^https:?$/i.test(v),S.host=S.hostname||S.host,typeof S.port=="string"&&(S.port=parseInt(S.port,10)),!S.port&&S.host&&(S.port=this.secureProxy?443:80),this.secureProxy&&!("ALPNProtocols"in S)&&(S.ALPNProtocols=["http 1.1"]),S.host&&S.path&&(delete S.path,delete S.pathname),this.proxy=S}callback(P,L){return u(this,void 0,void 0,(function*(){let{proxy:S,secureProxy:v}=this,b;v?(C("Creating `tls.Socket`: %o",S),b=p.default.connect(S)):(C("Creating `net.Socket`: %o",S),b=c.default.connect(S));let O=Object.assign({},S.headers),d=`CONNECT ${L.host}:${L.port} HTTP/1.1\r
`;S.auth&&(O["Proxy-Authorization"]=`Basic ${Buffer.from(S.auth).toString("base64")}`);let{host:g,port:A,secureEndpoint:T}=L;(function(H,j){return!!(!j&&H===80||j&&H===443)})(A,T)||(g+=`:${A}`),O.Host=g,O.Connection="close";for(let H of Object.keys(O))d+=`${H}: ${O[H]}\r
`;let x=k.default(b);b.write(`${d}\r
`);let{statusCode:w,buffered:F}=yield x;if(w===200){if(P.once("socket",E),L.secureEndpoint){C("Upgrading socket connection to TLS");let H=L.servername||L.host;return p.default.connect(Object.assign(Object.assign({},(function(j,...B){let K={},ie;for(ie in j)B.includes(ie)||(K[ie]=j[ie]);return K})(L,"host","hostname","path","port")),{socket:b,servername:H}))}return b}b.destroy();let D=new c.default.Socket({writable:!1});return D.readable=!0,P.once("socket",(H=>{C("replaying proxy buffer for failed request"),m.default(H.listenerCount("data")>0),H.push(F),H.push(null)})),D}))}}function E(_){_.resume()}s.default=R},18:function(o,s,a){"use strict";let u=(this&&this.__importDefault||function(c){return c&&c.__esModule?c:{default:c}})(a(146));function l(c){return new u.default(c)}(function(c){c.HttpsProxyAgent=u.default,c.prototype=u.default.prototype})(l||(l={})),o.exports=l},829:function(o,s,a){"use strict";var u=this&&this.__importDefault||function(c){return c&&c.__esModule?c:{default:c}};Object.defineProperty(s,"__esModule",{value:!0});let l=u(a(374)).default("https-proxy-agent:parse-proxy-response");s.default=function(c){return new Promise(((p,f)=>{let m=0,h=[];function y(){let R=c.read();R?(function(E){h.push(E),m+=E.length;let _=Buffer.concat(h,m);if(_.indexOf(`\r
\r
`)===-1)return l("have not received end of HTTP headers yet..."),void y();let P=_.toString("ascii",0,_.indexOf(`\r
`)),L=+P.split(" ")[1];l("got proxy server response: %o",P),p({statusCode:L,buffered:_})})(R):c.once("readable",y)}function k(R){l("onclose had error %o",R)}function C(){l("onend")}c.on("error",(function R(E){c.removeListener("end",C),c.removeListener("error",R),c.removeListener("close",k),c.removeListener("readable",y),l("onerror %o",E),f(E)})),c.on("close",k),c.on("end",C),y()}))}},539:function(o,s,a){"use strict";var u,l=this&&this.__extends||(u=function(v,b){return u=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(O,d){O.__proto__=d}||function(O,d){for(var g in d)Object.prototype.hasOwnProperty.call(d,g)&&(O[g]=d[g])},u(v,b)},function(v,b){if(typeof b!="function"&&b!==null)throw new TypeError("Class extends value "+String(b)+" is not a constructor or null");function O(){this.constructor=v}u(v,b),v.prototype=b===null?Object.create(b):(O.prototype=b.prototype,new O)}),c=this&&this.__assign||function(){return c=Object.assign||function(v){for(var b,O=1,d=arguments.length;O<d;O++)for(var g in b=arguments[O])Object.prototype.hasOwnProperty.call(b,g)&&(v[g]=b[g]);return v},c.apply(this,arguments)};Object.defineProperty(s,"__esModule",{value:!0}),s.getErrorStatusDescription=s.xhr=s.configure=void 0;var p=a(685),f=a(687),m=a(310),h=a(472),y=a(796),k=a(201),C=a(18);if(process.env.VSCODE_NLS_CONFIG){var R=process.env.VSCODE_NLS_CONFIG;h.config(JSON.parse(R))}var E=h.loadMessageBundle(),_=void 0,P=!0;function L(v){var b;return new Promise((function(O,d){var g=(0,m.parse)(v.url),A={hostname:g.hostname,agent:!!v.agent&&v.agent,port:g.port?parseInt(g.port):g.protocol==="https:"?443:80,path:g.path,method:v.type||"GET",headers:v.headers,rejectUnauthorized:typeof v.strictSSL!="boolean"||v.strictSSL};v.user&&v.password&&(A.auth=v.user+":"+v.password);var T=function(x){if(x.statusCode>=300&&x.statusCode<400&&v.followRedirects&&v.followRedirects>0&&x.headers.location){var w=x.headers.location;w.startsWith("/")&&(w=(0,m.format)({protocol:g.protocol,hostname:g.hostname,port:g.port,pathname:w})),O(L((function(F){for(var D=[],H=1;H<arguments.length;H++)D[H-1]=arguments[H];return D.forEach((function(j){return Object.keys(j).forEach((function(B){return F[B]=j[B]}))})),F})({},v,{url:w,followRedirects:v.followRedirects-1})))}else O({req:b,res:x})};(b=g.protocol==="https:"?f.request(A,T):p.request(A,T)).on("error",d),v.timeout&&b.setTimeout(v.timeout),v.data&&b.write(v.data),b.end(),v.token&&(v.token.isCancellationRequested&&b.destroy(new S),v.token.onCancellationRequested((function(){b.destroy(new S)})))}))}s.configure=function(v,b){_=v,P=b},s.xhr=function(v){return typeof(v=c({},v)).strictSSL!="boolean"&&(v.strictSSL=P),v.agent||(v.agent=(function(b,O){O===void 0&&(O={});var d=(0,m.parse)(b),g=O.proxyUrl||(function(x){return x.protocol==="http:"?process.env.HTTP_PROXY||process.env.http_proxy||null:x.protocol==="https:"&&(process.env.HTTPS_PROXY||process.env.https_proxy||process.env.HTTP_PROXY||process.env.http_proxy)||null})(d);if(!g)return null;var A=(0,m.parse)(g);if(!/^https?:$/.test(A.protocol))return null;var T={host:A.hostname,port:Number(A.port),auth:A.auth,rejectUnauthorized:typeof O.strictSSL!="boolean"||O.strictSSL,protocol:A.protocol};return d.protocol==="http:"?k(T):C(T)})(v.url,{proxyUrl:_,strictSSL:P})),typeof v.followRedirects!="number"&&(v.followRedirects=5),L(v).then((function(b){return new Promise((function(O,d){var g,A,T=b.res,x=T,w=!1,F=T.headers&&T.headers["content-encoding"];if(F&&(g=v.type,A=b.res.statusCode,!(g==="HEAD"||A>=100&&A<200||A===204||A===304))){var D={flush:y.constants.Z_SYNC_FLUSH,finishFlush:y.constants.Z_SYNC_FLUSH};if(F==="gzip"){var H=y.createGunzip(D);T.pipe(H),x=H}else if(F==="deflate"){var j=y.createInflate(D);T.pipe(j),x=j}}var B=[];x.on("data",(function(K){return B.push(K)})),x.on("end",(function(){if(!w){if(w=!0,v.followRedirects>0&&(T.statusCode>=300&&T.statusCode<=303||T.statusCode===307)){var K=T.headers.location;if(K.startsWith("/")){var ie=(0,m.parse)(v.url);K=(0,m.format)({protocol:ie.protocol,hostname:ie.hostname,port:ie.port,pathname:K})}if(K){var Le={type:v.type,url:K,user:v.user,password:v.password,headers:v.headers,timeout:v.timeout,followRedirects:v.followRedirects-1,data:v.data,token:v.token};return void(0,s.xhr)(Le).then(O,d)}}var he=Buffer.concat(B),W={responseText:he.toString(),body:he,status:T.statusCode,headers:T.headers||{}};T.statusCode>=200&&T.statusCode<300||T.statusCode===1223?O(W):d(W)}})),x.on("error",(function(K){var ie;ie=S.is(K)?K:{responseText:E("error","Unable to access {0}. Error: {1}",v.url,K.message),body:Buffer.concat(B),status:500,headers:{}},w=!0,d(ie)})),v.token&&(v.token.isCancellationRequested&&x.destroy(new S),v.token.onCancellationRequested((function(){x.destroy(new S)})))}))}),(function(b){var O;return O=S.is(b)?b:{responseText:v.agent?E("error.cannot.connect.proxy","Unable to connect to {0} through a proxy. Error: {1}",v.url,b.message):E("error.cannot.connect","Unable to connect to {0}. Error: {1}",v.url,b.message),body:Buffer.concat([]),status:404,headers:{}},Promise.reject(O)}))},s.getErrorStatusDescription=function(v){if(!(v<400))switch(v){case 400:return E("status.400","Bad request. The request cannot be fulfilled due to bad syntax.");case 401:return E("status.401","Unauthorized. The server is refusing to respond.");case 403:return E("status.403","Forbidden. The server is refusing to respond.");case 404:return E("status.404","Not Found. The requested location could not be found.");case 405:return E("status.405","Method not allowed. A request was made using a request method not supported by that location.");case 406:return E("status.406","Not Acceptable. The server can only generate a response that is not accepted by the client.");case 407:return E("status.407","Proxy Authentication Required. The client must first authenticate itself with the proxy.");case 408:return E("status.408","Request Timeout. The server timed out waiting for the request.");case 409:return E("status.409","Conflict. The request could not be completed because of a conflict in the request.");case 410:return E("status.410","Gone. The requested page is no longer available.");case 411:return E("status.411",'Length Required. The "Content-Length" is not defined.');case 412:return E("status.412","Precondition Failed. The precondition given in the request evaluated to false by the server.");case 413:return E("status.413","Request Entity Too Large. The server will not accept the request, because the request entity is too large.");case 414:return E("status.414","Request-URI Too Long. The server will not accept the request, because the URL is too long.");case 415:return E("status.415","Unsupported Media Type. The server will not accept the request, because the media type is not supported.");case 500:return E("status.500","Internal Server Error.");case 501:return E("status.501","Not Implemented. The server either does not recognize the request method, or it lacks the ability to fulfill the request.");case 502:return E("status.502","Bad Gateway. The upstream server did not respond.");case 503:return E("status.503","Service Unavailable. The server is currently unavailable (overloaded or down).");default:return E("status.416","HTTP status code {0}",v)}};var S=(function(v){function b(){var O=v.call(this,"The user aborted a request")||this;return O.name="AbortError",Object.setPrototypeOf(O,b.prototype),O}return l(b,v),b.is=function(O){return O instanceof b},b})(Error)},800:(o,s,a)=>{"use strict";Object.defineProperty(s,"__esModule",{value:!0}),s.config=s.loadMessageBundle=s.localize=s.format=s.setPseudo=s.isPseudo=s.isDefined=s.BundleFormat=s.MessageFormat=void 0;var u,l,c,p=a(926);function f(h){return h!==void 0}function m(h,y){return s.isPseudo&&(h="\uFF3B"+h.replace(/[aouei]/g,"$&$&")+"\uFF3D"),y.length===0?h:h.replace(/\{(\d+)\}/g,(function(k,C){var R=C[0],E=y[R],_=k;return typeof E=="string"?_=E:typeof E!="number"&&typeof E!="boolean"&&E!=null||(_=String(E)),_}))}(c=s.MessageFormat||(s.MessageFormat={})).file="file",c.bundle="bundle",c.both="both",(l=s.BundleFormat||(s.BundleFormat={})).standalone="standalone",l.languagePack="languagePack",(function(h){h.is=function(y){var k=y;return k&&f(k.key)&&f(k.comment)}})(u||(u={})),s.isDefined=f,s.isPseudo=!1,s.setPseudo=function(h){s.isPseudo=h},s.format=m,s.localize=function(h,y){for(var k=[],C=2;C<arguments.length;C++)k[C-2]=arguments[C];return m(y,k)},s.loadMessageBundle=function(h){return(0,p.default)().loadMessageBundle(h)},s.config=function(h){return(0,p.default)().config(h)}},926:(o,s)=>{"use strict";var a;function u(){if(a===void 0)throw new Error("No runtime abstraction layer installed");return a}Object.defineProperty(s,"__esModule",{value:!0}),(function(l){l.install=function(c){if(c===void 0)throw new Error("No runtime abstraction layer provided");a=c}})(u||(u={})),s.default=u},472:(o,s,a)=>{"use strict";Object.defineProperty(s,"__esModule",{value:!0}),s.config=s.loadMessageBundle=s.BundleFormat=s.MessageFormat=void 0;var u=a(17),l=a(147),c=a(926),p=a(800),f=a(800);Object.defineProperty(s,"MessageFormat",{enumerable:!0,get:function(){return f.MessageFormat}}),Object.defineProperty(s,"BundleFormat",{enumerable:!0,get:function(){return f.BundleFormat}});var m,h,y=Object.prototype.toString;function k(b){return y.call(b)==="[object Number]"}function C(b){return y.call(b)==="[object String]"}function R(b){return JSON.parse(l.readFileSync(b,"utf8"))}function E(b){return function(O,d){for(var g=[],A=2;A<arguments.length;A++)g[A-2]=arguments[A];return k(O)?O>=b.length?void console.error(`Broken localize call found. Index out of bounds. Stacktrace is
: `.concat(new Error("").stack)):(0,p.format)(b[O],g):C(d)?(console.warn("Message ".concat(d," didn't get externalized correctly.")),(0,p.format)(d,g)):void console.error(`Broken localize call found. Stacktrace is
: `.concat(new Error("").stack))}}function _(b,O){return m[b]=O,O}function P(b){try{return(function(O){var d=R(u.join(O,"nls.metadata.json")),g=Object.create(null);for(var A in d){var T=d[A];g[A]=T.messages}return g})(b)}catch(O){return void console.log("Generating default bundle from meta data failed.",O)}}function L(b,O){var d;if(h.languagePackSupport===!0&&h.cacheRoot!==void 0&&h.languagePackId!==void 0&&h.translationsConfigFile!==void 0&&h.translationsConfig!==void 0)try{d=(function(A,T){var x,w,F,D=u.join(h.cacheRoot,"".concat(A.id,"-").concat(A.hash,".json")),H=!1,j=!1;try{return x=JSON.parse(l.readFileSync(D,{encoding:"utf8",flag:"r"})),w=D,F=new Date,l.utimes(w,F,F,(function(){})),x}catch(B){if(B.code==="ENOENT")j=!0;else{if(!(B instanceof SyntaxError))throw B;console.log("Syntax error parsing message bundle: ".concat(B.message,".")),l.unlink(D,(function(K){K&&console.error("Deleting corrupted bundle ".concat(D," failed."))})),H=!0}}if(x=(function(B,K){var ie=h.translationsConfig[B.id];if(ie){var Le=R(ie).contents,he=R(u.join(K,"nls.metadata.json")),W=Object.create(null);for(var Te in he){var tt=he[Te],N=Le["".concat(B.outDir,"/").concat(Te)];if(N){for(var Q=[],I=0;I<tt.keys.length;I++){var Y=tt.keys[I],J=N[C(Y)?Y:Y.key];J===void 0&&(J=tt.messages[I]),Q.push(J)}W[Te]=Q}else W[Te]=tt.messages}return W}})(A,T),!x||H)return x;if(j)try{l.writeFileSync(D,JSON.stringify(x),{encoding:"utf8",flag:"wx"})}catch(B){if(B.code==="EEXIST")return x;throw B}return x})(b,O)}catch(A){console.log("Load or create bundle failed ",A)}if(!d){if(h.languagePackSupport)return P(O);var g=(function(A){for(var T=h.language;T;){var x=u.join(A,"nls.bundle.".concat(T,".json"));if(l.existsSync(x))return x;var w=T.lastIndexOf("-");T=w>0?T.substring(0,w):void 0}if(T===void 0&&(x=u.join(A,"nls.bundle.json"),l.existsSync(x)))return x})(O);if(g)try{return R(g)}catch(A){console.log("Loading in the box message bundle failed.",A)}d=P(O)}return d}function S(b){if(!b)return p.localize;var O=u.extname(b);if(O&&(b=b.substr(0,b.length-O.length)),h.messageFormat===p.MessageFormat.both||h.messageFormat===p.MessageFormat.bundle){var d=(function(H){for(var j,B=u.dirname(H);j=u.join(B,"nls.metadata.header.json"),!l.existsSync(j);){var K=u.dirname(B);if(K===B){j=void 0;break}B=K}return j})(b);if(d){var g=u.dirname(d),A=m[g];if(A===void 0)try{var T=JSON.parse(l.readFileSync(d,"utf8"));try{var x=L(T,g);A=_(g,x?{header:T,nlsBundle:x}:null)}catch(H){console.error("Failed to load nls bundle",H),A=_(g,null)}}catch(H){console.error("Failed to read header file",H),A=_(g,null)}if(A){var w=b.substr(g.length+1).replace(/\\/g,"/"),F=A.nlsBundle[w];return F===void 0?(console.error("Messages for file ".concat(b," not found. See console for details.")),function(){return"Messages not found."}):E(F)}}}if(h.messageFormat===p.MessageFormat.both||h.messageFormat===p.MessageFormat.file)try{var D=R((function(H){var j;if(!(h.cacheLanguageResolution&&j)){if(p.isPseudo||!h.language)j=".nls.json";else for(var B=h.language;B;){var K=".nls."+B+".json";if(l.existsSync(H+K)){j=K;break}var ie=B.lastIndexOf("-");ie>0?B=B.substring(0,ie):(j=".nls.json",B=null)}h.cacheLanguageResolution}return H+j})(b));return Array.isArray(D)?E(D):(0,p.isDefined)(D.messages)&&(0,p.isDefined)(D.keys)?E(D.messages):(console.error("String bundle '".concat(b,"' uses an unsupported format.")),function(){return"File bundle has unsupported format. See console for details"})}catch(H){H.code!=="ENOENT"&&console.error("Failed to load single file bundle",H)}return console.error("Failed to load message bundle for file ".concat(b)),function(){return"Failed to load message bundle. See console for details."}}function v(b){return b&&(C(b.locale)&&(h.locale=b.locale.toLowerCase(),h.language=h.locale,m=Object.create(null)),b.messageFormat!==void 0&&(h.messageFormat=b.messageFormat),b.bundleFormat===p.BundleFormat.standalone&&h.languagePackSupport===!0&&(h.languagePackSupport=!1)),(0,p.setPseudo)(h.locale==="pseudo"),S}(function(){if(h={locale:void 0,language:void 0,languagePackSupport:!1,cacheLanguageResolution:!0,messageFormat:p.MessageFormat.bundle},C(process.env.VSCODE_NLS_CONFIG))try{var b=JSON.parse(process.env.VSCODE_NLS_CONFIG),O=void 0;if(b.availableLanguages){var d=b.availableLanguages["*"];C(d)&&(O=d)}if(C(b.locale)&&(h.locale=b.locale.toLowerCase()),O===void 0?h.language=h.locale:O!=="en"&&(h.language=O),(function(A){return A===!0||A===!1})(b._languagePackSupport)&&(h.languagePackSupport=b._languagePackSupport),C(b._cacheRoot)&&(h.cacheRoot=b._cacheRoot),C(b._languagePackId)&&(h.languagePackId=b._languagePackId),C(b._translationsConfigFile)){h.translationsConfigFile=b._translationsConfigFile;try{h.translationsConfig=R(h.translationsConfigFile)}catch{if(b._corruptedFile){var g=u.dirname(b._corruptedFile);l.exists(g,(function(T){T&&l.writeFile(b._corruptedFile,"corrupted","utf8",(function(x){console.error(x)}))}))}}}}catch{}(0,p.setPseudo)(h.locale==="pseudo"),m=Object.create(null)})(),s.loadMessageBundle=S,s.config=v,c.default.install(Object.freeze({loadMessageBundle:S,config:v}))},374:(o,s)=>{function a(){}Object.defineProperty(s,"__esModule",{value:!0}),s.default=function(u){return a}},491:o=>{"use strict";o.exports=require("assert")},361:o=>{"use strict";o.exports=require("events")},147:o=>{"use strict";o.exports=require("fs")},685:o=>{"use strict";o.exports=require("http")},687:o=>{"use strict";o.exports=require("https")},808:o=>{"use strict";o.exports=require("net")},17:o=>{"use strict";o.exports=require("path")},404:o=>{"use strict";o.exports=require("tls")},310:o=>{"use strict";o.exports=require("url")},796:o=>{"use strict";o.exports=require("zlib")}},t={},n=(function o(s){var a=t[s];if(a!==void 0)return a.exports;var u=t[s]={exports:{}};return e[s].call(u.exports,u,u.exports,o),u.exports})(539),r=Hr;for(var i in n)r[i]=n[i];n.__esModule&&Object.defineProperty(r,"__esModule",{value:!0})})()});var Qr=M((Og,zr)=>{var dc=typeof process=="object"&&process&&process.platform==="win32";zr.exports=dc?{sep:"\\"}:{sep:"/"}});var ni=M((Cg,ti)=>{"use strict";ti.exports=Zr;function Zr(e,t,n){e instanceof RegExp&&(e=Xr(e,n)),t instanceof RegExp&&(t=Xr(t,n));var r=ei(e,t,n);return r&&{start:r[0],end:r[1],pre:n.slice(0,r[0]),body:n.slice(r[0]+e.length,r[1]),post:n.slice(r[1]+t.length)}}function Xr(e,t){var n=t.match(e);return n?n[0]:null}Zr.range=ei;function ei(e,t,n){var r,i,o,s,a,u=n.indexOf(e),l=n.indexOf(t,u+1),c=u;if(u>=0&&l>0){for(r=[],o=n.length;c>=0&&!a;)c==u?(r.push(c),u=n.indexOf(e,c+1)):r.length==1?a=[r.pop(),l]:(i=r.pop(),i<o&&(o=i,s=l),l=n.indexOf(t,c+1)),c=u<l&&u>=0?u:l;r.length&&(a=[o,s])}return a}});var li=M((Pg,ci)=>{var ri=ni();ci.exports=yc;var ii="\0SLASH"+Math.random()+"\0",oi="\0OPEN"+Math.random()+"\0",jn="\0CLOSE"+Math.random()+"\0",si="\0COMMA"+Math.random()+"\0",ai="\0PERIOD"+Math.random()+"\0";function Hn(e){return parseInt(e,10)==e?parseInt(e,10):e.charCodeAt(0)}function gc(e){return e.split("\\\\").join(ii).split("\\{").join(oi).split("\\}").join(jn).split("\\,").join(si).split("\\.").join(ai)}function mc(e){return e.split(ii).join("\\").split(oi).join("{").split(jn).join("}").split(si).join(",").split(ai).join(".")}function ui(e){if(!e)return[""];var t=[],n=ri("{","}",e);if(!n)return e.split(",");var r=n.pre,i=n.body,o=n.post,s=r.split(",");s[s.length-1]+="{"+i+"}";var a=ui(o);return o.length&&(s[s.length-1]+=a.shift(),s.push.apply(s,a)),t.push.apply(t,s),t}function yc(e){return e?(e.substr(0,2)==="{}"&&(e="\\{\\}"+e.substr(2)),St(gc(e),!0).map(mc)):[]}function xc(e){return"{"+e+"}"}function vc(e){return/^-?0\d/.test(e)}function bc(e,t){return e<=t}function wc(e,t){return e>=t}function St(e,t){var n=[],r=ri("{","}",e);if(!r)return[e];var i=r.pre,o=r.post.length?St(r.post,!1):[""];if(/\$$/.test(r.pre))for(var s=0;s<o.length;s++){var a=i+"{"+r.body+"}"+o[s];n.push(a)}else{var u=/^-?\d+\.\.-?\d+(?:\.\.-?\d+)?$/.test(r.body),l=/^[a-zA-Z]\.\.[a-zA-Z](?:\.\.-?\d+)?$/.test(r.body),c=u||l,p=r.body.indexOf(",")>=0;if(!c&&!p)return r.post.match(/,(?!,).*\}/)?(e=r.pre+"{"+r.body+jn+r.post,St(e)):[e];var f;if(c)f=r.body.split(/\.\./);else if(f=ui(r.body),f.length===1&&(f=St(f[0],!1).map(xc),f.length===1))return o.map(function(O){return r.pre+f[0]+O});var m;if(c){var h=Hn(f[0]),y=Hn(f[1]),k=Math.max(f[0].length,f[1].length),C=f.length==3?Math.max(Math.abs(Hn(f[2])),1):1,R=bc,E=y<h;E&&(C*=-1,R=wc);var _=f.some(vc);m=[];for(var P=h;R(P,y);P+=C){var L;if(l)L=String.fromCharCode(P),L==="\\"&&(L="");else if(L=String(P),_){var S=k-L.length;if(S>0){var v=new Array(S+1).join("0");P<0?L="-"+v+L.slice(1):L=v+L}}m.push(L)}}else{m=[];for(var b=0;b<f.length;b++)m.push.apply(m,St(f[b],!1))}for(var b=0;b<m.length;b++)for(var s=0;s<o.length;s++){var a=i+m[b]+o[s];(!t||c||a)&&n.push(a)}}return n}});var mi=M((Ig,Gn)=>{var ye=Gn.exports=(e,t,n={})=>(Wt(t),!n.nocomment&&t.charAt(0)==="#"?!1:new rt(t,n).match(e));Gn.exports=ye;var Un=Qr();ye.sep=Un.sep;var fe=Symbol("globstar **");ye.GLOBSTAR=fe;var Ac=li(),fi={"!":{open:"(?:(?!(?:",close:"))[^/]*?)"},"?":{open:"(?:",close:")?"},"+":{open:"(?:",close:")+"},"*":{open:"(?:",close:")*"},"@":{open:"(?:",close:")"}},Bn="[^/]",$n=Bn+"*?",Sc="(?:(?!(?:\\/|^)(?:\\.{1,2})($|\\/)).)*?",Ec="(?:(?!(?:\\/|^)\\.).)*?",di=e=>e.split("").reduce((t,n)=>(t[n]=!0,t),{}),pi=di("().*{}+?[]^$\\!"),kc=di("[.("),hi=/\/+/;ye.filter=(e,t={})=>(n,r,i)=>ye(n,e,t);var Ie=(e,t={})=>{let n={};return Object.keys(e).forEach(r=>n[r]=e[r]),Object.keys(t).forEach(r=>n[r]=t[r]),n};ye.defaults=e=>{if(!e||typeof e!="object"||!Object.keys(e).length)return ye;let t=ye,n=(r,i,o)=>t(r,i,Ie(e,o));return n.Minimatch=class extends t.Minimatch{constructor(i,o){super(i,Ie(e,o))}},n.Minimatch.defaults=r=>t.defaults(Ie(e,r)).Minimatch,n.filter=(r,i)=>t.filter(r,Ie(e,i)),n.defaults=r=>t.defaults(Ie(e,r)),n.makeRe=(r,i)=>t.makeRe(r,Ie(e,i)),n.braceExpand=(r,i)=>t.braceExpand(r,Ie(e,i)),n.match=(r,i,o)=>t.match(r,i,Ie(e,o)),n};ye.braceExpand=(e,t)=>gi(e,t);var gi=(e,t={})=>(Wt(e),t.nobrace||!/\{(?:(?!\{).)*\}/.test(e)?[e]:Ac(e)),_c=1024*64,Wt=e=>{if(typeof e!="string")throw new TypeError("invalid pattern");if(e.length>_c)throw new TypeError("pattern is too long")},qn=Symbol("subparse");ye.makeRe=(e,t)=>new rt(e,t||{}).makeRe();ye.match=(e,t,n={})=>{let r=new rt(t,n);return e=e.filter(i=>r.match(i)),r.options.nonull&&!e.length&&e.push(t),e};var Tc=e=>e.replace(/\\(.)/g,"$1"),Rc=e=>e.replace(/\\([^-\]])/g,"$1"),Oc=e=>e.replace(/[-[\]{}()*+?.,\\^$|#\s]/g,"\\$&"),Cc=e=>e.replace(/[[\]\\]/g,"\\$&"),rt=class{constructor(t,n){Wt(t),n||(n={}),this.options=n,this.maxGlobstarRecursion=n.maxGlobstarRecursion!==void 0?n.maxGlobstarRecursion:200,this.set=[],this.pattern=t,this.windowsPathsNoEscape=!!n.windowsPathsNoEscape||n.allowWindowsEscape===!1,this.windowsPathsNoEscape&&(this.pattern=this.pattern.replace(/\\/g,"/")),this.regexp=null,this.negate=!1,this.comment=!1,this.empty=!1,this.partial=!!n.partial,this.make()}debug(){}make(){let t=this.pattern,n=this.options;if(!n.nocomment&&t.charAt(0)==="#"){this.comment=!0;return}if(!t){this.empty=!0;return}this.parseNegate();let r=this.globSet=this.braceExpand();n.debug&&(this.debug=(...i)=>console.error(...i)),this.debug(this.pattern,r),r=this.globParts=r.map(i=>i.split(hi)),this.debug(this.pattern,r),r=r.map((i,o,s)=>i.map(this.parse,this)),this.debug(this.pattern,r),r=r.filter(i=>i.indexOf(!1)===-1),this.debug(this.pattern,r),this.set=r}parseNegate(){if(this.options.nonegate)return;let t=this.pattern,n=!1,r=0;for(let i=0;i<t.length&&t.charAt(i)==="!";i++)n=!n,r++;r&&(this.pattern=t.slice(r)),this.negate=n}matchOne(t,n,r){return n.indexOf(fe)!==-1?this._matchGlobstar(t,n,r,0,0):this._matchOne(t,n,r,0,0)}_matchGlobstar(t,n,r,i,o){let s=-1;for(let R=o;R<n.length;R++)if(n[R]===fe){s=R;break}let a=-1;for(let R=n.length-1;R>=0;R--)if(n[R]===fe){a=R;break}let u=n.slice(o,s),l=n.slice(s+1,a),c=n.slice(a+1);if(u.length){let R=t.slice(i,i+u.length);if(!this._matchOne(R,u,r,0,0))return!1;i+=u.length}let p=0;if(c.length){if(c.length+i>t.length)return!1;let R=t.length-c.length;if(this._matchOne(t,c,r,R,0))p=c.length;else{if(t[t.length-1]!==""||i+c.length===t.length||!this._matchOne(t,c,r,R-1,0))return!1;p=c.length+1}}if(!l.length){let R=!!p;for(let E=i;E<t.length-p;E++){let _=String(t[E]);if(R=!0,_==="."||_===".."||!this.options.dot&&_.charAt(0)===".")return!1}return R}let f=[[[],0]],m=f[0],h=0,y=[0];for(let R of l)R===fe?(y.push(h),m=[[],0],f.push(m)):(m[0].push(R),h++);let k=f.length-1,C=t.length-p;for(let R of f)R[1]=C-(y[k--]+R[0].length);return!!this._matchGlobStarBodySections(t,f,i,0,r,0,!!p)}_matchGlobStarBodySections(t,n,r,i,o,s,a){let u=n[i];if(!u){for(let p=r;p<t.length;p++){a=!0;let f=t[p];if(f==="."||f===".."||!this.options.dot&&f.charAt(0)===".")return!1}return a}let[l,c]=u;for(;r<=c;){if(this._matchOne(t.slice(0,r+l.length),l,o,r,0)&&s<this.maxGlobstarRecursion){let m=this._matchGlobStarBodySections(t,n,r+l.length,i+1,o,s+1,a);if(m!==!1)return m}let f=t[r];if(f==="."||f===".."||!this.options.dot&&f.charAt(0)===".")return!1;r++}return null}_matchOne(t,n,r,i,o){let s,a,u,l;for(s=i,a=o,u=t.length,l=n.length;s<u&&a<l;s++,a++){this.debug("matchOne loop");let c=n[a],p=t[s];if(this.debug(n,c,p),c===!1||c===fe)return!1;let f;if(typeof c=="string"?(f=p===c,this.debug("string match",c,p,f)):(f=p.match(c),this.debug("pattern match",c,p,f)),!f)return!1}if(s===u&&a===l)return!0;if(s===u)return r;if(a===l)return s===u-1&&t[s]==="";throw new Error("wtf?")}braceExpand(){return gi(this.pattern,this.options)}parse(t,n){Wt(t);let r=this.options;if(t==="**")if(r.noglobstar)t="*";else return fe;if(t==="")return"";let i="",o=!1,s=!1,a=[],u=[],l,c=!1,p=-1,f=-1,m,h,y,k=t.charAt(0)===".",C=r.dot||k,R=()=>k?"":C?"(?!(?:^|\\/)\\.{1,2}(?:$|\\/))":"(?!\\.)",E=S=>S.charAt(0)==="."?"":r.dot?"(?!(?:^|\\/)\\.{1,2}(?:$|\\/))":"(?!\\.)",_=()=>{if(l){switch(l){case"*":i+=$n,o=!0;break;case"?":i+=Bn,o=!0;break;default:i+="\\"+l;break}this.debug("clearStateChar %j %j",l,i),l=!1}};for(let S=0,v;S<t.length&&(v=t.charAt(S));S++){if(this.debug("%s	%s %s %j",t,S,i,v),s){if(v==="/")return!1;pi[v]&&(i+="\\"),i+=v,s=!1;continue}switch(v){case"/":return!1;case"\\":if(c&&t.charAt(S+1)==="-"){i+=v;continue}_(),s=!0;continue;case"?":case"*":case"+":case"@":case"!":if(this.debug("%s	%s %s %j <-- stateChar",t,S,i,v),c){this.debug("  in class"),v==="!"&&S===f+1&&(v="^"),i+=v;continue}if(v==="*"&&l==="*")continue;this.debug("call clearStateChar %j",l),_(),l=v,r.noext&&_();continue;case"(":{if(c){i+="(";continue}if(!l){i+="\\(";continue}let b={type:l,start:S-1,reStart:i.length,open:fi[l].open,close:fi[l].close};this.debug(this.pattern,"	",b),a.push(b),i+=b.open,b.start===0&&b.type!=="!"&&(k=!0,i+=E(t.slice(S+1))),this.debug("plType %j %j",l,i),l=!1;continue}case")":{let b=a[a.length-1];if(c||!b){i+="\\)";continue}a.pop(),_(),o=!0,h=b,i+=h.close,h.type==="!"&&u.push(Object.assign(h,{reEnd:i.length}));continue}case"|":{let b=a[a.length-1];if(c||!b){i+="\\|";continue}_(),i+="|",b.start===0&&b.type!=="!"&&(k=!0,i+=E(t.slice(S+1)));continue}case"[":if(_(),c){i+="\\"+v;continue}c=!0,f=S,p=i.length,i+=v;continue;case"]":if(S===f+1||!c){i+="\\"+v;continue}m=t.substring(f+1,S);try{RegExp("["+Cc(Rc(m))+"]"),i+=v}catch{i=i.substring(0,p)+"(?:$.)"}o=!0,c=!1;continue;default:_(),pi[v]&&!(v==="^"&&c)&&(i+="\\"),i+=v;break}}for(c&&(m=t.slice(f+1),y=this.parse(m,qn),i=i.substring(0,p)+"\\["+y[0],o=o||y[1]),h=a.pop();h;h=a.pop()){let S;S=i.slice(h.reStart+h.open.length),this.debug("setting tail",i,h),S=S.replace(/((?:\\{2}){0,64})(\\?)\|/g,(b,O,d)=>(d||(d="\\"),O+O+d+"|")),this.debug(`tail=%j
   %s`,S,S,h,i);let v=h.type==="*"?$n:h.type==="?"?Bn:"\\"+h.type;o=!0,i=i.slice(0,h.reStart)+v+"\\("+S}_(),s&&(i+="\\\\");let P=kc[i.charAt(0)];for(let S=u.length-1;S>-1;S--){let v=u[S],b=i.slice(0,v.reStart),O=i.slice(v.reStart,v.reEnd-8),d=i.slice(v.reEnd),g=i.slice(v.reEnd-8,v.reEnd)+d,A=b.split(")").length,T=b.split("(").length-A,x=d;for(let F=0;F<T;F++)x=x.replace(/\)[+*?]?/,"");d=x;let w=d===""&&n!==qn?"(?:$|\\/)":"";i=b+O+d+w+g}if(i!==""&&o&&(i="(?=.)"+i),P&&(i=R()+i),n===qn)return[i,o];if(r.nocase&&!o&&(o=t.toUpperCase()!==t.toLowerCase()),!o)return Tc(t);let L=r.nocase?"i":"";try{return Object.assign(new RegExp("^"+i+"$",L),{_glob:t,_src:i})}catch{return new RegExp("$.")}}makeRe(){if(this.regexp||this.regexp===!1)return this.regexp;let t=this.set;if(!t.length)return this.regexp=!1,this.regexp;let n=this.options,r=n.noglobstar?$n:n.dot?Sc:Ec,i=n.nocase?"i":"",o=t.map(s=>(s=s.map(a=>typeof a=="string"?Oc(a):a===fe?fe:a._src).reduce((a,u)=>(a[a.length-1]===fe&&u===fe||a.push(u),a),[]),s.forEach((a,u)=>{a!==fe||s[u-1]===fe||(u===0?s.length>1?s[u+1]="(?:\\/|"+r+"\\/)?"+s[u+1]:s[u]=r:u===s.length-1?s[u-1]+="(?:\\/|"+r+")?":(s[u-1]+="(?:\\/|\\/"+r+"\\/)"+s[u+1],s[u+1]=fe))}),s.filter(a=>a!==fe).join("/"))).join("|");o="^(?:"+o+")$",this.negate&&(o="^(?!"+o+").*$");try{this.regexp=new RegExp(o,i)}catch{this.regexp=!1}return this.regexp}match(t,n=this.partial){if(this.debug("match",t,this.pattern),this.comment)return!1;if(this.empty)return t==="";if(t==="/"&&n)return!0;let r=this.options;Un.sep!=="/"&&(t=t.split(Un.sep).join("/")),t=t.split(hi),this.debug(this.pattern,"split",t);let i=this.set;this.debug(this.pattern,"set",i);let o;for(let s=t.length-1;s>=0&&(o=t[s],!o);s--);for(let s=0;s<i.length;s++){let a=i[s],u=t;if(r.matchBase&&a.length===1&&(u=[o]),this.matchOne(u,a,n))return r.flipNegate?!0:!this.negate}return r.flipNegate?!1:this.negate}static defaults(t){return ye.defaults(t).Minimatch}};ye.Minimatch=rt});var vi=M((Mg,xi)=>{var Yn=class{constructor(t){this.value=t,this.next=void 0}},Vn=class{constructor(){this.clear()}enqueue(t){let n=new Yn(t);this._head?(this._tail.next=n,this._tail=n):(this._head=n,this._tail=n),this._size++}dequeue(){let t=this._head;if(t)return this._head=this._head.next,this._size--,t.value}clear(){this._head=void 0,this._tail=void 0,this._size=0}get size(){return this._size}*[Symbol.iterator](){let t=this._head;for(;t;)yield t.value,t=t.next}};xi.exports=Vn});var wi=M((Dg,bi)=>{"use strict";var Pc=vi(),Lc=e=>{if(!((Number.isInteger(e)||e===1/0)&&e>0))throw new TypeError("Expected `concurrency` to be a number from 1 and up");let t=new Pc,n=0,r=()=>{n--,t.size>0&&t.dequeue()()},i=async(a,u,...l)=>{n++;let c=(async()=>a(...l))();u(c);try{await c}catch{}r()},o=(a,u,...l)=>{t.enqueue(i.bind(null,a,u,...l)),(async()=>(await Promise.resolve(),n<e&&t.size>0&&t.dequeue()()))()},s=(a,...u)=>new Promise(l=>{o(a,l,...u)});return Object.defineProperties(s,{activeCount:{get:()=>n},pendingCount:{get:()=>t.size},clearQueue:{value:()=>{t.clear()}}}),s};bi.exports=Lc});var Ei=M((Hg,Si)=>{"use strict";var Ai=wi(),Yt=class extends Error{constructor(t){super(),this.value=t}},Ic=async(e,t)=>t(await e),Nc=async e=>{let t=await Promise.all(e);if(t[1]===!0)throw new Yt(t[0]);return!1},Fc=async(e,t,n)=>{n={concurrency:1/0,preserveOrder:!0,...n};let r=Ai(n.concurrency),i=[...e].map(s=>[s,r(Ic,s,t)]),o=Ai(n.preserveOrder?1:1/0);try{await Promise.all(i.map(s=>o(Nc,s)))}catch(s){if(s instanceof Yt)return s.value;throw s}};Si.exports=Fc});var Ci=M((jg,Kn)=>{"use strict";var ki=require("path"),Vt=require("fs"),{promisify:_i}=require("util"),Mc=Ei(),Dc=_i(Vt.stat),Hc=_i(Vt.lstat),Ti={directory:"isDirectory",file:"isFile"};function Ri({type:e}){if(!(e in Ti))throw new Error(`Invalid type specified: ${e}`)}var Oi=(e,t)=>e===void 0||t[Ti[e]]();Kn.exports=async(e,t)=>{t={cwd:process.cwd(),type:"file",allowSymlinks:!0,...t},Ri(t);let n=t.allowSymlinks?Dc:Hc;return Mc(e,async r=>{try{let i=await n(ki.resolve(t.cwd,r));return Oi(t.type,i)}catch{return!1}},t)};Kn.exports.sync=(e,t)=>{t={cwd:process.cwd(),allowSymlinks:!0,type:"file",...t},Ri(t);let n=t.allowSymlinks?Vt.statSync:Vt.lstatSync;for(let r of e)try{let i=n(ki.resolve(t.cwd,r));if(Oi(t.type,i))return r}catch{}}});var zn=M(($g,Jn)=>{"use strict";var Pi=require("fs"),{promisify:jc}=require("util"),$c=jc(Pi.access);Jn.exports=async e=>{try{return await $c(e),!0}catch{return!1}};Jn.exports.sync=e=>{try{return Pi.accessSync(e),!0}catch{return!1}}});var Ii=M((qg,it)=>{"use strict";var Ne=require("path"),Kt=Ci(),Li=zn(),Qn=Symbol("findUp.stop");it.exports=async(e,t={})=>{let n=Ne.resolve(t.cwd||""),{root:r}=Ne.parse(n),i=[].concat(e),o=async s=>{if(typeof e!="function")return Kt(i,s);let a=await e(s.cwd);return typeof a=="string"?Kt([a],s):a};for(;;){let s=await o({...t,cwd:n});if(s===Qn)return;if(s)return Ne.resolve(n,s);if(n===r)return;n=Ne.dirname(n)}};it.exports.sync=(e,t={})=>{let n=Ne.resolve(t.cwd||""),{root:r}=Ne.parse(n),i=[].concat(e),o=s=>{if(typeof e!="function")return Kt.sync(i,s);let a=e(s.cwd);return typeof a=="string"?Kt.sync([a],s):a};for(;;){let s=o({...t,cwd:n});if(s===Qn)return;if(s)return Ne.resolve(n,s);if(n===r)return;n=Ne.dirname(n)}};it.exports.exists=Li;it.exports.sync.exists=Li.sync;it.exports.stop=Qn});var Fi=M((Ug,Ni)=>{var Fe=require("constants"),qc=process.cwd,Jt=null,Uc=process.env.GRACEFUL_FS_PLATFORM||process.platform;process.cwd=function(){return Jt||(Jt=qc.call(process)),Jt};try{process.cwd()}catch{}var Bc=process.chdir;process.chdir=function(e){Jt=null,Bc.call(process,e)};Ni.exports=Gc;function Gc(e){Fe.hasOwnProperty("O_SYMLINK")&&process.version.match(/^v0\.6\.[0-2]|^v0\.5\./)&&t(e),e.lutimes||n(e),e.chown=o(e.chown),e.fchown=o(e.fchown),e.lchown=o(e.lchown),e.chmod=r(e.chmod),e.fchmod=r(e.fchmod),e.lchmod=r(e.lchmod),e.chownSync=s(e.chownSync),e.fchownSync=s(e.fchownSync),e.lchownSync=s(e.lchownSync),e.chmodSync=i(e.chmodSync),e.fchmodSync=i(e.fchmodSync),e.lchmodSync=i(e.lchmodSync),e.stat=a(e.stat),e.fstat=a(e.fstat),e.lstat=a(e.lstat),e.statSync=u(e.statSync),e.fstatSync=u(e.fstatSync),e.lstatSync=u(e.lstatSync),e.lchmod||(e.lchmod=function(c,p,f){f&&process.nextTick(f)},e.lchmodSync=function(){}),e.lchown||(e.lchown=function(c,p,f,m){m&&process.nextTick(m)},e.lchownSync=function(){}),Uc==="win32"&&(e.rename=(function(c){return function(p,f,m){var h=Date.now(),y=0;c(p,f,function k(C){if(C&&(C.code==="EACCES"||C.code==="EPERM")&&Date.now()-h<6e4){setTimeout(function(){e.stat(f,function(R,E){R&&R.code==="ENOENT"?c(p,f,k):m(C)})},y),y<100&&(y+=10);return}m&&m(C)})}})(e.rename)),e.read=(function(c){function p(f,m,h,y,k,C){var R;if(C&&typeof C=="function"){var E=0;R=function(_,P,L){if(_&&_.code==="EAGAIN"&&E<10)return E++,c.call(e,f,m,h,y,k,R);C.apply(this,arguments)}}return c.call(e,f,m,h,y,k,R)}return p.__proto__=c,p})(e.read),e.readSync=(function(c){return function(p,f,m,h,y){for(var k=0;;)try{return c.call(e,p,f,m,h,y)}catch(C){if(C.code==="EAGAIN"&&k<10){k++;continue}throw C}}})(e.readSync);function t(c){c.lchmod=function(p,f,m){c.open(p,Fe.O_WRONLY|Fe.O_SYMLINK,f,function(h,y){if(h){m&&m(h);return}c.fchmod(y,f,function(k){c.close(y,function(C){m&&m(k||C)})})})},c.lchmodSync=function(p,f){var m=c.openSync(p,Fe.O_WRONLY|Fe.O_SYMLINK,f),h=!0,y;try{y=c.fchmodSync(m,f),h=!1}finally{if(h)try{c.closeSync(m)}catch{}else c.closeSync(m)}return y}}function n(c){Fe.hasOwnProperty("O_SYMLINK")?(c.lutimes=function(p,f,m,h){c.open(p,Fe.O_SYMLINK,function(y,k){if(y){h&&h(y);return}c.futimes(k,f,m,function(C){c.close(k,function(R){h&&h(C||R)})})})},c.lutimesSync=function(p,f,m){var h=c.openSync(p,Fe.O_SYMLINK),y,k=!0;try{y=c.futimesSync(h,f,m),k=!1}finally{if(k)try{c.closeSync(h)}catch{}else c.closeSync(h)}return y}):(c.lutimes=function(p,f,m,h){h&&process.nextTick(h)},c.lutimesSync=function(){})}function r(c){return c&&function(p,f,m){return c.call(e,p,f,function(h){l(h)&&(h=null),m&&m.apply(this,arguments)})}}function i(c){return c&&function(p,f){try{return c.call(e,p,f)}catch(m){if(!l(m))throw m}}}function o(c){return c&&function(p,f,m,h){return c.call(e,p,f,m,function(y){l(y)&&(y=null),h&&h.apply(this,arguments)})}}function s(c){return c&&function(p,f,m){try{return c.call(e,p,f,m)}catch(h){if(!l(h))throw h}}}function a(c){return c&&function(p,f,m){typeof f=="function"&&(m=f,f=null);function h(y,k){k&&(k.uid<0&&(k.uid+=4294967296),k.gid<0&&(k.gid+=4294967296)),m&&m.apply(this,arguments)}return f?c.call(e,p,f,h):c.call(e,p,h)}}function u(c){return c&&function(p,f){var m=f?c.call(e,p,f):c.call(e,p);return m.uid<0&&(m.uid+=4294967296),m.gid<0&&(m.gid+=4294967296),m}}function l(c){if(!c||c.code==="ENOSYS")return!0;var p=!process.getuid||process.getuid()!==0;return!!(p&&(c.code==="EINVAL"||c.code==="EPERM"))}}});var Hi=M((Bg,Di)=>{var Mi=require("stream").Stream;Di.exports=Wc;function Wc(e){return{ReadStream:t,WriteStream:n};function t(r,i){if(!(this instanceof t))return new t(r,i);Mi.call(this);var o=this;this.path=r,this.fd=null,this.readable=!0,this.paused=!1,this.flags="r",this.mode=438,this.bufferSize=64*1024,i=i||{};for(var s=Object.keys(i),a=0,u=s.length;a<u;a++){var l=s[a];this[l]=i[l]}if(this.encoding&&this.setEncoding(this.encoding),this.start!==void 0){if(typeof this.start!="number")throw TypeError("start must be a Number");if(this.end===void 0)this.end=1/0;else if(typeof this.end!="number")throw TypeError("end must be a Number");if(this.start>this.end)throw new Error("start must be <= end");this.pos=this.start}if(this.fd!==null){process.nextTick(function(){o._read()});return}e.open(this.path,this.flags,this.mode,function(c,p){if(c){o.emit("error",c),o.readable=!1;return}o.fd=p,o.emit("open",p),o._read()})}function n(r,i){if(!(this instanceof n))return new n(r,i);Mi.call(this),this.path=r,this.fd=null,this.writable=!0,this.flags="w",this.encoding="binary",this.mode=438,this.bytesWritten=0,i=i||{};for(var o=Object.keys(i),s=0,a=o.length;s<a;s++){var u=o[s];this[u]=i[u]}if(this.start!==void 0){if(typeof this.start!="number")throw TypeError("start must be a Number");if(this.start<0)throw new Error("start must be >= zero");this.pos=this.start}this.busy=!1,this._queue=[],this.fd===null&&(this._open=e.open,this._queue.push([this._open,this.path,this.flags,this.mode,void 0]),this.flush())}}});var $i=M((Gg,ji)=>{"use strict";ji.exports=Yc;function Yc(e){if(e===null||typeof e!="object")return e;if(e instanceof Object)var t={__proto__:e.__proto__};else var t=Object.create(null);return Object.getOwnPropertyNames(e).forEach(function(n){Object.defineProperty(t,n,Object.getOwnPropertyDescriptor(e,n))}),t}});var Bi=M((Wg,Zn)=>{var ue=require("fs"),Vc=Fi(),Kc=Hi(),Jc=$i(),zt=require("util"),we,Qt;typeof Symbol=="function"&&typeof Symbol.for=="function"?(we=Symbol.for("graceful-fs.queue"),Qt=Symbol.for("graceful-fs.previous")):(we="___graceful-fs.queue",Qt="___graceful-fs.previous");function zc(){}function Ui(e,t){Object.defineProperty(e,we,{get:function(){return t}})}var kt=zc;zt.debuglog?kt=zt.debuglog("gfs4"):/\bgfs4\b/i.test(process.env.NODE_DEBUG||"")&&(kt=function(){var e=zt.format.apply(zt,arguments);e="GFS4: "+e.split(/\n/).join(`
GFS4: `),console.error(e)});ue[we]||(qi=global[we]||[],Ui(ue,qi),ue.close=(function(e){function t(n,r){return e.call(ue,n,function(i){i||je(),typeof r=="function"&&r.apply(this,arguments)})}return Object.defineProperty(t,Qt,{value:e}),t})(ue.close),ue.closeSync=(function(e){function t(n){e.apply(ue,arguments),je()}return Object.defineProperty(t,Qt,{value:e}),t})(ue.closeSync),/\bgfs4\b/i.test(process.env.NODE_DEBUG||"")&&process.on("exit",function(){kt(ue[we]),require("assert").equal(ue[we].length,0)}));var qi;global[we]||Ui(global,ue[we]);Zn.exports=Xn(Jc(ue));process.env.TEST_GRACEFUL_FS_GLOBAL_PATCH&&!ue.__patched&&(Zn.exports=Xn(ue),ue.__patched=!0);function Xn(e){Vc(e),e.gracefulify=Xn,e.createReadStream=E,e.createWriteStream=_;var t=e.readFile;e.readFile=n;function n(S,v,b){return typeof v=="function"&&(b=v,v=null),O(S,v,b);function O(d,g,A){return t(d,g,function(T){T&&(T.code==="EMFILE"||T.code==="ENFILE")?Et([O,[d,g,A]]):(typeof A=="function"&&A.apply(this,arguments),je())})}}var r=e.writeFile;e.writeFile=i;function i(S,v,b,O){return typeof b=="function"&&(O=b,b=null),d(S,v,b,O);function d(g,A,T,x){return r(g,A,T,function(w){w&&(w.code==="EMFILE"||w.code==="ENFILE")?Et([d,[g,A,T,x]]):(typeof x=="function"&&x.apply(this,arguments),je())})}}var o=e.appendFile;o&&(e.appendFile=s);function s(S,v,b,O){return typeof b=="function"&&(O=b,b=null),d(S,v,b,O);function d(g,A,T,x){return o(g,A,T,function(w){w&&(w.code==="EMFILE"||w.code==="ENFILE")?Et([d,[g,A,T,x]]):(typeof x=="function"&&x.apply(this,arguments),je())})}}var a=e.readdir;e.readdir=u;function u(S,v,b){var O=[S];return typeof v!="function"?O.push(v):b=v,O.push(d),l(O);function d(g,A){A&&A.sort&&A.sort(),g&&(g.code==="EMFILE"||g.code==="ENFILE")?Et([l,[O]]):(typeof b=="function"&&b.apply(this,arguments),je())}}function l(S){return a.apply(e,S)}if(process.version.substr(0,4)==="v0.8"){var c=Kc(e);y=c.ReadStream,C=c.WriteStream}var p=e.ReadStream;p&&(y.prototype=Object.create(p.prototype),y.prototype.open=k);var f=e.WriteStream;f&&(C.prototype=Object.create(f.prototype),C.prototype.open=R),Object.defineProperty(e,"ReadStream",{get:function(){return y},set:function(S){y=S},enumerable:!0,configurable:!0}),Object.defineProperty(e,"WriteStream",{get:function(){return C},set:function(S){C=S},enumerable:!0,configurable:!0});var m=y;Object.defineProperty(e,"FileReadStream",{get:function(){return m},set:function(S){m=S},enumerable:!0,configurable:!0});var h=C;Object.defineProperty(e,"FileWriteStream",{get:function(){return h},set:function(S){h=S},enumerable:!0,configurable:!0});function y(S,v){return this instanceof y?(p.apply(this,arguments),this):y.apply(Object.create(y.prototype),arguments)}function k(){var S=this;L(S.path,S.flags,S.mode,function(v,b){v?(S.autoClose&&S.destroy(),S.emit("error",v)):(S.fd=b,S.emit("open",b),S.read())})}function C(S,v){return this instanceof C?(f.apply(this,arguments),this):C.apply(Object.create(C.prototype),arguments)}function R(){var S=this;L(S.path,S.flags,S.mode,function(v,b){v?(S.destroy(),S.emit("error",v)):(S.fd=b,S.emit("open",b))})}function E(S,v){return new e.ReadStream(S,v)}function _(S,v){return new e.WriteStream(S,v)}var P=e.open;e.open=L;function L(S,v,b,O){return typeof b=="function"&&(O=b,b=null),d(S,v,b,O);function d(g,A,T,x){return P(g,A,T,function(w,F){w&&(w.code==="EMFILE"||w.code==="ENFILE")?Et([d,[g,A,T,x]]):(typeof x=="function"&&x.apply(this,arguments),je())})}}return e}function Et(e){kt("ENQUEUE",e[0].name,e[1]),ue[we].push(e)}function je(){var e=ue[we].shift();e&&(kt("RETRY",e[0].name,e[1]),e[0].apply(null,e[1]))}});var Yi=M((Yg,Wi)=>{"use strict";var Gi=(e,t)=>function(...n){let r=t.promiseModule;return new r((i,o)=>{t.multiArgs?n.push((...s)=>{t.errorFirst?s[0]?o(s):(s.shift(),i(s)):i(s)}):t.errorFirst?n.push((s,a)=>{s?o(s):i(a)}):n.push(i),e.apply(this,n)})};Wi.exports=(e,t)=>{t=Object.assign({exclude:[/.+(Sync|Stream)$/],errorFirst:!0,promiseModule:Promise},t);let n=typeof e;if(!(e!==null&&(n==="object"||n==="function")))throw new TypeError(`Expected \`input\` to be a \`Function\` or \`Object\`, got \`${e===null?"null":n}\``);let r=o=>{let s=a=>typeof a=="string"?o===a:a.test(o);return t.include?t.include.some(s):!t.exclude.some(s)},i;n==="function"?i=function(...o){return t.excludeMain?e(...o):Gi(e,t).apply(this,o)}:i=Object.create(Object.getPrototypeOf(e));for(let o in e){let s=e[o];i[o]=typeof s=="function"&&r(o)?Gi(s,t):s}return i}});var Ki=M((Vg,Vi)=>{"use strict";Vi.exports=e=>{if(typeof e!="string")throw new TypeError("Expected a string, got "+typeof e);return e.charCodeAt(0)===65279?e.slice(1):e}});var qe=M((Kg,$e)=>{"use strict";function Ji(e){return typeof e>"u"||e===null}function Qc(e){return typeof e=="object"&&e!==null}function Xc(e){return Array.isArray(e)?e:Ji(e)?[]:[e]}function Zc(e,t){var n,r,i,o;if(t)for(o=Object.keys(t),n=0,r=o.length;n<r;n+=1)i=o[n],e[i]=t[i];return e}function el(e,t){var n="",r;for(r=0;r<t;r+=1)n+=e;return n}function tl(e){return e===0&&Number.NEGATIVE_INFINITY===1/e}$e.exports.isNothing=Ji;$e.exports.isObject=Qc;$e.exports.toArray=Xc;$e.exports.repeat=el;$e.exports.isNegativeZero=tl;$e.exports.extend=Zc});var ot=M((Jg,zi)=>{"use strict";function _t(e,t){Error.call(this),this.name="YAMLException",this.reason=e,this.mark=t,this.message=(this.reason||"(unknown reason)")+(this.mark?" "+this.mark.toString():""),Error.captureStackTrace?Error.captureStackTrace(this,this.constructor):this.stack=new Error().stack||""}_t.prototype=Object.create(Error.prototype);_t.prototype.constructor=_t;_t.prototype.toString=function(t){var n=this.name+": ";return n+=this.reason||"(unknown reason)",!t&&this.mark&&(n+=" "+this.mark.toString()),n};zi.exports=_t});var Zi=M((zg,Xi)=>{"use strict";var Qi=qe();function er(e,t,n,r,i){this.name=e,this.buffer=t,this.position=n,this.line=r,this.column=i}er.prototype.getSnippet=function(t,n){var r,i,o,s,a;if(!this.buffer)return null;for(t=t||4,n=n||75,r="",i=this.position;i>0&&`\0\r
\x85\u2028\u2029`.indexOf(this.buffer.charAt(i-1))===-1;)if(i-=1,this.position-i>n/2-1){r=" ... ",i+=5;break}for(o="",s=this.position;s<this.buffer.length&&`\0\r
\x85\u2028\u2029`.indexOf(this.buffer.charAt(s))===-1;)if(s+=1,s-this.position>n/2-1){o=" ... ",s-=5;break}return a=this.buffer.slice(i,s),Qi.repeat(" ",t)+r+a+o+`
`+Qi.repeat(" ",t+this.position-i+r.length)+"^"};er.prototype.toString=function(t){var n,r="";return this.name&&(r+='in "'+this.name+'" '),r+="at line "+(this.line+1)+", column "+(this.column+1),t||(n=this.getSnippet(),n&&(r+=`:
`+n)),r};Xi.exports=er});var se=M((Qg,to)=>{"use strict";var eo=ot(),nl=["kind","resolve","construct","instanceOf","predicate","represent","defaultStyle","styleAliases"],rl=["scalar","sequence","mapping"];function il(e){var t={};return e!==null&&Object.keys(e).forEach(function(n){e[n].forEach(function(r){t[String(r)]=n})}),t}function ol(e,t){if(t=t||{},Object.keys(t).forEach(function(n){if(nl.indexOf(n)===-1)throw new eo('Unknown option "'+n+'" is met in definition of "'+e+'" YAML type.')}),this.tag=e,this.kind=t.kind||null,this.resolve=t.resolve||function(){return!0},this.construct=t.construct||function(n){return n},this.instanceOf=t.instanceOf||null,this.predicate=t.predicate||null,this.represent=t.represent||null,this.defaultStyle=t.defaultStyle||null,this.styleAliases=il(t.styleAliases||null),rl.indexOf(this.kind)===-1)throw new eo('Unknown kind "'+this.kind+'" is specified for "'+e+'" YAML type.')}to.exports=ol});var Ue=M((Xg,ro)=>{"use strict";var no=qe(),Xt=ot(),sl=se();function tr(e,t,n){var r=[];return e.include.forEach(function(i){n=tr(i,t,n)}),e[t].forEach(function(i){n.forEach(function(o,s){o.tag===i.tag&&o.kind===i.kind&&r.push(s)}),n.push(i)}),n.filter(function(i,o){return r.indexOf(o)===-1})}function al(){var e={scalar:{},sequence:{},mapping:{},fallback:{}},t,n;function r(i){e[i.kind][i.tag]=e.fallback[i.tag]=i}for(t=0,n=arguments.length;t<n;t+=1)arguments[t].forEach(r);return e}function st(e){this.include=e.include||[],this.implicit=e.implicit||[],this.explicit=e.explicit||[],this.implicit.forEach(function(t){if(t.loadKind&&t.loadKind!=="scalar")throw new Xt("There is a non-scalar type in the implicit list of a schema. Implicit resolving of such types is not supported.")}),this.compiledImplicit=tr(this,"implicit",[]),this.compiledExplicit=tr(this,"explicit",[]),this.compiledTypeMap=al(this.compiledImplicit,this.compiledExplicit)}st.DEFAULT=null;st.create=function(){var t,n;switch(arguments.length){case 1:t=st.DEFAULT,n=arguments[0];break;case 2:t=arguments[0],n=arguments[1];break;default:throw new Xt("Wrong number of arguments for Schema.create function")}if(t=no.toArray(t),n=no.toArray(n),!t.every(function(r){return r instanceof st}))throw new Xt("Specified list of super schemas (or a single Schema object) contains a non-Schema object.");if(!n.every(function(r){return r instanceof sl}))throw new Xt("Specified list of YAML types (or a single Type object) contains a non-Type object.");return new st({include:t,explicit:n})};ro.exports=st});var oo=M((Zg,io)=>{"use strict";var ul=se();io.exports=new ul("tag:yaml.org,2002:str",{kind:"scalar",construct:function(e){return e!==null?e:""}})});var ao=M((em,so)=>{"use strict";var cl=se();so.exports=new cl("tag:yaml.org,2002:seq",{kind:"sequence",construct:function(e){return e!==null?e:[]}})});var co=M((tm,uo)=>{"use strict";var ll=se();uo.exports=new ll("tag:yaml.org,2002:map",{kind:"mapping",construct:function(e){return e!==null?e:{}}})});var Zt=M((nm,lo)=>{"use strict";var fl=Ue();lo.exports=new fl({explicit:[oo(),ao(),co()]})});var po=M((rm,fo)=>{"use strict";var pl=se();function hl(e){if(e===null)return!0;var t=e.length;return t===1&&e==="~"||t===4&&(e==="null"||e==="Null"||e==="NULL")}function dl(){return null}function gl(e){return e===null}fo.exports=new pl("tag:yaml.org,2002:null",{kind:"scalar",resolve:hl,construct:dl,predicate:gl,represent:{canonical:function(){return"~"},lowercase:function(){return"null"},uppercase:function(){return"NULL"},camelcase:function(){return"Null"}},defaultStyle:"lowercase"})});var go=M((im,ho)=>{"use strict";var ml=se();function yl(e){if(e===null)return!1;var t=e.length;return t===4&&(e==="true"||e==="True"||e==="TRUE")||t===5&&(e==="false"||e==="False"||e==="FALSE")}function xl(e){return e==="true"||e==="True"||e==="TRUE"}function vl(e){return Object.prototype.toString.call(e)==="[object Boolean]"}ho.exports=new ml("tag:yaml.org,2002:bool",{kind:"scalar",resolve:yl,construct:xl,predicate:vl,represent:{lowercase:function(e){return e?"true":"false"},uppercase:function(e){return e?"TRUE":"FALSE"},camelcase:function(e){return e?"True":"False"}},defaultStyle:"lowercase"})});var yo=M((om,mo)=>{"use strict";var bl=qe(),wl=se();function Al(e){return 48<=e&&e<=57||65<=e&&e<=70||97<=e&&e<=102}function Sl(e){return 48<=e&&e<=55}function El(e){return 48<=e&&e<=57}function kl(e){if(e===null)return!1;var t=e.length,n=0,r=!1,i;if(!t)return!1;if(i=e[n],(i==="-"||i==="+")&&(i=e[++n]),i==="0"){if(n+1===t)return!0;if(i=e[++n],i==="b"){for(n++;n<t;n++)if(i=e[n],i!=="_"){if(i!=="0"&&i!=="1")return!1;r=!0}return r&&i!=="_"}if(i==="x"){for(n++;n<t;n++)if(i=e[n],i!=="_"){if(!Al(e.charCodeAt(n)))return!1;r=!0}return r&&i!=="_"}for(;n<t;n++)if(i=e[n],i!=="_"){if(!Sl(e.charCodeAt(n)))return!1;r=!0}return r&&i!=="_"}if(i==="_")return!1;for(;n<t;n++)if(i=e[n],i!=="_"){if(i===":")break;if(!El(e.charCodeAt(n)))return!1;r=!0}return!r||i==="_"?!1:i!==":"?!0:/^(:[0-5]?[0-9])+$/.test(e.slice(n))}function _l(e){var t=e,n=1,r,i,o=[];return t.indexOf("_")!==-1&&(t=t.replace(/_/g,"")),r=t[0],(r==="-"||r==="+")&&(r==="-"&&(n=-1),t=t.slice(1),r=t[0]),t==="0"?0:r==="0"?t[1]==="b"?n*parseInt(t.slice(2),2):t[1]==="x"?n*parseInt(t,16):n*parseInt(t,8):t.indexOf(":")!==-1?(t.split(":").forEach(function(s){o.unshift(parseInt(s,10))}),t=0,i=1,o.forEach(function(s){t+=s*i,i*=60}),n*t):n*parseInt(t,10)}function Tl(e){return Object.prototype.toString.call(e)==="[object Number]"&&e%1===0&&!bl.isNegativeZero(e)}mo.exports=new wl("tag:yaml.org,2002:int",{kind:"scalar",resolve:kl,construct:_l,predicate:Tl,represent:{binary:function(e){return e>=0?"0b"+e.toString(2):"-0b"+e.toString(2).slice(1)},octal:function(e){return e>=0?"0"+e.toString(8):"-0"+e.toString(8).slice(1)},decimal:function(e){return e.toString(10)},hexadecimal:function(e){return e>=0?"0x"+e.toString(16).toUpperCase():"-0x"+e.toString(16).toUpperCase().slice(1)}},defaultStyle:"decimal",styleAliases:{binary:[2,"bin"],octal:[8,"oct"],decimal:[10,"dec"],hexadecimal:[16,"hex"]}})});var bo=M((sm,vo)=>{"use strict";var xo=qe(),Rl=se(),Ol=new RegExp("^(?:[-+]?(?:0|[1-9][0-9_]*)(?:\\.[0-9_]*)?(?:[eE][-+]?[0-9]+)?|\\.[0-9_]+(?:[eE][-+]?[0-9]+)?|[-+]?[0-9][0-9_]*(?::[0-5]?[0-9])+\\.[0-9_]*|[-+]?\\.(?:inf|Inf|INF)|\\.(?:nan|NaN|NAN))$");function Cl(e){return!(e===null||!Ol.test(e)||e[e.length-1]==="_")}function Pl(e){var t,n,r,i;return t=e.replace(/_/g,"").toLowerCase(),n=t[0]==="-"?-1:1,i=[],"+-".indexOf(t[0])>=0&&(t=t.slice(1)),t===".inf"?n===1?Number.POSITIVE_INFINITY:Number.NEGATIVE_INFINITY:t===".nan"?NaN:t.indexOf(":")>=0?(t.split(":").forEach(function(o){i.unshift(parseFloat(o,10))}),t=0,r=1,i.forEach(function(o){t+=o*r,r*=60}),n*t):n*parseFloat(t,10)}var Ll=/^[-+]?[0-9]+e/;function Il(e,t){var n;if(isNaN(e))switch(t){case"lowercase":return".nan";case"uppercase":return".NAN";case"camelcase":return".NaN"}else if(Number.POSITIVE_INFINITY===e)switch(t){case"lowercase":return".inf";case"uppercase":return".INF";case"camelcase":return".Inf"}else if(Number.NEGATIVE_INFINITY===e)switch(t){case"lowercase":return"-.inf";case"uppercase":return"-.INF";case"camelcase":return"-.Inf"}else if(xo.isNegativeZero(e))return"-0.0";return n=e.toString(10),Ll.test(n)?n.replace("e",".e"):n}function Nl(e){return Object.prototype.toString.call(e)==="[object Number]"&&(e%1!==0||xo.isNegativeZero(e))}vo.exports=new Rl("tag:yaml.org,2002:float",{kind:"scalar",resolve:Cl,construct:Pl,predicate:Nl,represent:Il,defaultStyle:"lowercase"})});var nr=M((am,wo)=>{"use strict";var Fl=Ue();wo.exports=new Fl({include:[Zt()],implicit:[po(),go(),yo(),bo()]})});var rr=M((um,Ao)=>{"use strict";var Ml=Ue();Ao.exports=new Ml({include:[nr()]})});var _o=M((cm,ko)=>{"use strict";var Dl=se(),So=new RegExp("^([0-9][0-9][0-9][0-9])-([0-9][0-9])-([0-9][0-9])$"),Eo=new RegExp("^([0-9][0-9][0-9][0-9])-([0-9][0-9]?)-([0-9][0-9]?)(?:[Tt]|[ \\t]+)([0-9][0-9]?):([0-9][0-9]):([0-9][0-9])(?:\\.([0-9]*))?(?:[ \\t]*(Z|([-+])([0-9][0-9]?)(?::([0-9][0-9]))?))?$");function Hl(e){return e===null?!1:So.exec(e)!==null||Eo.exec(e)!==null}function jl(e){var t,n,r,i,o,s,a,u=0,l=null,c,p,f;if(t=So.exec(e),t===null&&(t=Eo.exec(e)),t===null)throw new Error("Date resolve error");if(n=+t[1],r=+t[2]-1,i=+t[3],!t[4])return new Date(Date.UTC(n,r,i));if(o=+t[4],s=+t[5],a=+t[6],t[7]){for(u=t[7].slice(0,3);u.length<3;)u+="0";u=+u}return t[9]&&(c=+t[10],p=+(t[11]||0),l=(c*60+p)*6e4,t[9]==="-"&&(l=-l)),f=new Date(Date.UTC(n,r,i,o,s,a,u)),l&&f.setTime(f.getTime()-l),f}function $l(e){return e.toISOString()}ko.exports=new Dl("tag:yaml.org,2002:timestamp",{kind:"scalar",resolve:Hl,construct:jl,instanceOf:Date,represent:$l})});var Ro=M((lm,To)=>{"use strict";var ql=se();function Ul(e){return e==="<<"||e===null}To.exports=new ql("tag:yaml.org,2002:merge",{kind:"scalar",resolve:Ul})});var Po=M((fm,Co)=>{"use strict";var Be;try{Oo=require,Be=Oo("buffer").Buffer}catch{}var Oo,Bl=se(),ir=`ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=
\r`;function Gl(e){if(e===null)return!1;var t,n,r=0,i=e.length,o=ir;for(n=0;n<i;n++)if(t=o.indexOf(e.charAt(n)),!(t>64)){if(t<0)return!1;r+=6}return r%8===0}function Wl(e){var t,n,r=e.replace(/[\r\n=]/g,""),i=r.length,o=ir,s=0,a=[];for(t=0;t<i;t++)t%4===0&&t&&(a.push(s>>16&255),a.push(s>>8&255),a.push(s&255)),s=s<<6|o.indexOf(r.charAt(t));return n=i%4*6,n===0?(a.push(s>>16&255),a.push(s>>8&255),a.push(s&255)):n===18?(a.push(s>>10&255),a.push(s>>2&255)):n===12&&a.push(s>>4&255),Be?Be.from?Be.from(a):new Be(a):a}function Yl(e){var t="",n=0,r,i,o=e.length,s=ir;for(r=0;r<o;r++)r%3===0&&r&&(t+=s[n>>18&63],t+=s[n>>12&63],t+=s[n>>6&63],t+=s[n&63]),n=(n<<8)+e[r];return i=o%3,i===0?(t+=s[n>>18&63],t+=s[n>>12&63],t+=s[n>>6&63],t+=s[n&63]):i===2?(t+=s[n>>10&63],t+=s[n>>4&63],t+=s[n<<2&63],t+=s[64]):i===1&&(t+=s[n>>2&63],t+=s[n<<4&63],t+=s[64],t+=s[64]),t}function Vl(e){return Be&&Be.isBuffer(e)}Co.exports=new Bl("tag:yaml.org,2002:binary",{kind:"scalar",resolve:Gl,construct:Wl,predicate:Vl,represent:Yl})});var Io=M((pm,Lo)=>{"use strict";var Kl=se(),Jl=Object.prototype.hasOwnProperty,zl=Object.prototype.toString;function Ql(e){if(e===null)return!0;var t=[],n,r,i,o,s,a=e;for(n=0,r=a.length;n<r;n+=1){if(i=a[n],s=!1,zl.call(i)!=="[object Object]")return!1;for(o in i)if(Jl.call(i,o))if(!s)s=!0;else return!1;if(!s)return!1;if(t.indexOf(o)===-1)t.push(o);else return!1}return!0}function Xl(e){return e!==null?e:[]}Lo.exports=new Kl("tag:yaml.org,2002:omap",{kind:"sequence",resolve:Ql,construct:Xl})});var Fo=M((hm,No)=>{"use strict";var Zl=se(),ef=Object.prototype.toString;function tf(e){if(e===null)return!0;var t,n,r,i,o,s=e;for(o=new Array(s.length),t=0,n=s.length;t<n;t+=1){if(r=s[t],ef.call(r)!=="[object Object]"||(i=Object.keys(r),i.length!==1))return!1;o[t]=[i[0],r[i[0]]]}return!0}function nf(e){if(e===null)return[];var t,n,r,i,o,s=e;for(o=new Array(s.length),t=0,n=s.length;t<n;t+=1)r=s[t],i=Object.keys(r),o[t]=[i[0],r[i[0]]];return o}No.exports=new Zl("tag:yaml.org,2002:pairs",{kind:"sequence",resolve:tf,construct:nf})});var Do=M((dm,Mo)=>{"use strict";var rf=se(),of=Object.prototype.hasOwnProperty;function sf(e){if(e===null)return!0;var t,n=e;for(t in n)if(of.call(n,t)&&n[t]!==null)return!1;return!0}function af(e){return e!==null?e:{}}Mo.exports=new rf("tag:yaml.org,2002:set",{kind:"mapping",resolve:sf,construct:af})});var at=M((gm,Ho)=>{"use strict";var uf=Ue();Ho.exports=new uf({include:[rr()],implicit:[_o(),Ro()],explicit:[Po(),Io(),Fo(),Do()]})});var $o=M((mm,jo)=>{"use strict";var cf=se();function lf(){return!0}function ff(){}function pf(){return""}function hf(e){return typeof e>"u"}jo.exports=new cf("tag:yaml.org,2002:js/undefined",{kind:"scalar",resolve:lf,construct:ff,predicate:hf,represent:pf})});var Uo=M((ym,qo)=>{"use strict";var df=se();function gf(e){if(e===null||e.length===0)return!1;var t=e,n=/\/([gim]*)$/.exec(e),r="";return!(t[0]==="/"&&(n&&(r=n[1]),r.length>3||t[t.length-r.length-1]!=="/"))}function mf(e){var t=e,n=/\/([gim]*)$/.exec(e),r="";return t[0]==="/"&&(n&&(r=n[1]),t=t.slice(1,t.length-r.length-1)),new RegExp(t,r)}function yf(e){var t="/"+e.source+"/";return e.global&&(t+="g"),e.multiline&&(t+="m"),e.ignoreCase&&(t+="i"),t}function xf(e){return Object.prototype.toString.call(e)==="[object RegExp]"}qo.exports=new df("tag:yaml.org,2002:js/regexp",{kind:"scalar",resolve:gf,construct:mf,predicate:xf,represent:yf})});var Wo=M((xm,Go)=>{"use strict";var en;try{Bo=require,en=Bo("esprima")}catch{typeof window<"u"&&(en=window.esprima)}var Bo,vf=se();function bf(e){if(e===null)return!1;try{var t="("+e+")",n=en.parse(t,{range:!0});return!(n.type!=="Program"||n.body.length!==1||n.body[0].type!=="ExpressionStatement"||n.body[0].expression.type!=="ArrowFunctionExpression"&&n.body[0].expression.type!=="FunctionExpression")}catch{return!1}}function wf(e){var t="("+e+")",n=en.parse(t,{range:!0}),r=[],i;if(n.type!=="Program"||n.body.length!==1||n.body[0].type!=="ExpressionStatement"||n.body[0].expression.type!=="ArrowFunctionExpression"&&n.body[0].expression.type!=="FunctionExpression")throw new Error("Failed to resolve function");return n.body[0].expression.params.forEach(function(o){r.push(o.name)}),i=n.body[0].expression.body.range,n.body[0].expression.body.type==="BlockStatement"?new Function(r,t.slice(i[0]+1,i[1]-1)):new Function(r,"return "+t.slice(i[0],i[1]))}function Af(e){return e.toString()}function Sf(e){return Object.prototype.toString.call(e)==="[object Function]"}Go.exports=new vf("tag:yaml.org,2002:js/function",{kind:"scalar",resolve:bf,construct:wf,predicate:Sf,represent:Af})});var Tt=M((vm,Vo)=>{"use strict";var Yo=Ue();Vo.exports=Yo.DEFAULT=new Yo({include:[at()],explicit:[$o(),Uo(),Wo()]})});var hs=M((bm,Rt)=>{"use strict";var Re=qe(),es=ot(),Ef=Zi(),ts=at(),kf=Tt(),De=Object.prototype.hasOwnProperty,tn=1,ns=2,rs=3,nn=4,or=1,_f=2,Ko=3,Tf=/[\x00-\x08\x0B\x0C\x0E-\x1F\x7F-\x84\x86-\x9F\uFFFE\uFFFF]|[\uD800-\uDBFF](?![\uDC00-\uDFFF])|(?:[^\uD800-\uDBFF]|^)[\uDC00-\uDFFF]/,Rf=/[\x85\u2028\u2029]/,Of=/[,\[\]\{\}]/,is=/^(?:!|!!|![a-z\-]+!)$/i,os=/^(?:!|[^,\[\]\{\}])(?:%[0-9a-f]{2}|[0-9a-z\-#;\/\?:@&=\+\$,_\.!~\*'\(\)\[\]])*$/i;function Jo(e){return Object.prototype.toString.call(e)}function Ee(e){return e===10||e===13}function We(e){return e===9||e===32}function de(e){return e===9||e===32||e===10||e===13}function ut(e){return e===44||e===91||e===93||e===123||e===125}function Cf(e){var t;return 48<=e&&e<=57?e-48:(t=e|32,97<=t&&t<=102?t-97+10:-1)}function Pf(e){return e===120?2:e===117?4:e===85?8:0}function Lf(e){return 48<=e&&e<=57?e-48:-1}function zo(e){return e===48?"\0":e===97?"\x07":e===98?"\b":e===116||e===9?"	":e===110?`
`:e===118?"\v":e===102?"\f":e===114?"\r":e===101?"\x1B":e===32?" ":e===34?'"':e===47?"/":e===92?"\\":e===78?"\x85":e===95?"\xA0":e===76?"\u2028":e===80?"\u2029":""}function If(e){return e<=65535?String.fromCharCode(e):String.fromCharCode((e-65536>>10)+55296,(e-65536&1023)+56320)}function ss(e,t,n){t==="__proto__"?Object.defineProperty(e,t,{configurable:!0,enumerable:!0,writable:!0,value:n}):e[t]=n}var as=new Array(256),us=new Array(256);for(Ge=0;Ge<256;Ge++)as[Ge]=zo(Ge)?1:0,us[Ge]=zo(Ge);var Ge;function Nf(e,t){this.input=e,this.filename=t.filename||null,this.schema=t.schema||kf,this.onWarning=t.onWarning||null,this.legacy=t.legacy||!1,this.json=t.json||!1,this.listener=t.listener||null,this.implicitTypes=this.schema.compiledImplicit,this.typeMap=this.schema.compiledTypeMap,this.length=e.length,this.position=0,this.line=0,this.lineStart=0,this.lineIndent=0,this.documents=[]}function cs(e,t){return new es(t,new Ef(e.filename,e.input,e.position,e.line,e.position-e.lineStart))}function U(e,t){throw cs(e,t)}function rn(e,t){e.onWarning&&e.onWarning.call(null,cs(e,t))}var Qo={YAML:function(t,n,r){var i,o,s;t.version!==null&&U(t,"duplication of %YAML directive"),r.length!==1&&U(t,"YAML directive accepts exactly one argument"),i=/^([0-9]+)\.([0-9]+)$/.exec(r[0]),i===null&&U(t,"ill-formed argument of the YAML directive"),o=parseInt(i[1],10),s=parseInt(i[2],10),o!==1&&U(t,"unacceptable YAML version of the document"),t.version=r[0],t.checkLineBreaks=s<2,s!==1&&s!==2&&rn(t,"unsupported YAML version of the document")},TAG:function(t,n,r){var i,o;r.length!==2&&U(t,"TAG directive accepts exactly two arguments"),i=r[0],o=r[1],is.test(i)||U(t,"ill-formed tag handle (first argument) of the TAG directive"),De.call(t.tagMap,i)&&U(t,'there is a previously declared suffix for "'+i+'" tag handle'),os.test(o)||U(t,"ill-formed tag prefix (second argument) of the TAG directive"),t.tagMap[i]=o}};function Me(e,t,n,r){var i,o,s,a;if(t<n){if(a=e.input.slice(t,n),r)for(i=0,o=a.length;i<o;i+=1)s=a.charCodeAt(i),s===9||32<=s&&s<=1114111||U(e,"expected valid JSON character");else Tf.test(a)&&U(e,"the stream contains non-printable characters");e.result+=a}}function Xo(e,t,n,r){var i,o,s,a;for(Re.isObject(n)||U(e,"cannot merge mappings; the provided source object is unacceptable"),i=Object.keys(n),s=0,a=i.length;s<a;s+=1)o=i[s],De.call(t,o)||(ss(t,o,n[o]),r[o]=!0)}function ct(e,t,n,r,i,o,s,a){var u,l;if(Array.isArray(i))for(i=Array.prototype.slice.call(i),u=0,l=i.length;u<l;u+=1)Array.isArray(i[u])&&U(e,"nested arrays are not supported inside keys"),typeof i=="object"&&Jo(i[u])==="[object Object]"&&(i[u]="[object Object]");if(typeof i=="object"&&Jo(i)==="[object Object]"&&(i="[object Object]"),i=String(i),t===null&&(t={}),r==="tag:yaml.org,2002:merge")if(Array.isArray(o))for(u=0,l=o.length;u<l;u+=1)Xo(e,t,o[u],n);else Xo(e,t,o,n);else!e.json&&!De.call(n,i)&&De.call(t,i)&&(e.line=s||e.line,e.position=a||e.position,U(e,"duplicated mapping key")),ss(t,i,o),delete n[i];return t}function sr(e){var t;t=e.input.charCodeAt(e.position),t===10?e.position++:t===13?(e.position++,e.input.charCodeAt(e.position)===10&&e.position++):U(e,"a line break is expected"),e.line+=1,e.lineStart=e.position}function ne(e,t,n){for(var r=0,i=e.input.charCodeAt(e.position);i!==0;){for(;We(i);)i=e.input.charCodeAt(++e.position);if(t&&i===35)do i=e.input.charCodeAt(++e.position);while(i!==10&&i!==13&&i!==0);if(Ee(i))for(sr(e),i=e.input.charCodeAt(e.position),r++,e.lineIndent=0;i===32;)e.lineIndent++,i=e.input.charCodeAt(++e.position);else break}return n!==-1&&r!==0&&e.lineIndent<n&&rn(e,"deficient indentation"),r}function on(e){var t=e.position,n;return n=e.input.charCodeAt(t),!!((n===45||n===46)&&n===e.input.charCodeAt(t+1)&&n===e.input.charCodeAt(t+2)&&(t+=3,n=e.input.charCodeAt(t),n===0||de(n)))}function ar(e,t){t===1?e.result+=" ":t>1&&(e.result+=Re.repeat(`
`,t-1))}function Ff(e,t,n){var r,i,o,s,a,u,l,c,p=e.kind,f=e.result,m;if(m=e.input.charCodeAt(e.position),de(m)||ut(m)||m===35||m===38||m===42||m===33||m===124||m===62||m===39||m===34||m===37||m===64||m===96||(m===63||m===45)&&(i=e.input.charCodeAt(e.position+1),de(i)||n&&ut(i)))return!1;for(e.kind="scalar",e.result="",o=s=e.position,a=!1;m!==0;){if(m===58){if(i=e.input.charCodeAt(e.position+1),de(i)||n&&ut(i))break}else if(m===35){if(r=e.input.charCodeAt(e.position-1),de(r))break}else{if(e.position===e.lineStart&&on(e)||n&&ut(m))break;if(Ee(m))if(u=e.line,l=e.lineStart,c=e.lineIndent,ne(e,!1,-1),e.lineIndent>=t){a=!0,m=e.input.charCodeAt(e.position);continue}else{e.position=s,e.line=u,e.lineStart=l,e.lineIndent=c;break}}a&&(Me(e,o,s,!1),ar(e,e.line-u),o=s=e.position,a=!1),We(m)||(s=e.position+1),m=e.input.charCodeAt(++e.position)}return Me(e,o,s,!1),e.result?!0:(e.kind=p,e.result=f,!1)}function Mf(e,t){var n,r,i;if(n=e.input.charCodeAt(e.position),n!==39)return!1;for(e.kind="scalar",e.result="",e.position++,r=i=e.position;(n=e.input.charCodeAt(e.position))!==0;)if(n===39)if(Me(e,r,e.position,!0),n=e.input.charCodeAt(++e.position),n===39)r=e.position,e.position++,i=e.position;else return!0;else Ee(n)?(Me(e,r,i,!0),ar(e,ne(e,!1,t)),r=i=e.position):e.position===e.lineStart&&on(e)?U(e,"unexpected end of the document within a single quoted scalar"):(e.position++,i=e.position);U(e,"unexpected end of the stream within a single quoted scalar")}function Df(e,t){var n,r,i,o,s,a;if(a=e.input.charCodeAt(e.position),a!==34)return!1;for(e.kind="scalar",e.result="",e.position++,n=r=e.position;(a=e.input.charCodeAt(e.position))!==0;){if(a===34)return Me(e,n,e.position,!0),e.position++,!0;if(a===92){if(Me(e,n,e.position,!0),a=e.input.charCodeAt(++e.position),Ee(a))ne(e,!1,t);else if(a<256&&as[a])e.result+=us[a],e.position++;else if((s=Pf(a))>0){for(i=s,o=0;i>0;i--)a=e.input.charCodeAt(++e.position),(s=Cf(a))>=0?o=(o<<4)+s:U(e,"expected hexadecimal character");e.result+=If(o),e.position++}else U(e,"unknown escape sequence");n=r=e.position}else Ee(a)?(Me(e,n,r,!0),ar(e,ne(e,!1,t)),n=r=e.position):e.position===e.lineStart&&on(e)?U(e,"unexpected end of the document within a double quoted scalar"):(e.position++,r=e.position)}U(e,"unexpected end of the stream within a double quoted scalar")}function Hf(e,t){var n=!0,r,i=e.tag,o,s=e.anchor,a,u,l,c,p,f={},m,h,y,k;if(k=e.input.charCodeAt(e.position),k===91)u=93,p=!1,o=[];else if(k===123)u=125,p=!0,o={};else return!1;for(e.anchor!==null&&(e.anchorMap[e.anchor]=o),k=e.input.charCodeAt(++e.position);k!==0;){if(ne(e,!0,t),k=e.input.charCodeAt(e.position),k===u)return e.position++,e.tag=i,e.anchor=s,e.kind=p?"mapping":"sequence",e.result=o,!0;n||U(e,"missed comma between flow collection entries"),h=m=y=null,l=c=!1,k===63&&(a=e.input.charCodeAt(e.position+1),de(a)&&(l=c=!0,e.position++,ne(e,!0,t))),r=e.line,lt(e,t,tn,!1,!0),h=e.tag,m=e.result,ne(e,!0,t),k=e.input.charCodeAt(e.position),(c||e.line===r)&&k===58&&(l=!0,k=e.input.charCodeAt(++e.position),ne(e,!0,t),lt(e,t,tn,!1,!0),y=e.result),p?ct(e,o,f,h,m,y):l?o.push(ct(e,null,f,h,m,y)):o.push(m),ne(e,!0,t),k=e.input.charCodeAt(e.position),k===44?(n=!0,k=e.input.charCodeAt(++e.position)):n=!1}U(e,"unexpected end of the stream within a flow collection")}function jf(e,t){var n,r,i=or,o=!1,s=!1,a=t,u=0,l=!1,c,p;if(p=e.input.charCodeAt(e.position),p===124)r=!1;else if(p===62)r=!0;else return!1;for(e.kind="scalar",e.result="";p!==0;)if(p=e.input.charCodeAt(++e.position),p===43||p===45)or===i?i=p===43?Ko:_f:U(e,"repeat of a chomping mode identifier");else if((c=Lf(p))>=0)c===0?U(e,"bad explicit indentation width of a block scalar; it cannot be less than one"):s?U(e,"repeat of an indentation width identifier"):(a=t+c-1,s=!0);else break;if(We(p)){do p=e.input.charCodeAt(++e.position);while(We(p));if(p===35)do p=e.input.charCodeAt(++e.position);while(!Ee(p)&&p!==0)}for(;p!==0;){for(sr(e),e.lineIndent=0,p=e.input.charCodeAt(e.position);(!s||e.lineIndent<a)&&p===32;)e.lineIndent++,p=e.input.charCodeAt(++e.position);if(!s&&e.lineIndent>a&&(a=e.lineIndent),Ee(p)){u++;continue}if(e.lineIndent<a){i===Ko?e.result+=Re.repeat(`
`,o?1+u:u):i===or&&o&&(e.result+=`
`);break}for(r?We(p)?(l=!0,e.result+=Re.repeat(`
`,o?1+u:u)):l?(l=!1,e.result+=Re.repeat(`
`,u+1)):u===0?o&&(e.result+=" "):e.result+=Re.repeat(`
`,u):e.result+=Re.repeat(`
`,o?1+u:u),o=!0,s=!0,u=0,n=e.position;!Ee(p)&&p!==0;)p=e.input.charCodeAt(++e.position);Me(e,n,e.position,!1)}return!0}function Zo(e,t){var n,r=e.tag,i=e.anchor,o=[],s,a=!1,u;for(e.anchor!==null&&(e.anchorMap[e.anchor]=o),u=e.input.charCodeAt(e.position);u!==0&&!(u!==45||(s=e.input.charCodeAt(e.position+1),!de(s)));){if(a=!0,e.position++,ne(e,!0,-1)&&e.lineIndent<=t){o.push(null),u=e.input.charCodeAt(e.position);continue}if(n=e.line,lt(e,t,rs,!1,!0),o.push(e.result),ne(e,!0,-1),u=e.input.charCodeAt(e.position),(e.line===n||e.lineIndent>t)&&u!==0)U(e,"bad indentation of a sequence entry");else if(e.lineIndent<t)break}return a?(e.tag=r,e.anchor=i,e.kind="sequence",e.result=o,!0):!1}function $f(e,t,n){var r,i,o,s,a=e.tag,u=e.anchor,l={},c={},p=null,f=null,m=null,h=!1,y=!1,k;for(e.anchor!==null&&(e.anchorMap[e.anchor]=l),k=e.input.charCodeAt(e.position);k!==0;){if(r=e.input.charCodeAt(e.position+1),o=e.line,s=e.position,(k===63||k===58)&&de(r))k===63?(h&&(ct(e,l,c,p,f,null),p=f=m=null),y=!0,h=!0,i=!0):h?(h=!1,i=!0):U(e,"incomplete explicit mapping pair; a key node is missed; or followed by a non-tabulated empty line"),e.position+=1,k=r;else if(lt(e,n,ns,!1,!0))if(e.line===o){for(k=e.input.charCodeAt(e.position);We(k);)k=e.input.charCodeAt(++e.position);if(k===58)k=e.input.charCodeAt(++e.position),de(k)||U(e,"a whitespace character is expected after the key-value separator within a block mapping"),h&&(ct(e,l,c,p,f,null),p=f=m=null),y=!0,h=!1,i=!1,p=e.tag,f=e.result;else if(y)U(e,"can not read an implicit mapping pair; a colon is missed");else return e.tag=a,e.anchor=u,!0}else if(y)U(e,"can not read a block mapping entry; a multiline key may not be an implicit key");else return e.tag=a,e.anchor=u,!0;else break;if((e.line===o||e.lineIndent>t)&&(lt(e,t,nn,!0,i)&&(h?f=e.result:m=e.result),h||(ct(e,l,c,p,f,m,o,s),p=f=m=null),ne(e,!0,-1),k=e.input.charCodeAt(e.position)),e.lineIndent>t&&k!==0)U(e,"bad indentation of a mapping entry");else if(e.lineIndent<t)break}return h&&ct(e,l,c,p,f,null),y&&(e.tag=a,e.anchor=u,e.kind="mapping",e.result=l),y}function qf(e){var t,n=!1,r=!1,i,o,s;if(s=e.input.charCodeAt(e.position),s!==33)return!1;if(e.tag!==null&&U(e,"duplication of a tag property"),s=e.input.charCodeAt(++e.position),s===60?(n=!0,s=e.input.charCodeAt(++e.position)):s===33?(r=!0,i="!!",s=e.input.charCodeAt(++e.position)):i="!",t=e.position,n){do s=e.input.charCodeAt(++e.position);while(s!==0&&s!==62);e.position<e.length?(o=e.input.slice(t,e.position),s=e.input.charCodeAt(++e.position)):U(e,"unexpected end of the stream within a verbatim tag")}else{for(;s!==0&&!de(s);)s===33&&(r?U(e,"tag suffix cannot contain exclamation marks"):(i=e.input.slice(t-1,e.position+1),is.test(i)||U(e,"named tag handle cannot contain such characters"),r=!0,t=e.position+1)),s=e.input.charCodeAt(++e.position);o=e.input.slice(t,e.position),Of.test(o)&&U(e,"tag suffix cannot contain flow indicator characters")}return o&&!os.test(o)&&U(e,"tag name cannot contain such characters: "+o),n?e.tag=o:De.call(e.tagMap,i)?e.tag=e.tagMap[i]+o:i==="!"?e.tag="!"+o:i==="!!"?e.tag="tag:yaml.org,2002:"+o:U(e,'undeclared tag handle "'+i+'"'),!0}function Uf(e){var t,n;if(n=e.input.charCodeAt(e.position),n!==38)return!1;for(e.anchor!==null&&U(e,"duplication of an anchor property"),n=e.input.charCodeAt(++e.position),t=e.position;n!==0&&!de(n)&&!ut(n);)n=e.input.charCodeAt(++e.position);return e.position===t&&U(e,"name of an anchor node must contain at least one character"),e.anchor=e.input.slice(t,e.position),!0}function Bf(e){var t,n,r;if(r=e.input.charCodeAt(e.position),r!==42)return!1;for(r=e.input.charCodeAt(++e.position),t=e.position;r!==0&&!de(r)&&!ut(r);)r=e.input.charCodeAt(++e.position);return e.position===t&&U(e,"name of an alias node must contain at least one character"),n=e.input.slice(t,e.position),De.call(e.anchorMap,n)||U(e,'unidentified alias "'+n+'"'),e.result=e.anchorMap[n],ne(e,!0,-1),!0}function lt(e,t,n,r,i){var o,s,a,u=1,l=!1,c=!1,p,f,m,h,y;if(e.listener!==null&&e.listener("open",e),e.tag=null,e.anchor=null,e.kind=null,e.result=null,o=s=a=nn===n||rs===n,r&&ne(e,!0,-1)&&(l=!0,e.lineIndent>t?u=1:e.lineIndent===t?u=0:e.lineIndent<t&&(u=-1)),u===1)for(;qf(e)||Uf(e);)ne(e,!0,-1)?(l=!0,a=o,e.lineIndent>t?u=1:e.lineIndent===t?u=0:e.lineIndent<t&&(u=-1)):a=!1;if(a&&(a=l||i),(u===1||nn===n)&&(tn===n||ns===n?h=t:h=t+1,y=e.position-e.lineStart,u===1?a&&(Zo(e,y)||$f(e,y,h))||Hf(e,h)?c=!0:(s&&jf(e,h)||Mf(e,h)||Df(e,h)?c=!0:Bf(e)?(c=!0,(e.tag!==null||e.anchor!==null)&&U(e,"alias node should not have any properties")):Ff(e,h,tn===n)&&(c=!0,e.tag===null&&(e.tag="?")),e.anchor!==null&&(e.anchorMap[e.anchor]=e.result)):u===0&&(c=a&&Zo(e,y))),e.tag!==null&&e.tag!=="!")if(e.tag==="?"){for(e.result!==null&&e.kind!=="scalar"&&U(e,'unacceptable node kind for !<?> tag; it should be "scalar", not "'+e.kind+'"'),p=0,f=e.implicitTypes.length;p<f;p+=1)if(m=e.implicitTypes[p],m.resolve(e.result)){e.result=m.construct(e.result),e.tag=m.tag,e.anchor!==null&&(e.anchorMap[e.anchor]=e.result);break}}else De.call(e.typeMap[e.kind||"fallback"],e.tag)?(m=e.typeMap[e.kind||"fallback"][e.tag],e.result!==null&&m.kind!==e.kind&&U(e,"unacceptable node kind for !<"+e.tag+'> tag; it should be "'+m.kind+'", not "'+e.kind+'"'),m.resolve(e.result)?(e.result=m.construct(e.result),e.anchor!==null&&(e.anchorMap[e.anchor]=e.result)):U(e,"cannot resolve a node with !<"+e.tag+"> explicit tag")):U(e,"unknown tag !<"+e.tag+">");return e.listener!==null&&e.listener("close",e),e.tag!==null||e.anchor!==null||c}function Gf(e){var t=e.position,n,r,i,o=!1,s;for(e.version=null,e.checkLineBreaks=e.legacy,e.tagMap={},e.anchorMap={};(s=e.input.charCodeAt(e.position))!==0&&(ne(e,!0,-1),s=e.input.charCodeAt(e.position),!(e.lineIndent>0||s!==37));){for(o=!0,s=e.input.charCodeAt(++e.position),n=e.position;s!==0&&!de(s);)s=e.input.charCodeAt(++e.position);for(r=e.input.slice(n,e.position),i=[],r.length<1&&U(e,"directive name must not be less than one character in length");s!==0;){for(;We(s);)s=e.input.charCodeAt(++e.position);if(s===35){do s=e.input.charCodeAt(++e.position);while(s!==0&&!Ee(s));break}if(Ee(s))break;for(n=e.position;s!==0&&!de(s);)s=e.input.charCodeAt(++e.position);i.push(e.input.slice(n,e.position))}s!==0&&sr(e),De.call(Qo,r)?Qo[r](e,r,i):rn(e,'unknown document directive "'+r+'"')}if(ne(e,!0,-1),e.lineIndent===0&&e.input.charCodeAt(e.position)===45&&e.input.charCodeAt(e.position+1)===45&&e.input.charCodeAt(e.position+2)===45?(e.position+=3,ne(e,!0,-1)):o&&U(e,"directives end mark is expected"),lt(e,e.lineIndent-1,nn,!1,!0),ne(e,!0,-1),e.checkLineBreaks&&Rf.test(e.input.slice(t,e.position))&&rn(e,"non-ASCII line breaks are interpreted as content"),e.documents.push(e.result),e.position===e.lineStart&&on(e)){e.input.charCodeAt(e.position)===46&&(e.position+=3,ne(e,!0,-1));return}if(e.position<e.length-1)U(e,"end of the stream or a document separator is expected");else return}function ls(e,t){e=String(e),t=t||{},e.length!==0&&(e.charCodeAt(e.length-1)!==10&&e.charCodeAt(e.length-1)!==13&&(e+=`
`),e.charCodeAt(0)===65279&&(e=e.slice(1)));var n=new Nf(e,t),r=e.indexOf("\0");for(r!==-1&&(n.position=r,U(n,"null byte is not allowed in input")),n.input+="\0";n.input.charCodeAt(n.position)===32;)n.lineIndent+=1,n.position+=1;for(;n.position<n.length-1;)Gf(n);return n.documents}function fs(e,t,n){t!==null&&typeof t=="object"&&typeof n>"u"&&(n=t,t=null);var r=ls(e,n);if(typeof t!="function")return r;for(var i=0,o=r.length;i<o;i+=1)t(r[i])}function ps(e,t){var n=ls(e,t);if(n.length!==0){if(n.length===1)return n[0];throw new es("expected a single document in the stream, but found more")}}function Wf(e,t,n){return typeof t=="object"&&t!==null&&typeof n>"u"&&(n=t,t=null),fs(e,t,Re.extend({schema:ts},n))}function Yf(e,t){return ps(e,Re.extend({schema:ts},t))}Rt.exports.loadAll=fs;Rt.exports.load=ps;Rt.exports.safeLoadAll=Wf;Rt.exports.safeLoad=Yf});var Ms=M((wm,fr)=>{"use strict";var Ct=qe(),Pt=ot(),Vf=Tt(),Kf=at(),ws=Object.prototype.toString,As=Object.prototype.hasOwnProperty,Jf=9,Ot=10,zf=13,Qf=32,Xf=33,Zf=34,Ss=35,ep=37,tp=38,np=39,rp=42,Es=44,ip=45,ks=58,op=61,sp=62,ap=63,up=64,_s=91,Ts=93,cp=96,Rs=123,lp=124,Os=125,ce={};ce[0]="\\0";ce[7]="\\a";ce[8]="\\b";ce[9]="\\t";ce[10]="\\n";ce[11]="\\v";ce[12]="\\f";ce[13]="\\r";ce[27]="\\e";ce[34]='\\"';ce[92]="\\\\";ce[133]="\\N";ce[160]="\\_";ce[8232]="\\L";ce[8233]="\\P";var fp=["y","Y","yes","Yes","YES","on","On","ON","n","N","no","No","NO","off","Off","OFF"];function pp(e,t){var n,r,i,o,s,a,u;if(t===null)return{};for(n={},r=Object.keys(t),i=0,o=r.length;i<o;i+=1)s=r[i],a=String(t[s]),s.slice(0,2)==="!!"&&(s="tag:yaml.org,2002:"+s.slice(2)),u=e.compiledTypeMap.fallback[s],u&&As.call(u.styleAliases,a)&&(a=u.styleAliases[a]),n[s]=a;return n}function ds(e){var t,n,r;if(t=e.toString(16).toUpperCase(),e<=255)n="x",r=2;else if(e<=65535)n="u",r=4;else if(e<=4294967295)n="U",r=8;else throw new Pt("code point within a string may not be greater than 0xFFFFFFFF");return"\\"+n+Ct.repeat("0",r-t.length)+t}function hp(e){this.schema=e.schema||Vf,this.indent=Math.max(1,e.indent||2),this.noArrayIndent=e.noArrayIndent||!1,this.skipInvalid=e.skipInvalid||!1,this.flowLevel=Ct.isNothing(e.flowLevel)?-1:e.flowLevel,this.styleMap=pp(this.schema,e.styles||null),this.sortKeys=e.sortKeys||!1,this.lineWidth=e.lineWidth||80,this.noRefs=e.noRefs||!1,this.noCompatMode=e.noCompatMode||!1,this.condenseFlow=e.condenseFlow||!1,this.implicitTypes=this.schema.compiledImplicit,this.explicitTypes=this.schema.compiledExplicit,this.tag=null,this.result="",this.duplicates=[],this.usedDuplicates=null}function gs(e,t){for(var n=Ct.repeat(" ",t),r=0,i=-1,o="",s,a=e.length;r<a;)i=e.indexOf(`
`,r),i===-1?(s=e.slice(r),r=a):(s=e.slice(r,i+1),r=i+1),s.length&&s!==`
`&&(o+=n),o+=s;return o}function ur(e,t){return`
`+Ct.repeat(" ",e.indent*t)}function dp(e,t){var n,r,i;for(n=0,r=e.implicitTypes.length;n<r;n+=1)if(i=e.implicitTypes[n],i.resolve(t))return!0;return!1}function lr(e){return e===Qf||e===Jf}function ft(e){return 32<=e&&e<=126||161<=e&&e<=55295&&e!==8232&&e!==8233||57344<=e&&e<=65533&&e!==65279||65536<=e&&e<=1114111}function gp(e){return ft(e)&&!lr(e)&&e!==65279&&e!==zf&&e!==Ot}function ms(e,t){return ft(e)&&e!==65279&&e!==Es&&e!==_s&&e!==Ts&&e!==Rs&&e!==Os&&e!==ks&&(e!==Ss||t&&gp(t))}function mp(e){return ft(e)&&e!==65279&&!lr(e)&&e!==ip&&e!==ap&&e!==ks&&e!==Es&&e!==_s&&e!==Ts&&e!==Rs&&e!==Os&&e!==Ss&&e!==tp&&e!==rp&&e!==Xf&&e!==lp&&e!==op&&e!==sp&&e!==np&&e!==Zf&&e!==ep&&e!==up&&e!==cp}function Cs(e){var t=/^\n* /;return t.test(e)}var Ps=1,Ls=2,Is=3,Ns=4,sn=5;function yp(e,t,n,r,i){var o,s,a,u=!1,l=!1,c=r!==-1,p=-1,f=mp(e.charCodeAt(0))&&!lr(e.charCodeAt(e.length-1));if(t)for(o=0;o<e.length;o++){if(s=e.charCodeAt(o),!ft(s))return sn;a=o>0?e.charCodeAt(o-1):null,f=f&&ms(s,a)}else{for(o=0;o<e.length;o++){if(s=e.charCodeAt(o),s===Ot)u=!0,c&&(l=l||o-p-1>r&&e[p+1]!==" ",p=o);else if(!ft(s))return sn;a=o>0?e.charCodeAt(o-1):null,f=f&&ms(s,a)}l=l||c&&o-p-1>r&&e[p+1]!==" "}return!u&&!l?f&&!i(e)?Ps:Ls:n>9&&Cs(e)?sn:l?Ns:Is}function xp(e,t,n,r){e.dump=(function(){if(t.length===0)return"''";if(!e.noCompatMode&&fp.indexOf(t)!==-1)return"'"+t+"'";var i=e.indent*Math.max(1,n),o=e.lineWidth===-1?-1:Math.max(Math.min(e.lineWidth,40),e.lineWidth-i),s=r||e.flowLevel>-1&&n>=e.flowLevel;function a(u){return dp(e,u)}switch(yp(t,s,e.indent,o,a)){case Ps:return t;case Ls:return"'"+t.replace(/'/g,"''")+"'";case Is:return"|"+ys(t,e.indent)+xs(gs(t,i));case Ns:return">"+ys(t,e.indent)+xs(gs(vp(t,o),i));case sn:return'"'+bp(t,o)+'"';default:throw new Pt("impossible error: invalid scalar style")}})()}function ys(e,t){var n=Cs(e)?String(t):"",r=e[e.length-1]===`
`,i=r&&(e[e.length-2]===`
`||e===`
`),o=i?"+":r?"":"-";return n+o+`
`}function xs(e){return e[e.length-1]===`
`?e.slice(0,-1):e}function vp(e,t){for(var n=/(\n+)([^\n]*)/g,r=(function(){var l=e.indexOf(`
`);return l=l!==-1?l:e.length,n.lastIndex=l,vs(e.slice(0,l),t)})(),i=e[0]===`
`||e[0]===" ",o,s;s=n.exec(e);){var a=s[1],u=s[2];o=u[0]===" ",r+=a+(!i&&!o&&u!==""?`
`:"")+vs(u,t),i=o}return r}function vs(e,t){if(e===""||e[0]===" ")return e;for(var n=/ [^ ]/g,r,i=0,o,s=0,a=0,u="";r=n.exec(e);)a=r.index,a-i>t&&(o=s>i?s:a,u+=`
`+e.slice(i,o),i=o+1),s=a;return u+=`
`,e.length-i>t&&s>i?u+=e.slice(i,s)+`
`+e.slice(s+1):u+=e.slice(i),u.slice(1)}function bp(e){for(var t="",n,r,i,o=0;o<e.length;o++){if(n=e.charCodeAt(o),n>=55296&&n<=56319&&(r=e.charCodeAt(o+1),r>=56320&&r<=57343)){t+=ds((n-55296)*1024+r-56320+65536),o++;continue}i=ce[n],t+=!i&&ft(n)?e[o]:i||ds(n)}return t}function wp(e,t,n){var r="",i=e.tag,o,s;for(o=0,s=n.length;o<s;o+=1)Ye(e,t,n[o],!1,!1)&&(o!==0&&(r+=","+(e.condenseFlow?"":" ")),r+=e.dump);e.tag=i,e.dump="["+r+"]"}function Ap(e,t,n,r){var i="",o=e.tag,s,a;for(s=0,a=n.length;s<a;s+=1)Ye(e,t+1,n[s],!0,!0)&&((!r||s!==0)&&(i+=ur(e,t)),e.dump&&Ot===e.dump.charCodeAt(0)?i+="-":i+="- ",i+=e.dump);e.tag=o,e.dump=i||"[]"}function Sp(e,t,n){var r="",i=e.tag,o=Object.keys(n),s,a,u,l,c;for(s=0,a=o.length;s<a;s+=1)c="",s!==0&&(c+=", "),e.condenseFlow&&(c+='"'),u=o[s],l=n[u],Ye(e,t,u,!1,!1)&&(e.dump.length>1024&&(c+="? "),c+=e.dump+(e.condenseFlow?'"':"")+":"+(e.condenseFlow?"":" "),Ye(e,t,l,!1,!1)&&(c+=e.dump,r+=c));e.tag=i,e.dump="{"+r+"}"}function Ep(e,t,n,r){var i="",o=e.tag,s=Object.keys(n),a,u,l,c,p,f;if(e.sortKeys===!0)s.sort();else if(typeof e.sortKeys=="function")s.sort(e.sortKeys);else if(e.sortKeys)throw new Pt("sortKeys must be a boolean or a function");for(a=0,u=s.length;a<u;a+=1)f="",(!r||a!==0)&&(f+=ur(e,t)),l=s[a],c=n[l],Ye(e,t+1,l,!0,!0,!0)&&(p=e.tag!==null&&e.tag!=="?"||e.dump&&e.dump.length>1024,p&&(e.dump&&Ot===e.dump.charCodeAt(0)?f+="?":f+="? "),f+=e.dump,p&&(f+=ur(e,t)),Ye(e,t+1,c,!0,p)&&(e.dump&&Ot===e.dump.charCodeAt(0)?f+=":":f+=": ",f+=e.dump,i+=f));e.tag=o,e.dump=i||"{}"}function bs(e,t,n){var r,i,o,s,a,u;for(i=n?e.explicitTypes:e.implicitTypes,o=0,s=i.length;o<s;o+=1)if(a=i[o],(a.instanceOf||a.predicate)&&(!a.instanceOf||typeof t=="object"&&t instanceof a.instanceOf)&&(!a.predicate||a.predicate(t))){if(e.tag=n?a.tag:"?",a.represent){if(u=e.styleMap[a.tag]||a.defaultStyle,ws.call(a.represent)==="[object Function]")r=a.represent(t,u);else if(As.call(a.represent,u))r=a.represent[u](t,u);else throw new Pt("!<"+a.tag+'> tag resolver accepts not "'+u+'" style');e.dump=r}return!0}return!1}function Ye(e,t,n,r,i,o){e.tag=null,e.dump=n,bs(e,n,!1)||bs(e,n,!0);var s=ws.call(e.dump);r&&(r=e.flowLevel<0||e.flowLevel>t);var a=s==="[object Object]"||s==="[object Array]",u,l;if(a&&(u=e.duplicates.indexOf(n),l=u!==-1),(e.tag!==null&&e.tag!=="?"||l||e.indent!==2&&t>0)&&(i=!1),l&&e.usedDuplicates[u])e.dump="*ref_"+u;else{if(a&&l&&!e.usedDuplicates[u]&&(e.usedDuplicates[u]=!0),s==="[object Object]")r&&Object.keys(e.dump).length!==0?(Ep(e,t,e.dump,i),l&&(e.dump="&ref_"+u+e.dump)):(Sp(e,t,e.dump),l&&(e.dump="&ref_"+u+" "+e.dump));else if(s==="[object Array]"){var c=e.noArrayIndent&&t>0?t-1:t;r&&e.dump.length!==0?(Ap(e,c,e.dump,i),l&&(e.dump="&ref_"+u+e.dump)):(wp(e,c,e.dump),l&&(e.dump="&ref_"+u+" "+e.dump))}else if(s==="[object String]")e.tag!=="?"&&xp(e,e.dump,t,o);else{if(e.skipInvalid)return!1;throw new Pt("unacceptable kind of an object to dump "+s)}e.tag!==null&&e.tag!=="?"&&(e.dump="!<"+e.tag+"> "+e.dump)}return!0}function kp(e,t){var n=[],r=[],i,o;for(cr(e,n,r),i=0,o=r.length;i<o;i+=1)t.duplicates.push(n[r[i]]);t.usedDuplicates=new Array(o)}function cr(e,t,n){var r,i,o;if(e!==null&&typeof e=="object")if(i=t.indexOf(e),i!==-1)n.indexOf(i)===-1&&n.push(i);else if(t.push(e),Array.isArray(e))for(i=0,o=e.length;i<o;i+=1)cr(e[i],t,n);else for(r=Object.keys(e),i=0,o=r.length;i<o;i+=1)cr(e[r[i]],t,n)}function Fs(e,t){t=t||{};var n=new hp(t);return n.noRefs||kp(e,n),Ye(n,0,e,!0,!0)?n.dump+`
`:""}function _p(e,t){return Fs(e,Ct.extend({schema:Kf},t))}fr.exports.dump=Fs;fr.exports.safeDump=_p});var Hs=M((Am,ee)=>{"use strict";var an=hs(),Ds=Ms();function un(e){return function(){throw new Error("Function "+e+" is deprecated and cannot be used.")}}ee.exports.Type=se();ee.exports.Schema=Ue();ee.exports.FAILSAFE_SCHEMA=Zt();ee.exports.JSON_SCHEMA=nr();ee.exports.CORE_SCHEMA=rr();ee.exports.DEFAULT_SAFE_SCHEMA=at();ee.exports.DEFAULT_FULL_SCHEMA=Tt();ee.exports.load=an.load;ee.exports.loadAll=an.loadAll;ee.exports.safeLoad=an.safeLoad;ee.exports.safeLoadAll=an.safeLoadAll;ee.exports.dump=Ds.dump;ee.exports.safeDump=Ds.safeDump;ee.exports.YAMLException=ot();ee.exports.MINIMAL_SCHEMA=Zt();ee.exports.SAFE_SCHEMA=at();ee.exports.DEFAULT_SCHEMA=Tt();ee.exports.scan=un("scan");ee.exports.parse=un("parse");ee.exports.compose=un("compose");ee.exports.addConstructor=un("addConstructor")});var $s=M((Sm,js)=>{"use strict";var Tp=Hs();js.exports=Tp});var Bs=M((Em,pr)=>{"use strict";var qs=Bi(),Rp=Yi(),Op=Ki(),Cp=$s(),Us=e=>Cp.safeLoad(Op(e));pr.exports=e=>Rp(qs.readFile)(e,"utf8").then(t=>Us(t));pr.exports.sync=e=>Us(qs.readFileSync(e,"utf8"))});var Ys=M((km,Ws)=>{"use strict";var hr=require("path"),Gs=zn(),Pp=Bs();Ws.exports=async function(e){let t=hr.join(e,"node_modules");if(await Gs(hr.join(t,".yarn-integrity")))return{name:"yarn"};try{let i=await Pp(hr.join(t,".modules.yaml"));return Lp(i.packageManager)}catch(i){if(i.code!=="ENOENT")throw i}return await Gs(t)?{name:"npm"}:null};function Lp(e){if(e[0]==="@"){let r=e.substr(1).split("@");return{name:`@${r[0]}`,version:r[1]}}let t=e.split("@");return{name:t[0],version:t[1]}}});var cn=M(be=>{"use strict";be.isInteger=e=>typeof e=="number"?Number.isInteger(e):typeof e=="string"&&e.trim()!==""?Number.isInteger(Number(e)):!1;be.find=(e,t)=>e.nodes.find(n=>n.type===t);be.exceedsLimit=(e,t,n=1,r)=>r===!1||!be.isInteger(e)||!be.isInteger(t)?!1:(Number(t)-Number(e))/Number(n)>=r;be.escapeNode=(e,t=0,n)=>{let r=e.nodes[t];r&&(n&&r.type===n||r.type==="open"||r.type==="close")&&r.escaped!==!0&&(r.value="\\"+r.value,r.escaped=!0)};be.encloseBrace=e=>e.type!=="brace"?!1:e.commas>>0+e.ranges>>0===0?(e.invalid=!0,!0):!1;be.isInvalidBrace=e=>e.type!=="brace"?!1:e.invalid===!0||e.dollar?!0:e.commas>>0+e.ranges>>0===0||e.open!==!0||e.close!==!0?(e.invalid=!0,!0):!1;be.isOpenOrClose=e=>e.type==="open"||e.type==="close"?!0:e.open===!0||e.close===!0;be.reduce=e=>e.reduce((t,n)=>(n.type==="text"&&t.push(n.value),n.type==="range"&&(n.type="text"),t),[]);be.flatten=(...e)=>{let t=[],n=r=>{for(let i=0;i<r.length;i++){let o=r[i];if(Array.isArray(o)){n(o);continue}o!==void 0&&t.push(o)}return t};return n(e),t}});var ln=M((Tm,Ks)=>{"use strict";var Vs=cn();Ks.exports=(e,t={})=>{let n=(r,i={})=>{let o=t.escapeInvalid&&Vs.isInvalidBrace(i),s=r.invalid===!0&&t.escapeInvalid===!0,a="";if(r.value)return(o||s)&&Vs.isOpenOrClose(r)?"\\"+r.value:r.value;if(r.value)return r.value;if(r.nodes)for(let u of r.nodes)a+=n(u);return a};return n(e)}});var zs=M((Rm,Js)=>{"use strict";Js.exports=function(e){return typeof e=="number"?e-e===0:typeof e=="string"&&e.trim()!==""?Number.isFinite?Number.isFinite(+e):isFinite(+e):!1}});var oa=M((Om,ia)=>{"use strict";var Qs=zs(),Ve=(e,t,n)=>{if(Qs(e)===!1)throw new TypeError("toRegexRange: expected the first argument to be a number");if(t===void 0||e===t)return String(e);if(Qs(t)===!1)throw new TypeError("toRegexRange: expected the second argument to be a number.");let r={relaxZeros:!0,...n};typeof r.strictZeros=="boolean"&&(r.relaxZeros=r.strictZeros===!1);let i=String(r.relaxZeros),o=String(r.shorthand),s=String(r.capture),a=String(r.wrap),u=e+":"+t+"="+i+o+s+a;if(Ve.cache.hasOwnProperty(u))return Ve.cache[u].result;let l=Math.min(e,t),c=Math.max(e,t);if(Math.abs(l-c)===1){let y=e+"|"+t;return r.capture?`(${y})`:r.wrap===!1?y:`(?:${y})`}let p=ra(e)||ra(t),f={min:e,max:t,a:l,b:c},m=[],h=[];if(p&&(f.isPadded=p,f.maxLen=String(f.max).length),l<0){let y=c<0?Math.abs(c):1;h=Xs(y,Math.abs(l),f,r),l=f.a=0}return c>=0&&(m=Xs(l,c,f,r)),f.negatives=h,f.positives=m,f.result=Ip(h,m,r),r.capture===!0?f.result=`(${f.result})`:r.wrap!==!1&&m.length+h.length>1&&(f.result=`(?:${f.result})`),Ve.cache[u]=f,f.result};function Ip(e,t,n){let r=dr(e,t,"-",!1,n)||[],i=dr(t,e,"",!1,n)||[],o=dr(e,t,"-?",!0,n)||[];return r.concat(o).concat(i).join("|")}function Np(e,t){let n=1,r=1,i=ea(e,n),o=new Set([t]);for(;e<=i&&i<=t;)o.add(i),n+=1,i=ea(e,n);for(i=ta(t+1,r)-1;e<i&&i<=t;)o.add(i),r+=1,i=ta(t+1,r)-1;return o=[...o],o.sort(Dp),o}function Fp(e,t,n){if(e===t)return{pattern:e,count:[],digits:0};let r=Mp(e,t),i=r.length,o="",s=0;for(let a=0;a<i;a++){let[u,l]=r[a];u===l?o+=u:u!=="0"||l!=="9"?o+=Hp(u,l,n):s++}return s&&(o+=n.shorthand===!0?"\\d":"[0-9]"),{pattern:o,count:[s],digits:i}}function Xs(e,t,n,r){let i=Np(e,t),o=[],s=e,a;for(let u=0;u<i.length;u++){let l=i[u],c=Fp(String(s),String(l),r),p="";if(!n.isPadded&&a&&a.pattern===c.pattern){a.count.length>1&&a.count.pop(),a.count.push(c.count[0]),a.string=a.pattern+na(a.count),s=l+1;continue}n.isPadded&&(p=jp(l,n,r)),c.string=p+c.pattern+na(c.count),o.push(c),s=l+1,a=c}return o}function dr(e,t,n,r,i){let o=[];for(let s of e){let{string:a}=s;!r&&!Zs(t,"string",a)&&o.push(n+a),r&&Zs(t,"string",a)&&o.push(n+a)}return o}function Mp(e,t){let n=[];for(let r=0;r<e.length;r++)n.push([e[r],t[r]]);return n}function Dp(e,t){return e>t?1:t>e?-1:0}function Zs(e,t,n){return e.some(r=>r[t]===n)}function ea(e,t){return Number(String(e).slice(0,-t)+"9".repeat(t))}function ta(e,t){return e-e%Math.pow(10,t)}function na(e){let[t=0,n=""]=e;return n||t>1?`{${t+(n?","+n:"")}}`:""}function Hp(e,t,n){return`[${e}${t-e===1?"":"-"}${t}]`}function ra(e){return/^-?(0+)\d/.test(e)}function jp(e,t,n){if(!t.isPadded)return e;let r=Math.abs(t.maxLen-String(e).length),i=n.relaxZeros!==!1;switch(r){case 0:return"";case 1:return i?"0?":"0";case 2:return i?"0{0,2}":"00";default:return i?`0{0,${r}}`:`0{${r}}`}}Ve.cache={};Ve.clearCache=()=>Ve.cache={};ia.exports=Ve});var yr=M((Cm,pa)=>{"use strict";var $p=require("util"),aa=oa(),sa=e=>e!==null&&typeof e=="object"&&!Array.isArray(e),qp=e=>t=>e===!0?Number(t):String(t),gr=e=>typeof e=="number"||typeof e=="string"&&e!=="",Lt=e=>Number.isInteger(+e),mr=e=>{let t=`${e}`,n=-1;if(t[0]==="-"&&(t=t.slice(1)),t==="0")return!1;for(;t[++n]==="0";);return n>0},Up=(e,t,n)=>typeof e=="string"||typeof t=="string"?!0:n.stringify===!0,Bp=(e,t,n)=>{if(t>0){let r=e[0]==="-"?"-":"";r&&(e=e.slice(1)),e=r+e.padStart(r?t-1:t,"0")}return n===!1?String(e):e},pn=(e,t)=>{let n=e[0]==="-"?"-":"";for(n&&(e=e.slice(1),t--);e.length<t;)e="0"+e;return n?"-"+e:e},Gp=(e,t,n)=>{e.negatives.sort((a,u)=>a<u?-1:a>u?1:0),e.positives.sort((a,u)=>a<u?-1:a>u?1:0);let r=t.capture?"":"?:",i="",o="",s;return e.positives.length&&(i=e.positives.map(a=>pn(String(a),n)).join("|")),e.negatives.length&&(o=`-(${r}${e.negatives.map(a=>pn(String(a),n)).join("|")})`),i&&o?s=`${i}|${o}`:s=i||o,t.wrap?`(${r}${s})`:s},ua=(e,t,n,r)=>{if(n)return aa(e,t,{wrap:!1,...r});let i=String.fromCharCode(e);if(e===t)return i;let o=String.fromCharCode(t);return`[${i}-${o}]`},ca=(e,t,n)=>{if(Array.isArray(e)){let r=n.wrap===!0,i=n.capture?"":"?:";return r?`(${i}${e.join("|")})`:e.join("|")}return aa(e,t,n)},la=(...e)=>new RangeError("Invalid range arguments: "+$p.inspect(...e)),fa=(e,t,n)=>{if(n.strictRanges===!0)throw la([e,t]);return[]},Wp=(e,t)=>{if(t.strictRanges===!0)throw new TypeError(`Expected step "${e}" to be a number`);return[]},Yp=(e,t,n=1,r={})=>{let i=Number(e),o=Number(t);if(!Number.isInteger(i)||!Number.isInteger(o)){if(r.strictRanges===!0)throw la([e,t]);return[]}i===0&&(i=0),o===0&&(o=0);let s=i>o,a=String(e),u=String(t),l=String(n);n=Math.max(Math.abs(n),1);let c=mr(a)||mr(u)||mr(l),p=c?Math.max(a.length,u.length,l.length):0,f=c===!1&&Up(e,t,r)===!1,m=r.transform||qp(f);if(r.toRegex&&n===1)return ua(pn(e,p),pn(t,p),!0,r);let h={negatives:[],positives:[]},y=R=>h[R<0?"negatives":"positives"].push(Math.abs(R)),k=[],C=0;for(;s?i>=o:i<=o;)r.toRegex===!0&&n>1?y(i):k.push(Bp(m(i,C),p,f)),i=s?i-n:i+n,C++;return r.toRegex===!0?n>1?Gp(h,r,p):ca(k,null,{wrap:!1,...r}):k},Vp=(e,t,n=1,r={})=>{if(!Lt(e)&&e.length>1||!Lt(t)&&t.length>1)return fa(e,t,r);let i=r.transform||(f=>String.fromCharCode(f)),o=`${e}`.charCodeAt(0),s=`${t}`.charCodeAt(0),a=o>s,u=Math.min(o,s),l=Math.max(o,s);if(r.toRegex&&n===1)return ua(u,l,!1,r);let c=[],p=0;for(;a?o>=s:o<=s;)c.push(i(o,p)),o=a?o-n:o+n,p++;return r.toRegex===!0?ca(c,null,{wrap:!1,options:r}):c},fn=(e,t,n,r={})=>{if(t==null&&gr(e))return[e];if(!gr(e)||!gr(t))return fa(e,t,r);if(typeof n=="function")return fn(e,t,1,{transform:n});if(sa(n))return fn(e,t,0,n);let i={...r};return i.capture===!0&&(i.wrap=!0),n=n||i.step||1,Lt(n)?Lt(e)&&Lt(t)?Yp(e,t,n,i):Vp(e,t,Math.max(Math.abs(n),1),i):n!=null&&!sa(n)?Wp(n,i):fn(e,t,1,n)};pa.exports=fn});var ga=M((Pm,da)=>{"use strict";var Kp=yr(),ha=cn(),Jp=(e,t={})=>{let n=(r,i={})=>{let o=ha.isInvalidBrace(i),s=r.invalid===!0&&t.escapeInvalid===!0,a=o===!0||s===!0,u=t.escapeInvalid===!0?"\\":"",l="";if(r.isOpen===!0)return u+r.value;if(r.isClose===!0)return console.log("node.isClose",u,r.value),u+r.value;if(r.type==="open")return a?u+r.value:"(";if(r.type==="close")return a?u+r.value:")";if(r.type==="comma")return r.prev.type==="comma"?"":a?r.value:"|";if(r.value)return r.value;if(r.nodes&&r.ranges>0){let c=ha.reduce(r.nodes),p=Kp(...c,{...t,wrap:!1,toRegex:!0,strictZeros:!0});if(p.length!==0)return c.length>1&&p.length>1?`(${p})`:p}if(r.nodes)for(let c of r.nodes)l+=n(c,r);return l};return n(e)};da.exports=Jp});var xa=M((Lm,ya)=>{"use strict";var zp=yr(),ma=ln(),pt=cn(),Ke=(e="",t="",n=!1)=>{let r=[];if(e=[].concat(e),t=[].concat(t),!t.length)return e;if(!e.length)return n?pt.flatten(t).map(i=>`{${i}}`):t;for(let i of e)if(Array.isArray(i))for(let o of i)r.push(Ke(o,t,n));else for(let o of t)n===!0&&typeof o=="string"&&(o=`{${o}}`),r.push(Array.isArray(o)?Ke(i,o,n):i+o);return pt.flatten(r)},Qp=(e,t={})=>{let n=t.rangeLimit===void 0?1e3:t.rangeLimit,r=(i,o={})=>{i.queue=[];let s=o,a=o.queue;for(;s.type!=="brace"&&s.type!=="root"&&s.parent;)s=s.parent,a=s.queue;if(i.invalid||i.dollar){a.push(Ke(a.pop(),ma(i,t)));return}if(i.type==="brace"&&i.invalid!==!0&&i.nodes.length===2){a.push(Ke(a.pop(),["{}"]));return}if(i.nodes&&i.ranges>0){let p=pt.reduce(i.nodes);if(pt.exceedsLimit(...p,t.step,n))throw new RangeError("expanded array length exceeds range limit. Use options.rangeLimit to increase or disable the limit.");let f=zp(...p,t);f.length===0&&(f=ma(i,t)),a.push(Ke(a.pop(),f)),i.nodes=[];return}let u=pt.encloseBrace(i),l=i.queue,c=i;for(;c.type!=="brace"&&c.type!=="root"&&c.parent;)c=c.parent,l=c.queue;for(let p=0;p<i.nodes.length;p++){let f=i.nodes[p];if(f.type==="comma"&&i.type==="brace"){p===1&&l.push(""),l.push("");continue}if(f.type==="close"){a.push(Ke(a.pop(),l,u));continue}if(f.value&&f.type!=="open"){l.push(Ke(l.pop(),f.value));continue}f.nodes&&r(f,i)}return l};return pt.flatten(r(e))};ya.exports=Qp});var ba=M((Im,va)=>{"use strict";va.exports={MAX_LENGTH:1e4,CHAR_0:"0",CHAR_9:"9",CHAR_UPPERCASE_A:"A",CHAR_LOWERCASE_A:"a",CHAR_UPPERCASE_Z:"Z",CHAR_LOWERCASE_Z:"z",CHAR_LEFT_PARENTHESES:"(",CHAR_RIGHT_PARENTHESES:")",CHAR_ASTERISK:"*",CHAR_AMPERSAND:"&",CHAR_AT:"@",CHAR_BACKSLASH:"\\",CHAR_BACKTICK:"`",CHAR_CARRIAGE_RETURN:"\r",CHAR_CIRCUMFLEX_ACCENT:"^",CHAR_COLON:":",CHAR_COMMA:",",CHAR_DOLLAR:"$",CHAR_DOT:".",CHAR_DOUBLE_QUOTE:'"',CHAR_EQUAL:"=",CHAR_EXCLAMATION_MARK:"!",CHAR_FORM_FEED:"\f",CHAR_FORWARD_SLASH:"/",CHAR_HASH:"#",CHAR_HYPHEN_MINUS:"-",CHAR_LEFT_ANGLE_BRACKET:"<",CHAR_LEFT_CURLY_BRACE:"{",CHAR_LEFT_SQUARE_BRACKET:"[",CHAR_LINE_FEED:`
`,CHAR_NO_BREAK_SPACE:"\xA0",CHAR_PERCENT:"%",CHAR_PLUS:"+",CHAR_QUESTION_MARK:"?",CHAR_RIGHT_ANGLE_BRACKET:">",CHAR_RIGHT_CURLY_BRACE:"}",CHAR_RIGHT_SQUARE_BRACKET:"]",CHAR_SEMICOLON:";",CHAR_SINGLE_QUOTE:"'",CHAR_SPACE:" ",CHAR_TAB:"	",CHAR_UNDERSCORE:"_",CHAR_VERTICAL_LINE:"|",CHAR_ZERO_WIDTH_NOBREAK_SPACE:"\uFEFF"}});var ka=M((Nm,Ea)=>{"use strict";var Xp=ln(),{MAX_LENGTH:wa,CHAR_BACKSLASH:xr,CHAR_BACKTICK:Zp,CHAR_COMMA:eh,CHAR_DOT:th,CHAR_LEFT_PARENTHESES:nh,CHAR_RIGHT_PARENTHESES:rh,CHAR_LEFT_CURLY_BRACE:ih,CHAR_RIGHT_CURLY_BRACE:oh,CHAR_LEFT_SQUARE_BRACKET:Aa,CHAR_RIGHT_SQUARE_BRACKET:Sa,CHAR_DOUBLE_QUOTE:sh,CHAR_SINGLE_QUOTE:ah,CHAR_NO_BREAK_SPACE:uh,CHAR_ZERO_WIDTH_NOBREAK_SPACE:ch}=ba(),lh=(e,t={})=>{if(typeof e!="string")throw new TypeError("Expected a string");let n=t||{},r=typeof n.maxLength=="number"?Math.min(wa,n.maxLength):wa;if(e.length>r)throw new SyntaxError(`Input length (${e.length}), exceeds max characters (${r})`);let i={type:"root",input:e,nodes:[]},o=[i],s=i,a=i,u=0,l=e.length,c=0,p=0,f,m=()=>e[c++],h=y=>{if(y.type==="text"&&a.type==="dot"&&(a.type="text"),a&&a.type==="text"&&y.type==="text"){a.value+=y.value;return}return s.nodes.push(y),y.parent=s,y.prev=a,a=y,y};for(h({type:"bos"});c<l;)if(s=o[o.length-1],f=m(),!(f===ch||f===uh)){if(f===xr){h({type:"text",value:(t.keepEscaping?f:"")+m()});continue}if(f===Sa){h({type:"text",value:"\\"+f});continue}if(f===Aa){u++;let y;for(;c<l&&(y=m());){if(f+=y,y===Aa){u++;continue}if(y===xr){f+=m();continue}if(y===Sa&&(u--,u===0))break}h({type:"text",value:f});continue}if(f===nh){s=h({type:"paren",nodes:[]}),o.push(s),h({type:"text",value:f});continue}if(f===rh){if(s.type!=="paren"){h({type:"text",value:f});continue}s=o.pop(),h({type:"text",value:f}),s=o[o.length-1];continue}if(f===sh||f===ah||f===Zp){let y=f,k;for(t.keepQuotes!==!0&&(f="");c<l&&(k=m());){if(k===xr){f+=k+m();continue}if(k===y){t.keepQuotes===!0&&(f+=k);break}f+=k}h({type:"text",value:f});continue}if(f===ih){p++;let k={type:"brace",open:!0,close:!1,dollar:a.value&&a.value.slice(-1)==="$"||s.dollar===!0,depth:p,commas:0,ranges:0,nodes:[]};s=h(k),o.push(s),h({type:"open",value:f});continue}if(f===oh){if(s.type!=="brace"){h({type:"text",value:f});continue}let y="close";s=o.pop(),s.close=!0,h({type:y,value:f}),p--,s=o[o.length-1];continue}if(f===eh&&p>0){if(s.ranges>0){s.ranges=0;let y=s.nodes.shift();s.nodes=[y,{type:"text",value:Xp(s)}]}h({type:"comma",value:f}),s.commas++;continue}if(f===th&&p>0&&s.commas===0){let y=s.nodes;if(p===0||y.length===0){h({type:"text",value:f});continue}if(a.type==="dot"){if(s.range=[],a.value+=f,a.type="range",s.nodes.length!==3&&s.nodes.length!==5){s.invalid=!0,s.ranges=0,a.type="text";continue}s.ranges++,s.args=[];continue}if(a.type==="range"){y.pop();let k=y[y.length-1];k.value+=a.value+f,a=k,s.ranges--;continue}h({type:"dot",value:f});continue}h({type:"text",value:f})}do if(s=o.pop(),s.type!=="root"){s.nodes.forEach(C=>{C.nodes||(C.type==="open"&&(C.isOpen=!0),C.type==="close"&&(C.isClose=!0),C.nodes||(C.type="text"),C.invalid=!0)});let y=o[o.length-1],k=y.nodes.indexOf(s);y.nodes.splice(k,1,...s.nodes)}while(o.length>0);return h({type:"eos"}),i};Ea.exports=lh});var Ra=M((Fm,Ta)=>{"use strict";var _a=ln(),fh=ga(),ph=xa(),hh=ka(),xe=(e,t={})=>{let n=[];if(Array.isArray(e))for(let r of e){let i=xe.create(r,t);Array.isArray(i)?n.push(...i):n.push(i)}else n=[].concat(xe.create(e,t));return t&&t.expand===!0&&t.nodupes===!0&&(n=[...new Set(n)]),n};xe.parse=(e,t={})=>hh(e,t);xe.stringify=(e,t={})=>_a(typeof e=="string"?xe.parse(e,t):e,t);xe.compile=(e,t={})=>(typeof e=="string"&&(e=xe.parse(e,t)),fh(e,t));xe.expand=(e,t={})=>{typeof e=="string"&&(e=xe.parse(e,t));let n=ph(e,t);return t.noempty===!0&&(n=n.filter(Boolean)),t.nodupes===!0&&(n=[...new Set(n)]),n};xe.create=(e,t={})=>e===""||e.length<3?[e]:t.expand!==!0?xe.compile(e,t):xe.expand(e,t);Ta.exports=xe});var It=M((Mm,Ia)=>{"use strict";var dh=require("path"),ke="\\\\/",Oa=`[^${ke}]`,gh=0,Oe="\\.",mh="\\+",yh="\\?",hn="\\/",xh="(?=.)",Ca="[^/]",vr=`(?:${hn}|$)`,Pa=`(?:^|${hn})`,br=`${Oe}{1,2}${vr}`,vh=`(?!${Oe})`,bh=`(?!${Pa}${br})`,wh=`(?!${Oe}{0,1}${vr})`,Ah=`(?!${br})`,Sh=`[^.${hn}]`,Eh=`${Ca}*?`,La={DOT_LITERAL:Oe,PLUS_LITERAL:mh,QMARK_LITERAL:yh,SLASH_LITERAL:hn,ONE_CHAR:xh,QMARK:Ca,END_ANCHOR:vr,DOTS_SLASH:br,NO_DOT:vh,NO_DOTS:bh,NO_DOT_SLASH:wh,NO_DOTS_SLASH:Ah,QMARK_NO_DOT:Sh,STAR:Eh,START_ANCHOR:Pa},kh={...La,SLASH_LITERAL:`[${ke}]`,QMARK:Oa,STAR:`${Oa}*?`,DOTS_SLASH:`${Oe}{1,2}(?:[${ke}]|$)`,NO_DOT:`(?!${Oe})`,NO_DOTS:`(?!(?:^|[${ke}])${Oe}{1,2}(?:[${ke}]|$))`,NO_DOT_SLASH:`(?!${Oe}{0,1}(?:[${ke}]|$))`,NO_DOTS_SLASH:`(?!${Oe}{1,2}(?:[${ke}]|$))`,QMARK_NO_DOT:`[^.${ke}]`,START_ANCHOR:`(?:^|[${ke}])`,END_ANCHOR:`(?:[${ke}]|$)`},_h={__proto__:null,alnum:"a-zA-Z0-9",alpha:"a-zA-Z",ascii:"\\x00-\\x7F",blank:" \\t",cntrl:"\\x00-\\x1F\\x7F",digit:"0-9",graph:"\\x21-\\x7E",lower:"a-z",print:"\\x20-\\x7E ",punct:"\\-!\"#$%&'()\\*+,./:;<=>?@[\\]^_`{|}~",space:" \\t\\r\\n\\v\\f",upper:"A-Z",word:"A-Za-z0-9_",xdigit:"A-Fa-f0-9"};Ia.exports={DEFAULT_MAX_EXTGLOB_RECURSION:gh,MAX_LENGTH:1024*64,POSIX_REGEX_SOURCE:_h,REGEX_BACKSLASH:/\\(?![*+?^${}(|)[\]])/g,REGEX_NON_SPECIAL_CHARS:/^[^@![\].,$*+?^{}()|\\/]+/,REGEX_SPECIAL_CHARS:/[-*+?.^${}(|)[\]]/,REGEX_SPECIAL_CHARS_BACKREF:/(\\?)((\W)(\3*))/g,REGEX_SPECIAL_CHARS_GLOBAL:/([-*+?.^${}(|)[\]])/g,REGEX_REMOVE_BACKSLASH:/(?:\[.*?[^\\]\]|\\(?=.))/g,REPLACEMENTS:{__proto__:null,"***":"*","**/**":"**","**/**/**":"**"},CHAR_0:48,CHAR_9:57,CHAR_UPPERCASE_A:65,CHAR_LOWERCASE_A:97,CHAR_UPPERCASE_Z:90,CHAR_LOWERCASE_Z:122,CHAR_LEFT_PARENTHESES:40,CHAR_RIGHT_PARENTHESES:41,CHAR_ASTERISK:42,CHAR_AMPERSAND:38,CHAR_AT:64,CHAR_BACKWARD_SLASH:92,CHAR_CARRIAGE_RETURN:13,CHAR_CIRCUMFLEX_ACCENT:94,CHAR_COLON:58,CHAR_COMMA:44,CHAR_DOT:46,CHAR_DOUBLE_QUOTE:34,CHAR_EQUAL:61,CHAR_EXCLAMATION_MARK:33,CHAR_FORM_FEED:12,CHAR_FORWARD_SLASH:47,CHAR_GRAVE_ACCENT:96,CHAR_HASH:35,CHAR_HYPHEN_MINUS:45,CHAR_LEFT_ANGLE_BRACKET:60,CHAR_LEFT_CURLY_BRACE:123,CHAR_LEFT_SQUARE_BRACKET:91,CHAR_LINE_FEED:10,CHAR_NO_BREAK_SPACE:160,CHAR_PERCENT:37,CHAR_PLUS:43,CHAR_QUESTION_MARK:63,CHAR_RIGHT_ANGLE_BRACKET:62,CHAR_RIGHT_CURLY_BRACE:125,CHAR_RIGHT_SQUARE_BRACKET:93,CHAR_SEMICOLON:59,CHAR_SINGLE_QUOTE:39,CHAR_SPACE:32,CHAR_TAB:9,CHAR_UNDERSCORE:95,CHAR_VERTICAL_LINE:124,CHAR_ZERO_WIDTH_NOBREAK_SPACE:65279,SEP:dh.sep,extglobChars(e){return{"!":{type:"negate",open:"(?:(?!(?:",close:`))${e.STAR})`},"?":{type:"qmark",open:"(?:",close:")?"},"+":{type:"plus",open:"(?:",close:")+"},"*":{type:"star",open:"(?:",close:")*"},"@":{type:"at",open:"(?:",close:")"}}},globChars(e){return e===!0?kh:La}}});var Nt=M(ge=>{"use strict";var Th=require("path"),Rh=process.platform==="win32",{REGEX_BACKSLASH:Oh,REGEX_REMOVE_BACKSLASH:Ch,REGEX_SPECIAL_CHARS:Ph,REGEX_SPECIAL_CHARS_GLOBAL:Lh}=It();ge.isObject=e=>e!==null&&typeof e=="object"&&!Array.isArray(e);ge.hasRegexChars=e=>Ph.test(e);ge.isRegexChar=e=>e.length===1&&ge.hasRegexChars(e);ge.escapeRegex=e=>e.replace(Lh,"\\$1");ge.toPosixSlashes=e=>e.replace(Oh,"/");ge.removeBackslashes=e=>e.replace(Ch,t=>t==="\\"?"":t);ge.supportsLookbehinds=()=>{let e=process.version.slice(1).split(".").map(Number);return e.length===3&&e[0]>=9||e[0]===8&&e[1]>=10};ge.isWindows=e=>e&&typeof e.windows=="boolean"?e.windows:Rh===!0||Th.sep==="\\";ge.escapeLast=(e,t,n)=>{let r=e.lastIndexOf(t,n);return r===-1?e:e[r-1]==="\\"?ge.escapeLast(e,t,r-1):`${e.slice(0,r)}\\${e.slice(r)}`};ge.removePrefix=(e,t={})=>{let n=e;return n.startsWith("./")&&(n=n.slice(2),t.prefix="./"),n};ge.wrapOutput=(e,t={},n={})=>{let r=n.contains?"":"^",i=n.contains?"":"$",o=`${r}(?:${e})${i}`;return t.negated===!0&&(o=`(?:^(?!${o}).*$)`),o}});var qa=M((Hm,$a)=>{"use strict";var Na=Nt(),{CHAR_ASTERISK:wr,CHAR_AT:Ih,CHAR_BACKWARD_SLASH:Ft,CHAR_COMMA:Nh,CHAR_DOT:Ar,CHAR_EXCLAMATION_MARK:Sr,CHAR_FORWARD_SLASH:ja,CHAR_LEFT_CURLY_BRACE:Er,CHAR_LEFT_PARENTHESES:kr,CHAR_LEFT_SQUARE_BRACKET:Fh,CHAR_PLUS:Mh,CHAR_QUESTION_MARK:Fa,CHAR_RIGHT_CURLY_BRACE:Dh,CHAR_RIGHT_PARENTHESES:Ma,CHAR_RIGHT_SQUARE_BRACKET:Hh}=It(),Da=e=>e===ja||e===Ft,Ha=e=>{e.isPrefix!==!0&&(e.depth=e.isGlobstar?1/0:1)},jh=(e,t)=>{let n=t||{},r=e.length-1,i=n.parts===!0||n.scanToEnd===!0,o=[],s=[],a=[],u=e,l=-1,c=0,p=0,f=!1,m=!1,h=!1,y=!1,k=!1,C=!1,R=!1,E=!1,_=!1,P=!1,L=0,S,v,b={value:"",depth:0,isGlob:!1},O=()=>l>=r,d=()=>u.charCodeAt(l+1),g=()=>(S=v,u.charCodeAt(++l));for(;l<r;){v=g();let F;if(v===Ft){R=b.backslashes=!0,v=g(),v===Er&&(C=!0);continue}if(C===!0||v===Er){for(L++;O()!==!0&&(v=g());){if(v===Ft){R=b.backslashes=!0,g();continue}if(v===Er){L++;continue}if(C!==!0&&v===Ar&&(v=g())===Ar){if(f=b.isBrace=!0,h=b.isGlob=!0,P=!0,i===!0)continue;break}if(C!==!0&&v===Nh){if(f=b.isBrace=!0,h=b.isGlob=!0,P=!0,i===!0)continue;break}if(v===Dh&&(L--,L===0)){C=!1,f=b.isBrace=!0,P=!0;break}}if(i===!0)continue;break}if(v===ja){if(o.push(l),s.push(b),b={value:"",depth:0,isGlob:!1},P===!0)continue;if(S===Ar&&l===c+1){c+=2;continue}p=l+1;continue}if(n.noext!==!0&&(v===Mh||v===Ih||v===wr||v===Fa||v===Sr)===!0&&d()===kr){if(h=b.isGlob=!0,y=b.isExtglob=!0,P=!0,v===Sr&&l===c&&(_=!0),i===!0){for(;O()!==!0&&(v=g());){if(v===Ft){R=b.backslashes=!0,v=g();continue}if(v===Ma){h=b.isGlob=!0,P=!0;break}}continue}break}if(v===wr){if(S===wr&&(k=b.isGlobstar=!0),h=b.isGlob=!0,P=!0,i===!0)continue;break}if(v===Fa){if(h=b.isGlob=!0,P=!0,i===!0)continue;break}if(v===Fh){for(;O()!==!0&&(F=g());){if(F===Ft){R=b.backslashes=!0,g();continue}if(F===Hh){m=b.isBracket=!0,h=b.isGlob=!0,P=!0;break}}if(i===!0)continue;break}if(n.nonegate!==!0&&v===Sr&&l===c){E=b.negated=!0,c++;continue}if(n.noparen!==!0&&v===kr){if(h=b.isGlob=!0,i===!0){for(;O()!==!0&&(v=g());){if(v===kr){R=b.backslashes=!0,v=g();continue}if(v===Ma){P=!0;break}}continue}break}if(h===!0){if(P=!0,i===!0)continue;break}}n.noext===!0&&(y=!1,h=!1);let A=u,T="",x="";c>0&&(T=u.slice(0,c),u=u.slice(c),p-=c),A&&h===!0&&p>0?(A=u.slice(0,p),x=u.slice(p)):h===!0?(A="",x=u):A=u,A&&A!==""&&A!=="/"&&A!==u&&Da(A.charCodeAt(A.length-1))&&(A=A.slice(0,-1)),n.unescape===!0&&(x&&(x=Na.removeBackslashes(x)),A&&R===!0&&(A=Na.removeBackslashes(A)));let w={prefix:T,input:e,start:c,base:A,glob:x,isBrace:f,isBracket:m,isGlob:h,isExtglob:y,isGlobstar:k,negated:E,negatedExtglob:_};if(n.tokens===!0&&(w.maxDepth=0,Da(v)||s.push(b),w.tokens=s),n.parts===!0||n.tokens===!0){let F;for(let D=0;D<o.length;D++){let H=F?F+1:c,j=o[D],B=e.slice(H,j);n.tokens&&(D===0&&c!==0?(s[D].isPrefix=!0,s[D].value=T):s[D].value=B,Ha(s[D]),w.maxDepth+=s[D].depth),(D!==0||B!=="")&&a.push(B),F=j}if(F&&F+1<e.length){let D=e.slice(F+1);a.push(D),n.tokens&&(s[s.length-1].value=D,Ha(s[s.length-1]),w.maxDepth+=s[s.length-1].depth)}w.slashes=o,w.parts=a}return w};$a.exports=jh});var Ya=M((jm,Wa)=>{"use strict";var Mt=It(),le=Nt(),{MAX_LENGTH:dn,POSIX_REGEX_SOURCE:$h,REGEX_NON_SPECIAL_CHARS:qh,REGEX_SPECIAL_CHARS_BACKREF:Uh,REPLACEMENTS:Ua}=Mt,Bh=(e,t)=>{if(typeof t.expandRange=="function")return t.expandRange(...e,t);e.sort();let n=`[${e.join("-")}]`;try{new RegExp(n)}catch{return e.map(i=>le.escapeRegex(i)).join("..")}return n},ht=(e,t)=>`Missing ${e}: "${t}" - use "\\\\${t}" to match literal characters`,Ba=e=>{let t=[],n=0,r=0,i=0,o="",s=!1;for(let a of e){if(s===!0){o+=a,s=!1;continue}if(a==="\\"){o+=a,s=!0;continue}if(a==='"'){i=i===1?0:1,o+=a;continue}if(i===0){if(a==="[")n++;else if(a==="]"&&n>0)n--;else if(n===0){if(a==="(")r++;else if(a===")"&&r>0)r--;else if(a==="|"&&r===0){t.push(o),o="";continue}}}o+=a}return t.push(o),t},Gh=e=>{let t=!1;for(let n of e){if(t===!0){t=!1;continue}if(n==="\\"){t=!0;continue}if(/[?*+@!()[\]{}]/.test(n))return!1}return!0},Ga=e=>{let t=e.trim(),n=!0;for(;n===!0;)n=!1,/^@\([^\\()[\]{}|]+\)$/.test(t)&&(t=t.slice(2,-1),n=!0);if(Gh(t))return t.replace(/\\(.)/g,"$1")},Wh=e=>{let t=e.map(Ga).filter(Boolean);for(let n=0;n<t.length;n++)for(let r=n+1;r<t.length;r++){let i=t[n],o=t[r],s=i[0];if(!(!s||i!==s.repeat(i.length)||o!==s.repeat(o.length))&&(i===o||i.startsWith(o)||o.startsWith(i)))return!0}return!1},_r=(e,t=!0)=>{if(e[0]!=="+"&&e[0]!=="*"||e[1]!=="(")return;let n=0,r=0,i=0,o=!1;for(let s=1;s<e.length;s++){let a=e[s];if(o===!0){o=!1;continue}if(a==="\\"){o=!0;continue}if(a==='"'){i=i===1?0:1;continue}if(i!==1){if(a==="["){n++;continue}if(a==="]"&&n>0){n--;continue}if(!(n>0)){if(a==="("){r++;continue}if(a===")"&&(r--,r===0))return t===!0&&s!==e.length-1?void 0:{type:e[0],body:e.slice(2,s),end:s}}}}},Yh=e=>{let t=0,n=[];for(;t<e.length;){let i=_r(e.slice(t),!1);if(!i||i.type!=="*")return;let o=Ba(i.body).map(a=>a.trim());if(o.length!==1)return;let s=Ga(o[0]);if(!s||s.length!==1)return;n.push(s),t+=i.end+1}return n.length<1?void 0:`${n.length===1?le.escapeRegex(n[0]):`[${n.map(i=>le.escapeRegex(i)).join("")}]`}*`},Vh=e=>{let t=0,n=e.trim(),r=_r(n);for(;r;)t++,n=r.body.trim(),r=_r(n);return t},Kh=(e,t)=>{if(t.maxExtglobRecursion===!1)return{risky:!1};let n=typeof t.maxExtglobRecursion=="number"?t.maxExtglobRecursion:Mt.DEFAULT_MAX_EXTGLOB_RECURSION,r=Ba(e).map(i=>i.trim());if(r.length>1&&(r.some(i=>i==="")||r.some(i=>/^[*?]+$/.test(i))||Wh(r)))return{risky:!0};for(let i of r){let o=Yh(i);if(o)return{risky:!0,safeOutput:o};if(Vh(i)>n)return{risky:!0}}return{risky:!1}},Tr=(e,t)=>{if(typeof e!="string")throw new TypeError("Expected a string");e=Ua[e]||e;let n={...t},r=typeof n.maxLength=="number"?Math.min(dn,n.maxLength):dn,i=e.length;if(i>r)throw new SyntaxError(`Input length: ${i}, exceeds maximum allowed length: ${r}`);let o={type:"bos",value:"",output:n.prepend||""},s=[o],a=n.capture?"":"?:",u=le.isWindows(t),l=Mt.globChars(u),c=Mt.extglobChars(l),{DOT_LITERAL:p,PLUS_LITERAL:f,SLASH_LITERAL:m,ONE_CHAR:h,DOTS_SLASH:y,NO_DOT:k,NO_DOT_SLASH:C,NO_DOTS_SLASH:R,QMARK:E,QMARK_NO_DOT:_,STAR:P,START_ANCHOR:L}=l,S=N=>`(${a}(?:(?!${L}${N.dot?y:p}).)*?)`,v=n.dot?"":k,b=n.dot?E:_,O=n.bash===!0?S(n):P;n.capture&&(O=`(${O})`),typeof n.noext=="boolean"&&(n.noextglob=n.noext);let d={input:e,index:-1,start:0,dot:n.dot===!0,consumed:"",output:"",prefix:"",backtrack:!1,negated:!1,brackets:0,braces:0,parens:0,quotes:0,globstar:!1,tokens:s};e=le.removePrefix(e,d),i=e.length;let g=[],A=[],T=[],x=o,w,F=()=>d.index===i-1,D=d.peek=(N=1)=>e[d.index+N],H=d.advance=()=>e[++d.index]||"",j=()=>e.slice(d.index+1),B=(N="",Q=0)=>{d.consumed+=N,d.index+=Q},K=N=>{d.output+=N.output!=null?N.output:N.value,B(N.value)},ie=()=>{let N=1;for(;D()==="!"&&(D(2)!=="("||D(3)==="?");)H(),d.start++,N++;return N%2===0?!1:(d.negated=!0,d.start++,!0)},Le=N=>{d[N]++,T.push(N)},he=N=>{d[N]--,T.pop()},W=N=>{if(x.type==="globstar"){let Q=d.braces>0&&(N.type==="comma"||N.type==="brace"),I=N.extglob===!0||g.length&&(N.type==="pipe"||N.type==="paren");N.type!=="slash"&&N.type!=="paren"&&!Q&&!I&&(d.output=d.output.slice(0,-x.output.length),x.type="star",x.value="*",x.output=O,d.output+=x.output)}if(g.length&&N.type!=="paren"&&(g[g.length-1].inner+=N.value),(N.value||N.output)&&K(N),x&&x.type==="text"&&N.type==="text"){x.value+=N.value,x.output=(x.output||"")+N.value;return}N.prev=x,s.push(N),x=N},Te=(N,Q)=>{let I={...c[Q],conditions:1,inner:""};I.prev=x,I.parens=d.parens,I.output=d.output,I.startIndex=d.index,I.tokensIndex=s.length;let Y=(n.capture?"(":"")+I.open;Le("parens"),W({type:N,value:Q,output:d.output?"":h}),W({type:"paren",extglob:!0,value:H(),output:Y}),g.push(I)},tt=N=>{let Q=e.slice(N.startIndex,d.index+1),I=e.slice(N.startIndex+2,d.index),Y=Kh(I,n);if((N.type==="plus"||N.type==="star")&&Y.risky){let X=Y.safeOutput?(N.output?"":h)+(n.capture?`(${Y.safeOutput})`:Y.safeOutput):void 0,Ae=s[N.tokensIndex];Ae.type="text",Ae.value=Q,Ae.output=X||le.escapeRegex(Q);for(let Se=N.tokensIndex+1;Se<s.length;Se++)s[Se].value="",s[Se].output="",delete s[Se].suffix;d.output=N.output+Ae.output,d.backtrack=!0,W({type:"paren",extglob:!0,value:w,output:""}),he("parens");return}let J=N.close+(n.capture?")":""),oe;if(N.type==="negate"){let X=O;if(N.inner&&N.inner.length>1&&N.inner.includes("/")&&(X=S(n)),(X!==O||F()||/^\)+$/.test(j()))&&(J=N.close=`)$))${X}`),N.inner.includes("*")&&(oe=j())&&/^\.[^\\/.]+$/.test(oe)){let Ae=Tr(oe,{...t,fastpaths:!1}).output;J=N.close=`)${Ae})${X})`}N.prev.type==="bos"&&(d.negatedExtglob=!0)}W({type:"paren",extglob:!0,value:w,output:J}),he("parens")};if(n.fastpaths!==!1&&!/(^[*!]|[/()[\]{}"])/.test(e)){let N=!1,Q=e.replace(Uh,(I,Y,J,oe,X,Ae)=>oe==="\\"?(N=!0,I):oe==="?"?Y?Y+oe+(X?E.repeat(X.length):""):Ae===0?b+(X?E.repeat(X.length):""):E.repeat(J.length):oe==="."?p.repeat(J.length):oe==="*"?Y?Y+oe+(X?O:""):O:Y?I:`\\${I}`);return N===!0&&(n.unescape===!0?Q=Q.replace(/\\/g,""):Q=Q.replace(/\\+/g,I=>I.length%2===0?"\\\\":I?"\\":"")),Q===e&&n.contains===!0?(d.output=e,d):(d.output=le.wrapOutput(Q,d,t),d)}for(;!F();){if(w=H(),w==="\0")continue;if(w==="\\"){let I=D();if(I==="/"&&n.bash!==!0||I==="."||I===";")continue;if(!I){w+="\\",W({type:"text",value:w});continue}let Y=/^\\+/.exec(j()),J=0;if(Y&&Y[0].length>2&&(J=Y[0].length,d.index+=J,J%2!==0&&(w+="\\")),n.unescape===!0?w=H():w+=H(),d.brackets===0){W({type:"text",value:w});continue}}if(d.brackets>0&&(w!=="]"||x.value==="["||x.value==="[^")){if(n.posix!==!1&&w===":"){let I=x.value.slice(1);if(I.includes("[")&&(x.posix=!0,I.includes(":"))){let Y=x.value.lastIndexOf("["),J=x.value.slice(0,Y),oe=x.value.slice(Y+2),X=$h[oe];if(X){x.value=J+X,d.backtrack=!0,H(),!o.output&&s.indexOf(x)===1&&(o.output=h);continue}}}(w==="["&&D()!==":"||w==="-"&&D()==="]")&&(w=`\\${w}`),w==="]"&&(x.value==="["||x.value==="[^")&&(w=`\\${w}`),n.posix===!0&&w==="!"&&x.value==="["&&(w="^"),x.value+=w,K({value:w});continue}if(d.quotes===1&&w!=='"'){w=le.escapeRegex(w),x.value+=w,K({value:w});continue}if(w==='"'){d.quotes=d.quotes===1?0:1,n.keepQuotes===!0&&W({type:"text",value:w});continue}if(w==="("){Le("parens"),W({type:"paren",value:w});continue}if(w===")"){if(d.parens===0&&n.strictBrackets===!0)throw new SyntaxError(ht("opening","("));let I=g[g.length-1];if(I&&d.parens===I.parens+1){tt(g.pop());continue}W({type:"paren",value:w,output:d.parens?")":"\\)"}),he("parens");continue}if(w==="["){if(n.nobracket===!0||!j().includes("]")){if(n.nobracket!==!0&&n.strictBrackets===!0)throw new SyntaxError(ht("closing","]"));w=`\\${w}`}else Le("brackets");W({type:"bracket",value:w});continue}if(w==="]"){if(n.nobracket===!0||x&&x.type==="bracket"&&x.value.length===1){W({type:"text",value:w,output:`\\${w}`});continue}if(d.brackets===0){if(n.strictBrackets===!0)throw new SyntaxError(ht("opening","["));W({type:"text",value:w,output:`\\${w}`});continue}he("brackets");let I=x.value.slice(1);if(x.posix!==!0&&I[0]==="^"&&!I.includes("/")&&(w=`/${w}`),x.value+=w,K({value:w}),n.literalBrackets===!1||le.hasRegexChars(I))continue;let Y=le.escapeRegex(x.value);if(d.output=d.output.slice(0,-x.value.length),n.literalBrackets===!0){d.output+=Y,x.value=Y;continue}x.value=`(${a}${Y}|${x.value})`,d.output+=x.value;continue}if(w==="{"&&n.nobrace!==!0){Le("braces");let I={type:"brace",value:w,output:"(",outputIndex:d.output.length,tokensIndex:d.tokens.length};A.push(I),W(I);continue}if(w==="}"){let I=A[A.length-1];if(n.nobrace===!0||!I){W({type:"text",value:w,output:w});continue}let Y=")";if(I.dots===!0){let J=s.slice(),oe=[];for(let X=J.length-1;X>=0&&(s.pop(),J[X].type!=="brace");X--)J[X].type!=="dots"&&oe.unshift(J[X].value);Y=Bh(oe,n),d.backtrack=!0}if(I.comma!==!0&&I.dots!==!0){let J=d.output.slice(0,I.outputIndex),oe=d.tokens.slice(I.tokensIndex);I.value=I.output="\\{",w=Y="\\}",d.output=J;for(let X of oe)d.output+=X.output||X.value}W({type:"brace",value:w,output:Y}),he("braces"),A.pop();continue}if(w==="|"){g.length>0&&g[g.length-1].conditions++,W({type:"text",value:w});continue}if(w===","){let I=w,Y=A[A.length-1];Y&&T[T.length-1]==="braces"&&(Y.comma=!0,I="|"),W({type:"comma",value:w,output:I});continue}if(w==="/"){if(x.type==="dot"&&d.index===d.start+1){d.start=d.index+1,d.consumed="",d.output="",s.pop(),x=o;continue}W({type:"slash",value:w,output:m});continue}if(w==="."){if(d.braces>0&&x.type==="dot"){x.value==="."&&(x.output=p);let I=A[A.length-1];x.type="dots",x.output+=w,x.value+=w,I.dots=!0;continue}if(d.braces+d.parens===0&&x.type!=="bos"&&x.type!=="slash"){W({type:"text",value:w,output:p});continue}W({type:"dot",value:w,output:p});continue}if(w==="?"){if(!(x&&x.value==="(")&&n.noextglob!==!0&&D()==="("&&D(2)!=="?"){Te("qmark",w);continue}if(x&&x.type==="paren"){let Y=D(),J=w;if(Y==="<"&&!le.supportsLookbehinds())throw new Error("Node.js v10 or higher is required for regex lookbehinds");(x.value==="("&&!/[!=<:]/.test(Y)||Y==="<"&&!/<([!=]|\w+>)/.test(j()))&&(J=`\\${w}`),W({type:"text",value:w,output:J});continue}if(n.dot!==!0&&(x.type==="slash"||x.type==="bos")){W({type:"qmark",value:w,output:_});continue}W({type:"qmark",value:w,output:E});continue}if(w==="!"){if(n.noextglob!==!0&&D()==="("&&(D(2)!=="?"||!/[!=<:]/.test(D(3)))){Te("negate",w);continue}if(n.nonegate!==!0&&d.index===0){ie();continue}}if(w==="+"){if(n.noextglob!==!0&&D()==="("&&D(2)!=="?"){Te("plus",w);continue}if(x&&x.value==="("||n.regex===!1){W({type:"plus",value:w,output:f});continue}if(x&&(x.type==="bracket"||x.type==="paren"||x.type==="brace")||d.parens>0){W({type:"plus",value:w});continue}W({type:"plus",value:f});continue}if(w==="@"){if(n.noextglob!==!0&&D()==="("&&D(2)!=="?"){W({type:"at",extglob:!0,value:w,output:""});continue}W({type:"text",value:w});continue}if(w!=="*"){(w==="$"||w==="^")&&(w=`\\${w}`);let I=qh.exec(j());I&&(w+=I[0],d.index+=I[0].length),W({type:"text",value:w});continue}if(x&&(x.type==="globstar"||x.star===!0)){x.type="star",x.star=!0,x.value+=w,x.output=O,d.backtrack=!0,d.globstar=!0,B(w);continue}let N=j();if(n.noextglob!==!0&&/^\([^?]/.test(N)){Te("star",w);continue}if(x.type==="star"){if(n.noglobstar===!0){B(w);continue}let I=x.prev,Y=I.prev,J=I.type==="slash"||I.type==="bos",oe=Y&&(Y.type==="star"||Y.type==="globstar");if(n.bash===!0&&(!J||N[0]&&N[0]!=="/")){W({type:"star",value:w,output:""});continue}let X=d.braces>0&&(I.type==="comma"||I.type==="brace"),Ae=g.length&&(I.type==="pipe"||I.type==="paren");if(!J&&I.type!=="paren"&&!X&&!Ae){W({type:"star",value:w,output:""});continue}for(;N.slice(0,3)==="/**";){let Se=e[d.index+4];if(Se&&Se!=="/")break;N=N.slice(3),B("/**",3)}if(I.type==="bos"&&F()){x.type="globstar",x.value+=w,x.output=S(n),d.output=x.output,d.globstar=!0,B(w);continue}if(I.type==="slash"&&I.prev.type!=="bos"&&!oe&&F()){d.output=d.output.slice(0,-(I.output+x.output).length),I.output=`(?:${I.output}`,x.type="globstar",x.output=S(n)+(n.strictSlashes?")":"|$)"),x.value+=w,d.globstar=!0,d.output+=I.output+x.output,B(w);continue}if(I.type==="slash"&&I.prev.type!=="bos"&&N[0]==="/"){let Se=N[1]!==void 0?"|$":"";d.output=d.output.slice(0,-(I.output+x.output).length),I.output=`(?:${I.output}`,x.type="globstar",x.output=`${S(n)}${m}|${m}${Se})`,x.value+=w,d.output+=I.output+x.output,d.globstar=!0,B(w+H()),W({type:"slash",value:"/",output:""});continue}if(I.type==="bos"&&N[0]==="/"){x.type="globstar",x.value+=w,x.output=`(?:^|${m}|${S(n)}${m})`,d.output=x.output,d.globstar=!0,B(w+H()),W({type:"slash",value:"/",output:""});continue}d.output=d.output.slice(0,-x.output.length),x.type="globstar",x.output=S(n),x.value+=w,d.output+=x.output,d.globstar=!0,B(w);continue}let Q={type:"star",value:w,output:O};if(n.bash===!0){Q.output=".*?",(x.type==="bos"||x.type==="slash")&&(Q.output=v+Q.output),W(Q);continue}if(x&&(x.type==="bracket"||x.type==="paren")&&n.regex===!0){Q.output=w,W(Q);continue}(d.index===d.start||x.type==="slash"||x.type==="dot")&&(x.type==="dot"?(d.output+=C,x.output+=C):n.dot===!0?(d.output+=R,x.output+=R):(d.output+=v,x.output+=v),D()!=="*"&&(d.output+=h,x.output+=h)),W(Q)}for(;d.brackets>0;){if(n.strictBrackets===!0)throw new SyntaxError(ht("closing","]"));d.output=le.escapeLast(d.output,"["),he("brackets")}for(;d.parens>0;){if(n.strictBrackets===!0)throw new SyntaxError(ht("closing",")"));d.output=le.escapeLast(d.output,"("),he("parens")}for(;d.braces>0;){if(n.strictBrackets===!0)throw new SyntaxError(ht("closing","}"));d.output=le.escapeLast(d.output,"{"),he("braces")}if(n.strictSlashes!==!0&&(x.type==="star"||x.type==="bracket")&&W({type:"maybe_slash",value:"",output:`${m}?`}),d.backtrack===!0){d.output="";for(let N of d.tokens)d.output+=N.output!=null?N.output:N.value,N.suffix&&(d.output+=N.suffix)}return d};Tr.fastpaths=(e,t)=>{let n={...t},r=typeof n.maxLength=="number"?Math.min(dn,n.maxLength):dn,i=e.length;if(i>r)throw new SyntaxError(`Input length: ${i}, exceeds maximum allowed length: ${r}`);e=Ua[e]||e;let o=le.isWindows(t),{DOT_LITERAL:s,SLASH_LITERAL:a,ONE_CHAR:u,DOTS_SLASH:l,NO_DOT:c,NO_DOTS:p,NO_DOTS_SLASH:f,STAR:m,START_ANCHOR:h}=Mt.globChars(o),y=n.dot?p:c,k=n.dot?f:c,C=n.capture?"":"?:",R={negated:!1,prefix:""},E=n.bash===!0?".*?":m;n.capture&&(E=`(${E})`);let _=v=>v.noglobstar===!0?E:`(${C}(?:(?!${h}${v.dot?l:s}).)*?)`,P=v=>{switch(v){case"*":return`${y}${u}${E}`;case".*":return`${s}${u}${E}`;case"*.*":return`${y}${E}${s}${u}${E}`;case"*/*":return`${y}${E}${a}${u}${k}${E}`;case"**":return y+_(n);case"**/*":return`(?:${y}${_(n)}${a})?${k}${u}${E}`;case"**/*.*":return`(?:${y}${_(n)}${a})?${k}${E}${s}${u}${E}`;case"**/.*":return`(?:${y}${_(n)}${a})?${s}${u}${E}`;default:{let b=/^(.*?)\.(\w+)$/.exec(v);if(!b)return;let O=P(b[1]);return O?O+s+b[2]:void 0}}},L=le.removePrefix(e,R),S=P(L);return S&&n.strictSlashes!==!0&&(S+=`${a}?`),S};Wa.exports=Tr});var Ka=M(($m,Va)=>{"use strict";var Jh=require("path"),zh=qa(),Rr=Ya(),Or=Nt(),Qh=It(),Xh=e=>e&&typeof e=="object"&&!Array.isArray(e),te=(e,t,n=!1)=>{if(Array.isArray(e)){let c=e.map(f=>te(f,t,n));return f=>{for(let m of c){let h=m(f);if(h)return h}return!1}}let r=Xh(e)&&e.tokens&&e.input;if(e===""||typeof e!="string"&&!r)throw new TypeError("Expected pattern to be a non-empty string");let i=t||{},o=Or.isWindows(t),s=r?te.compileRe(e,t):te.makeRe(e,t,!1,!0),a=s.state;delete s.state;let u=()=>!1;if(i.ignore){let c={...t,ignore:null,onMatch:null,onResult:null};u=te(i.ignore,c,n)}let l=(c,p=!1)=>{let{isMatch:f,match:m,output:h}=te.test(c,s,t,{glob:e,posix:o}),y={glob:e,state:a,regex:s,posix:o,input:c,output:h,match:m,isMatch:f};return typeof i.onResult=="function"&&i.onResult(y),f===!1?(y.isMatch=!1,p?y:!1):u(c)?(typeof i.onIgnore=="function"&&i.onIgnore(y),y.isMatch=!1,p?y:!1):(typeof i.onMatch=="function"&&i.onMatch(y),p?y:!0)};return n&&(l.state=a),l};te.test=(e,t,n,{glob:r,posix:i}={})=>{if(typeof e!="string")throw new TypeError("Expected input to be a string");if(e==="")return{isMatch:!1,output:""};let o=n||{},s=o.format||(i?Or.toPosixSlashes:null),a=e===r,u=a&&s?s(e):e;return a===!1&&(u=s?s(e):e,a=u===r),(a===!1||o.capture===!0)&&(o.matchBase===!0||o.basename===!0?a=te.matchBase(e,t,n,i):a=t.exec(u)),{isMatch:!!a,match:a,output:u}};te.matchBase=(e,t,n,r=Or.isWindows(n))=>(t instanceof RegExp?t:te.makeRe(t,n)).test(Jh.basename(e));te.isMatch=(e,t,n)=>te(t,n)(e);te.parse=(e,t)=>Array.isArray(e)?e.map(n=>te.parse(n,t)):Rr(e,{...t,fastpaths:!1});te.scan=(e,t)=>zh(e,t);te.compileRe=(e,t,n=!1,r=!1)=>{if(n===!0)return e.output;let i=t||{},o=i.contains?"":"^",s=i.contains?"":"$",a=`${o}(?:${e.output})${s}`;e&&e.negated===!0&&(a=`^(?!${a}).*$`);let u=te.toRegex(a,t);return r===!0&&(u.state=e),u};te.makeRe=(e,t={},n=!1,r=!1)=>{if(!e||typeof e!="string")throw new TypeError("Expected a non-empty string");let i={negated:!1,fastpaths:!0};return t.fastpaths!==!1&&(e[0]==="."||e[0]==="*")&&(i.output=Rr.fastpaths(e,t)),i.output||(i=Rr(e,t)),te.compileRe(i,t,n,r)};te.toRegex=(e,t)=>{try{let n=t||{};return new RegExp(e,n.flags||(n.nocase?"i":""))}catch(n){if(t&&t.debug===!0)throw n;return/$^/}};te.constants=Qh;Va.exports=te});var za=M((qm,Ja)=>{"use strict";Ja.exports=Ka()});var nu=M((Um,tu)=>{"use strict";var Xa=require("util"),Za=Ra(),_e=za(),Cr=Nt(),Qa=e=>e===""||e==="./",eu=e=>{let t=e.indexOf("{");return t>-1&&e.indexOf("}",t)>-1},Z=(e,t,n)=>{t=[].concat(t),e=[].concat(e);let r=new Set,i=new Set,o=new Set,s=0,a=c=>{o.add(c.output),n&&n.onResult&&n.onResult(c)};for(let c=0;c<t.length;c++){let p=_e(String(t[c]),{...n,onResult:a},!0),f=p.state.negated||p.state.negatedExtglob;f&&s++;for(let m of e){let h=p(m,!0);(f?!h.isMatch:h.isMatch)&&(f?r.add(h.output):(r.delete(h.output),i.add(h.output)))}}let l=(s===t.length?[...o]:[...i]).filter(c=>!r.has(c));if(n&&l.length===0){if(n.failglob===!0)throw new Error(`No matches found for "${t.join(", ")}"`);if(n.nonull===!0||n.nullglob===!0)return n.unescape?t.map(c=>c.replace(/\\/g,"")):t}return l};Z.match=Z;Z.matcher=(e,t)=>_e(e,t);Z.isMatch=(e,t,n)=>_e(t,n)(e);Z.any=Z.isMatch;Z.not=(e,t,n={})=>{t=[].concat(t).map(String);let r=new Set,i=[],o=a=>{n.onResult&&n.onResult(a),i.push(a.output)},s=new Set(Z(e,t,{...n,onResult:o}));for(let a of i)s.has(a)||r.add(a);return[...r]};Z.contains=(e,t,n)=>{if(typeof e!="string")throw new TypeError(`Expected a string: "${Xa.inspect(e)}"`);if(Array.isArray(t))return t.some(r=>Z.contains(e,r,n));if(typeof t=="string"){if(Qa(e)||Qa(t))return!1;if(e.includes(t)||e.startsWith("./")&&e.slice(2).includes(t))return!0}return Z.isMatch(e,t,{...n,contains:!0})};Z.matchKeys=(e,t,n)=>{if(!Cr.isObject(e))throw new TypeError("Expected the first argument to be an object");let r=Z(Object.keys(e),t,n),i={};for(let o of r)i[o]=e[o];return i};Z.some=(e,t,n)=>{let r=[].concat(e);for(let i of[].concat(t)){let o=_e(String(i),n);if(r.some(s=>o(s)))return!0}return!1};Z.every=(e,t,n)=>{let r=[].concat(e);for(let i of[].concat(t)){let o=_e(String(i),n);if(!r.every(s=>o(s)))return!1}return!0};Z.all=(e,t,n)=>{if(typeof e!="string")throw new TypeError(`Expected a string: "${Xa.inspect(e)}"`);return[].concat(t).every(r=>_e(r,n)(e))};Z.capture=(e,t,n)=>{let r=Cr.isWindows(n),o=_e.makeRe(String(e),{...n,capture:!0}).exec(r?Cr.toPosixSlashes(t):t);if(o)return o.slice(1).map(s=>s===void 0?"":s)};Z.makeRe=(...e)=>_e.makeRe(...e);Z.scan=(...e)=>_e.scan(...e);Z.parse=(e,t)=>{let n=[];for(let r of[].concat(e||[]))for(let i of Za(String(r),t))n.push(_e.parse(i,t));return n};Z.braces=(e,t)=>{if(typeof e!="string")throw new TypeError("Expected a string");return t&&t.nobrace===!0||!eu(e)?[e]:Za(e,t)};Z.braceExpand=(e,t)=>{if(typeof e!="string")throw new TypeError("Expected a string");return Z.braces(e,{...t,expand:!0})};Z.hasBraces=eu;tu.exports=Z});var ou=M((Bm,iu)=>{"use strict";var ru=require("fs"),Zh=nu(),gn=require("path");iu.exports=ed;function ed(e){e||(e=process.cwd());let t=null,n=gn.normalize(e);do{let r=nd(n),i=td(r);if(i){let o=gn.relative(n,e);return o===""||Zh([o],i).length>0?n:null}t=n,n=gn.dirname(n)}while(n!==t);return null}function td(e){let t=(e||{}).workspaces;return t&&t.packages||(Array.isArray(t)?t:null)}function nd(e){let t=gn.join(e,"package.json");return ru.existsSync(t)?JSON.parse(ru.readFileSync(t,"utf8")):null}});var Ou=M(xt=>{"use strict";Object.defineProperty(xt,"__esModule",{value:!0});xt.sync=xt.isexe=void 0;var wd=require("fs"),Ad=require("fs/promises"),Sd=async(e,t={})=>{let{ignoreErrors:n=!1}=t;try{return Ru(await(0,Ad.stat)(e),t)}catch(r){let i=r;if(n||i.code==="EACCES")return!1;throw i}};xt.isexe=Sd;var Ed=(e,t={})=>{let{ignoreErrors:n=!1}=t;try{return Ru((0,wd.statSync)(e),t)}catch(r){let i=r;if(n||i.code==="EACCES")return!1;throw i}};xt.sync=Ed;var Ru=(e,t)=>e.isFile()&&kd(e,t),kd=(e,t)=>{let n=t.uid??process.getuid?.(),r=t.groups??process.getgroups?.()??[],i=t.gid??process.getgid?.()??r[0];if(n===void 0||i===void 0)throw new Error("cannot get uid or gid");let o=new Set([i,...r]),s=e.mode,a=e.uid,u=e.gid,l=parseInt("100",8),c=parseInt("010",8),p=parseInt("001",8),f=l|c;return!!(s&p||s&c&&o.has(u)||s&l&&a===n||s&f&&n===0)}});var Pu=M(vt=>{"use strict";Object.defineProperty(vt,"__esModule",{value:!0});vt.sync=vt.isexe=void 0;var _d=require("fs"),Td=require("fs/promises"),Rd=async(e,t={})=>{let{ignoreErrors:n=!1}=t;try{return Cu(await(0,Td.stat)(e),e,t)}catch(r){let i=r;if(n||i.code==="EACCES")return!1;throw i}};vt.isexe=Rd;var Od=(e,t={})=>{let{ignoreErrors:n=!1}=t;try{return Cu((0,_d.statSync)(e),e,t)}catch(r){let i=r;if(n||i.code==="EACCES")return!1;throw i}};vt.sync=Od;var Cd=(e,t)=>{let{pathExt:n=process.env.PATHEXT||""}=t,r=n.split(";");if(r.indexOf("")!==-1)return!0;for(let i=0;i<r.length;i++){let o=r[i].toLowerCase(),s=e.substring(e.length-o.length).toLowerCase();if(o&&s===o)return!0}return!1},Cu=(e,t,n)=>e.isFile()&&Cd(t,n)});var Iu=M(Lu=>{"use strict";Object.defineProperty(Lu,"__esModule",{value:!0})});var ju=M(ae=>{"use strict";var Nu=ae&&ae.__createBinding||(Object.create?(function(e,t,n,r){r===void 0&&(r=n);var i=Object.getOwnPropertyDescriptor(t,n);(!i||("get"in i?!t.__esModule:i.writable||i.configurable))&&(i={enumerable:!0,get:function(){return t[n]}}),Object.defineProperty(e,r,i)}):(function(e,t,n,r){r===void 0&&(r=n),e[r]=t[n]})),Pd=ae&&ae.__setModuleDefault||(Object.create?(function(e,t){Object.defineProperty(e,"default",{enumerable:!0,value:t})}):function(e,t){e.default=t}),Fu=ae&&ae.__importStar||function(e){if(e&&e.__esModule)return e;var t={};if(e!=null)for(var n in e)n!=="default"&&Object.prototype.hasOwnProperty.call(e,n)&&Nu(t,e,n);return Pd(t,e),t},Ld=ae&&ae.__exportStar||function(e,t){for(var n in e)n!=="default"&&!Object.prototype.hasOwnProperty.call(t,n)&&Nu(t,e,n)};Object.defineProperty(ae,"__esModule",{value:!0});ae.sync=ae.isexe=ae.posix=ae.win32=void 0;var Mu=Fu(Ou());ae.posix=Mu;var Du=Fu(Pu());ae.win32=Du;Ld(Iu(),ae);var Id=process.env._ISEXE_TEST_PLATFORM_||process.platform,Hu=Id==="win32"?Du:Mu;ae.isexe=Hu.isexe;ae.sync=Hu.sync});var Ju=M((V0,Ku)=>{var{isexe:Nd,sync:Fd}=ju(),{join:Md,delimiter:Dd,sep:$u,posix:qu}=require("path"),Uu=process.platform==="win32",Bu=new RegExp(`[${qu.sep}${$u===qu.sep?"":$u}]`.replace(/(\\)/g,"\\$1")),Hd=new RegExp(`^\\.${Bu.source}`),Gu=e=>Object.assign(new Error(`not found: ${e}`),{code:"ENOENT"}),Wu=(e,{path:t=process.env.PATH,pathExt:n=process.env.PATHEXT,delimiter:r=Dd})=>{let i=e.match(Bu)?[""]:[...Uu?[process.cwd()]:[],...(t||"").split(r)];if(Uu){let o=n||[".EXE",".CMD",".BAT",".COM"].join(r),s=o.split(r).flatMap(a=>[a,a.toLowerCase()]);return e.includes(".")&&s[0]!==""&&s.unshift(""),{pathEnv:i,pathExt:s,pathExtExe:o}}return{pathEnv:i,pathExt:[""]}},Yu=(e,t)=>{let n=/^".*"$/.test(e)?e.slice(1,-1):e;return(!n&&Hd.test(t)?t.slice(0,2):"")+Md(n,t)},Vu=async(e,t={})=>{let{pathEnv:n,pathExt:r,pathExtExe:i}=Wu(e,t),o=[];for(let s of n){let a=Yu(s,e);for(let u of r){let l=a+u;if(await Nd(l,{pathExt:i,ignoreErrors:!0})){if(!t.all)return l;o.push(l)}}}if(t.all&&o.length)return o;if(t.nothrow)return null;throw Gu(e)},jd=(e,t={})=>{let{pathEnv:n,pathExt:r,pathExtExe:i}=Wu(e,t),o=[];for(let s of n){let a=Yu(s,e);for(let u of r){let l=a+u;if(Fd(l,{pathExt:i,ignoreErrors:!0})){if(!t.all)return l;o.push(l)}}}if(t.all&&o.length)return o;if(t.nothrow)return null;throw Gu(e)};Ku.exports=Vu;Vu.sync=jd});var Vd={};rc(Vd,{activate:()=>$d,deactivate:()=>Yd});module.exports=ic(Vd);var Tn=me(jr()),z=me(require("vscode"));function wt(e,t=!1){let n=e.length,r=0,i="",o=0,s=16,a=0,u=0,l=0,c=0,p=0;function f(E,_){let P=0,L=0;for(;P<E||!_;){let S=e.charCodeAt(r);if(S>=48&&S<=57)L=L*16+S-48;else if(S>=65&&S<=70)L=L*16+S-65+10;else if(S>=97&&S<=102)L=L*16+S-97+10;else break;r++,P++}return P<E&&(L=-1),L}function m(E){r=E,i="",o=0,s=16,p=0}function h(){let E=r;if(e.charCodeAt(r)===48)r++;else for(r++;r<e.length&&nt(e.charCodeAt(r));)r++;if(r<e.length&&e.charCodeAt(r)===46)if(r++,r<e.length&&nt(e.charCodeAt(r)))for(r++;r<e.length&&nt(e.charCodeAt(r));)r++;else return p=3,e.substring(E,r);let _=r;if(r<e.length&&(e.charCodeAt(r)===69||e.charCodeAt(r)===101))if(r++,(r<e.length&&e.charCodeAt(r)===43||e.charCodeAt(r)===45)&&r++,r<e.length&&nt(e.charCodeAt(r))){for(r++;r<e.length&&nt(e.charCodeAt(r));)r++;_=r}else p=3;return e.substring(E,_)}function y(){let E="",_=r;for(;;){if(r>=n){E+=e.substring(_,r),p=2;break}let P=e.charCodeAt(r);if(P===34){E+=e.substring(_,r),r++;break}if(P===92){if(E+=e.substring(_,r),r++,r>=n){p=2;break}switch(e.charCodeAt(r++)){case 34:E+='"';break;case 92:E+="\\";break;case 47:E+="/";break;case 98:E+="\b";break;case 102:E+="\f";break;case 110:E+=`
`;break;case 114:E+="\r";break;case 116:E+="	";break;case 117:let S=f(4,!0);S>=0?E+=String.fromCharCode(S):p=4;break;default:p=5}_=r;continue}if(P>=0&&P<=31)if(bt(P)){E+=e.substring(_,r),p=2;break}else p=6;r++}return E}function k(){if(i="",p=0,o=r,u=a,c=l,r>=n)return o=n,s=17;let E=e.charCodeAt(r);if(Rn(E)){do r++,i+=String.fromCharCode(E),E=e.charCodeAt(r);while(Rn(E));return s=15}if(bt(E))return r++,i+=String.fromCharCode(E),E===13&&e.charCodeAt(r)===10&&(r++,i+=`
`),a++,l=r,s=14;switch(E){case 123:return r++,s=1;case 125:return r++,s=2;case 91:return r++,s=3;case 93:return r++,s=4;case 58:return r++,s=6;case 44:return r++,s=5;case 34:return r++,i=y(),s=10;case 47:let _=r-1;if(e.charCodeAt(r+1)===47){for(r+=2;r<n&&!bt(e.charCodeAt(r));)r++;return i=e.substring(_,r),s=12}if(e.charCodeAt(r+1)===42){r+=2;let P=n-1,L=!1;for(;r<P;){let S=e.charCodeAt(r);if(S===42&&e.charCodeAt(r+1)===47){r+=2,L=!0;break}r++,bt(S)&&(S===13&&e.charCodeAt(r)===10&&r++,a++,l=r)}return L||(r++,p=1),i=e.substring(_,r),s=13}return i+=String.fromCharCode(E),r++,s=16;case 45:if(i+=String.fromCharCode(E),r++,r===n||!nt(e.charCodeAt(r)))return s=16;case 48:case 49:case 50:case 51:case 52:case 53:case 54:case 55:case 56:case 57:return i+=h(),s=11;default:for(;r<n&&C(E);)r++,E=e.charCodeAt(r);if(o!==r){switch(i=e.substring(o,r),i){case"true":return s=8;case"false":return s=9;case"null":return s=7}return s=16}return i+=String.fromCharCode(E),r++,s=16}}function C(E){if(Rn(E)||bt(E))return!1;switch(E){case 125:case 93:case 123:case 91:case 34:case 58:case 44:case 47:return!1}return!0}function R(){let E;do E=k();while(E>=12&&E<=15);return E}return{setPosition:m,getPosition:()=>r,scan:t?R:k,getToken:()=>s,getTokenValue:()=>i,getTokenOffset:()=>o,getTokenLength:()=>r-o,getTokenStartLine:()=>u,getTokenStartCharacter:()=>o-c,getTokenError:()=>p}}function Rn(e){return e===32||e===9}function bt(e){return e===10||e===13}function nt(e){return e>=48&&e<=57}var $r;(function(e){e[e.lineFeed=10]="lineFeed",e[e.carriageReturn=13]="carriageReturn",e[e.space=32]="space",e[e._0=48]="_0",e[e._1=49]="_1",e[e._2=50]="_2",e[e._3=51]="_3",e[e._4=52]="_4",e[e._5=53]="_5",e[e._6=54]="_6",e[e._7=55]="_7",e[e._8=56]="_8",e[e._9=57]="_9",e[e.a=97]="a",e[e.b=98]="b",e[e.c=99]="c",e[e.d=100]="d",e[e.e=101]="e",e[e.f=102]="f",e[e.g=103]="g",e[e.h=104]="h",e[e.i=105]="i",e[e.j=106]="j",e[e.k=107]="k",e[e.l=108]="l",e[e.m=109]="m",e[e.n=110]="n",e[e.o=111]="o",e[e.p=112]="p",e[e.q=113]="q",e[e.r=114]="r",e[e.s=115]="s",e[e.t=116]="t",e[e.u=117]="u",e[e.v=118]="v",e[e.w=119]="w",e[e.x=120]="x",e[e.y=121]="y",e[e.z=122]="z",e[e.A=65]="A",e[e.B=66]="B",e[e.C=67]="C",e[e.D=68]="D",e[e.E=69]="E",e[e.F=70]="F",e[e.G=71]="G",e[e.H=72]="H",e[e.I=73]="I",e[e.J=74]="J",e[e.K=75]="K",e[e.L=76]="L",e[e.M=77]="M",e[e.N=78]="N",e[e.O=79]="O",e[e.P=80]="P",e[e.Q=81]="Q",e[e.R=82]="R",e[e.S=83]="S",e[e.T=84]="T",e[e.U=85]="U",e[e.V=86]="V",e[e.W=87]="W",e[e.X=88]="X",e[e.Y=89]="Y",e[e.Z=90]="Z",e[e.asterisk=42]="asterisk",e[e.backslash=92]="backslash",e[e.closeBrace=125]="closeBrace",e[e.closeBracket=93]="closeBracket",e[e.colon=58]="colon",e[e.comma=44]="comma",e[e.dot=46]="dot",e[e.doubleQuote=34]="doubleQuote",e[e.minus=45]="minus",e[e.openBrace=123]="openBrace",e[e.openBracket=91]="openBracket",e[e.plus=43]="plus",e[e.slash=47]="slash",e[e.formFeed=12]="formFeed",e[e.tab=9]="tab"})($r||($r={}));var On;(function(e){e.DEFAULT={allowTrailingComma:!1}})(On||(On={}));function qr(e,t){let n=[],r=new Object,i,o={value:{},offset:0,length:0,type:"object",parent:void 0},s=!1;function a(u,l,c,p){o.value=u,o.offset=l,o.length=c,o.type=p,o.colonOffset=void 0,i=o}try{Cn(e,{onObjectBegin:(u,l)=>{if(t<=u)throw r;i=void 0,s=t>u,n.push("")},onObjectProperty:(u,l,c)=>{if(t<l||(a(u,l,c,"property"),n[n.length-1]=u,t<=l+c))throw r},onObjectEnd:(u,l)=>{if(t<=u)throw r;i=void 0,n.pop()},onArrayBegin:(u,l)=>{if(t<=u)throw r;i=void 0,n.push(0)},onArrayEnd:(u,l)=>{if(t<=u)throw r;i=void 0,n.pop()},onLiteralValue:(u,l,c)=>{if(t<l||(a(u,l,c,ac(u)),t<=l+c))throw r},onSeparator:(u,l,c)=>{if(t<=l)throw r;if(u===":"&&i&&i.type==="property")i.colonOffset=l,s=!1,i=void 0;else if(u===","){let p=n[n.length-1];typeof p=="number"?n[n.length-1]=p+1:(s=!0,n[n.length-1]=""),i=void 0}}})}catch(u){if(u!==r)throw u}return{path:n,previousNode:i,isAtPropertyKey:s,matches:u=>{let l=0;for(let c=0;l<u.length&&c<n.length;c++)if(u[l]===n[c]||u[l]==="*")l++;else if(u[l]!=="**")return!1;return l===u.length}}}function Cn(e,t,n=On.DEFAULT){let r=wt(e,!1),i=[];function o(g){return g?()=>g(r.getTokenOffset(),r.getTokenLength(),r.getTokenStartLine(),r.getTokenStartCharacter()):()=>!0}function s(g){return g?()=>g(r.getTokenOffset(),r.getTokenLength(),r.getTokenStartLine(),r.getTokenStartCharacter(),()=>i.slice()):()=>!0}function a(g){return g?A=>g(A,r.getTokenOffset(),r.getTokenLength(),r.getTokenStartLine(),r.getTokenStartCharacter()):()=>!0}function u(g){return g?A=>g(A,r.getTokenOffset(),r.getTokenLength(),r.getTokenStartLine(),r.getTokenStartCharacter(),()=>i.slice()):()=>!0}let l=s(t.onObjectBegin),c=u(t.onObjectProperty),p=o(t.onObjectEnd),f=s(t.onArrayBegin),m=o(t.onArrayEnd),h=u(t.onLiteralValue),y=a(t.onSeparator),k=o(t.onComment),C=a(t.onError),R=n&&n.disallowComments,E=n&&n.allowTrailingComma;function _(){for(;;){let g=r.scan();switch(r.getTokenError()){case 4:P(14);break;case 5:P(15);break;case 3:P(13);break;case 1:R||P(11);break;case 2:P(12);break;case 6:P(16);break}switch(g){case 12:case 13:R?P(10):k();break;case 16:P(1);break;case 15:case 14:break;default:return g}}}function P(g,A=[],T=[]){if(C(g),A.length+T.length>0){let x=r.getToken();for(;x!==17;){if(A.indexOf(x)!==-1){_();break}else if(T.indexOf(x)!==-1)break;x=_()}}}function L(g){let A=r.getTokenValue();return g?h(A):(c(A),i.push(A)),_(),!0}function S(){switch(r.getToken()){case 11:let g=r.getTokenValue(),A=Number(g);isNaN(A)&&(P(2),A=0),h(A);break;case 7:h(null);break;case 8:h(!0);break;case 9:h(!1);break;default:return!1}return _(),!0}function v(){return r.getToken()!==10?(P(3,[],[2,5]),!1):(L(!1),r.getToken()===6?(y(":"),_(),d()||P(4,[],[2,5])):P(5,[],[2,5]),i.pop(),!0)}function b(){l(),_();let g=!1;for(;r.getToken()!==2&&r.getToken()!==17;){if(r.getToken()===5){if(g||P(4,[],[]),y(","),_(),r.getToken()===2&&E)break}else g&&P(6,[],[]);v()||P(4,[],[2,5]),g=!0}return p(),r.getToken()!==2?P(7,[2],[]):_(),!0}function O(){f(),_();let g=!0,A=!1;for(;r.getToken()!==4&&r.getToken()!==17;){if(r.getToken()===5){if(A||P(4,[],[]),y(","),_(),r.getToken()===4&&E)break}else A&&P(6,[],[]);g?(i.push(0),g=!1):i[i.length-1]++,d()||P(4,[],[4,5]),A=!0}return m(),g||i.pop(),r.getToken()!==4?P(8,[4],[]):_(),!0}function d(){switch(r.getToken()){case 3:return O();case 1:return b();case 10:return L(!0);default:return S()}}return _(),r.getToken()===17?n.allowEmptyContent?!0:(P(4,[],[]),!1):d()?(r.getToken()!==17&&P(9,[],[]),!0):(P(4,[],[]),!1)}function ac(e){switch(typeof e){case"boolean":return"boolean";case"number":return"number";case"string":return"string";case"object":{if(e){if(Array.isArray(e))return"array"}else return"null";return"object"}default:return"null"}}var Br=wt,Bt;(function(e){e[e.None=0]="None",e[e.UnexpectedEndOfComment=1]="UnexpectedEndOfComment",e[e.UnexpectedEndOfString=2]="UnexpectedEndOfString",e[e.UnexpectedEndOfNumber=3]="UnexpectedEndOfNumber",e[e.InvalidUnicode=4]="InvalidUnicode",e[e.InvalidEscapeCharacter=5]="InvalidEscapeCharacter",e[e.InvalidCharacter=6]="InvalidCharacter"})(Bt||(Bt={}));var He;(function(e){e[e.OpenBraceToken=1]="OpenBraceToken",e[e.CloseBraceToken=2]="CloseBraceToken",e[e.OpenBracketToken=3]="OpenBracketToken",e[e.CloseBracketToken=4]="CloseBracketToken",e[e.CommaToken=5]="CommaToken",e[e.ColonToken=6]="ColonToken",e[e.NullKeyword=7]="NullKeyword",e[e.TrueKeyword=8]="TrueKeyword",e[e.FalseKeyword=9]="FalseKeyword",e[e.StringLiteral=10]="StringLiteral",e[e.NumericLiteral=11]="NumericLiteral",e[e.LineCommentTrivia=12]="LineCommentTrivia",e[e.BlockCommentTrivia=13]="BlockCommentTrivia",e[e.LineBreakTrivia=14]="LineBreakTrivia",e[e.Trivia=15]="Trivia",e[e.Unknown=16]="Unknown",e[e.EOF=17]="EOF"})(He||(He={}));var Pn=qr;var Gr=Cn;var Ur;(function(e){e[e.InvalidSymbol=1]="InvalidSymbol",e[e.InvalidNumberFormat=2]="InvalidNumberFormat",e[e.PropertyNameExpected=3]="PropertyNameExpected",e[e.ValueExpected=4]="ValueExpected",e[e.ColonExpected=5]="ColonExpected",e[e.CommaExpected=6]="CommaExpected",e[e.CloseBraceExpected=7]="CloseBraceExpected",e[e.CloseBracketExpected=8]="CloseBracketExpected",e[e.EndOfFileExpected=9]="EndOfFileExpected",e[e.InvalidCommentToken=10]="InvalidCommentToken",e[e.UnexpectedEndOfComment=11]="UnexpectedEndOfComment",e[e.UnexpectedEndOfString=12]="UnexpectedEndOfString",e[e.UnexpectedEndOfNumber=13]="UnexpectedEndOfNumber",e[e.InvalidUnicode=14]="InvalidUnicode",e[e.InvalidEscapeCharacter=15]="InvalidEscapeCharacter",e[e.InvalidCharacter=16]="InvalidCharacter"})(Ur||(Ur={}));var V=require("vscode"),Kr=require("path");var q=require("vscode"),Ln=60,In=Ln*60,At=In*24,Wr=At*7,Yr=At*30,Vr=At*365;function Nn(e,t,n,r){typeof e!="number"&&(e=e.getTime());let i=Math.round((new Date().getTime()-e)/1e3);if(i<-30)return q.l10n.t("in {0}",Nn(new Date().getTime()+i*1e3,!1));if(!r&&i<30)return q.l10n.t("now");let o;return i<Ln?(o=i,t?o===1?n?q.l10n.t("{0} second ago",o):q.l10n.t("{0} sec ago",o):n?q.l10n.t("{0} seconds ago",o):q.l10n.t("{0} secs ago",o):o===1?n?q.l10n.t("{0} second",o):q.l10n.t("{0} sec",o):n?q.l10n.t("{0} seconds",o):q.l10n.t("{0} secs",o)):i<In?(o=Math.floor(i/Ln),t?o===1?n?q.l10n.t("{0} minute ago",o):q.l10n.t("{0} min ago",o):n?q.l10n.t("{0} minutes ago",o):q.l10n.t("{0} mins ago",o):o===1?n?q.l10n.t("{0} minute",o):q.l10n.t("{0} min",o):n?q.l10n.t("{0} minutes",o):q.l10n.t("{0} mins",o)):i<At?(o=Math.floor(i/In),t?o===1?n?q.l10n.t("{0} hour ago",o):q.l10n.t("{0} hr ago",o):n?q.l10n.t("{0} hours ago",o):q.l10n.t("{0} hrs ago",o):o===1?n?q.l10n.t("{0} hour",o):q.l10n.t("{0} hr",o):n?q.l10n.t("{0} hours",o):q.l10n.t("{0} hrs",o)):i<Wr?(o=Math.floor(i/At),t?o===1?q.l10n.t("{0} day ago",o):q.l10n.t("{0} days ago",o):o===1?q.l10n.t("{0} day",o):q.l10n.t("{0} days",o)):i<Yr?(o=Math.floor(i/Wr),t?o===1?n?q.l10n.t("{0} week ago",o):q.l10n.t("{0} wk ago",o):n?q.l10n.t("{0} weeks ago",o):q.l10n.t("{0} wks ago",o):o===1?n?q.l10n.t("{0} week",o):q.l10n.t("{0} wk",o):n?q.l10n.t("{0} weeks",o):q.l10n.t("{0} wks",o)):i<Vr?(o=Math.floor(i/Yr),t?o===1?n?q.l10n.t("{0} month ago",o):q.l10n.t("{0} mo ago",o):n?q.l10n.t("{0} months ago",o):q.l10n.t("{0} mos ago",o):o===1?n?q.l10n.t("{0} month",o):q.l10n.t("{0} mo",o):n?q.l10n.t("{0} months",o):q.l10n.t("{0} mos",o)):(o=Math.floor(i/Vr),t?o===1?n?q.l10n.t("{0} year ago",o):q.l10n.t("{0} yr ago",o):n?q.l10n.t("{0} years ago",o):q.l10n.t("{0} yrs ago",o):o===1?n?q.l10n.t("{0} year",o):q.l10n.t("{0} yr",o):n?q.l10n.t("{0} years",o):q.l10n.t("{0} yrs",o))}var hc=40,Fn="Visual Studio Code",Gt=class{constructor(t,n){this.xhr=t;this.npmCommandPath=n}mostDependedOn=["lodash","async","underscore","request","commander","express","debug","chalk","colors","q","coffee-script","mkdirp","optimist","through2","yeoman-generator","moment","bluebird","glob","gulp-util","minimist","cheerio","pug","redis","node-uuid","socket","io","uglify-js","winston","through","fs-extra","handlebars","body-parser","rimraf","mime","semver","mongodb","jquery","grunt","connect","yosay","underscore","string","xml2js","ejs","mongoose","marked","extend","mocha","superagent","js-yaml","xtend","shelljs","gulp","yargs","browserify","minimatch","react","less","prompt","inquirer","ws","event-stream","inherits","mysql","esprima","jsdom","stylus","when","readable-stream","aws-sdk","concat-stream","chai","Thenable","wrench"];knownScopes=["@types","@angular","@babel","@nuxtjs","@vue","@bazel"];getDocumentSelector(){return[{language:"json",scheme:"*",pattern:"**/package.json"}]}collectDefaultSuggestions(t,n){let r={name:"${1:name}",description:"${2:description}",authors:"${3:author}",version:"${4:1.0.0}",main:"${5:pathToMain}",dependencies:{}},i=new V.CompletionItem(V.l10n.t("Default package.json"));return i.kind=V.CompletionItemKind.Module,i.insertText=new V.SnippetString(JSON.stringify(r,null,"	")),n.add(i),Promise.resolve(null)}isEnabled(){return this.npmCommandPath||this.onlineEnabled()}onlineEnabled(){return!!V.workspace.getConfiguration("npm").get("fetchOnlinePackageInfo")}collectPropertySuggestions(t,n,r,i,o,s){if(!this.isEnabled())return null;if(n.matches(["dependencies"])||n.matches(["devDependencies"])||n.matches(["optionalDependencies"])||n.matches(["peerDependencies"])){let a;if(r.length>0){if(r[0]==="@"){if(r.indexOf("/")!==-1)return this.collectScopedPackages(r,i,o,s);for(let u of this.knownScopes){let l=new V.CompletionItem(u);l.kind=V.CompletionItemKind.Property,l.insertText=new V.SnippetString().appendText(`"${u}/`).appendTabstop().appendText('"'),l.filterText=JSON.stringify(u),l.documentation="",l.command={title:"",command:"editor.action.triggerSuggest"},s.add(l)}s.setAsIncomplete()}return a=`https://registry.npmjs.org/-/v1/search?size=${hc}&text=${encodeURIComponent(r)}`,this.xhr({url:a,headers:{agent:Fn}}).then(u=>{if(u.status===200){try{let l=JSON.parse(u.responseText);if(l&&l.objects&&Array.isArray(l.objects)){let c=l.objects;for(let p of c)this.processPackage(p.package,i,o,s)}}catch{}s.setAsIncomplete()}else return s.error(V.l10n.t("Request to the NPM repository failed: {0}",u.responseText)),0},u=>(s.error(V.l10n.t("Request to the NPM repository failed: {0}",u.responseText)),0))}else return this.mostDependedOn.forEach(u=>{let l=new V.SnippetString().appendText(JSON.stringify(u));i&&(l.appendText(': "').appendTabstop().appendText('"'),o||l.appendText(","));let c=new V.CompletionItem(u);c.kind=V.CompletionItemKind.Property,c.insertText=l,c.filterText=JSON.stringify(u),c.documentation="",s.add(c)}),this.collectScopedPackages(r,i,o,s),s.setAsIncomplete(),Promise.resolve(null)}return null}collectScopedPackages(t,n,r,i){let o=t.split("/");if(o.length===2&&o[0].length>1){let s=o[0].substr(1),a=o[1];a.length<4&&(a="");let u=`https://registry.npmjs.com/-/v1/search?text=scope:${s}%20${a}&size=250`;return this.xhr({url:u,headers:{agent:Fn}}).then(l=>{if(l.status===200){try{let c=JSON.parse(l.responseText);if(c&&Array.isArray(c.objects)){let p=c.objects;for(let f of p)this.processPackage(f.package,n,r,i)}}catch{}i.setAsIncomplete()}else i.error(V.l10n.t("Request to the NPM repository failed: {0}",l.responseText));return null})}return Promise.resolve(null)}async collectValueSuggestions(t,n,r){if(!this.isEnabled())return null;if(n.matches(["dependencies","*"])||n.matches(["devDependencies","*"])||n.matches(["optionalDependencies","*"])||n.matches(["peerDependencies","*"])){let i=n.path[n.path.length-1];if(typeof i=="string"){let o=await this.fetchPackageInfo(i,t);if(o&&o.version){let s=JSON.stringify(o.version),a=new V.CompletionItem(s);a.kind=V.CompletionItemKind.Property,a.insertText=s,a.documentation=V.l10n.t("The currently latest version of the package"),r.add(a),s=JSON.stringify("^"+o.version),a=new V.CompletionItem(s),a.kind=V.CompletionItemKind.Property,a.insertText=s,a.documentation=V.l10n.t("Matches the most recent major version (1.x.x)"),r.add(a),s=JSON.stringify("~"+o.version),a=new V.CompletionItem(s),a.kind=V.CompletionItemKind.Property,a.insertText=s,a.documentation=V.l10n.t("Matches the most recent minor version (1.2.x)"),r.add(a)}}}return null}getDocumentation(t,n,r,i,o){let s=new V.MarkdownString;return t&&s.appendText(t),n&&(s.appendText(`

`),s.appendText(r?V.l10n.t("Latest version: {0} published {1}",n,Nn(Date.parse(r),!0,!0)):V.l10n.t("Latest version: {0}",n))),o&&(s.appendText(`

`),s.appendText(V.l10n.t("Installed version: {0}",o))),i&&(s.appendText(`

`),s.appendText(i)),s}resolveSuggestion(t,n){if(n.kind===V.CompletionItemKind.Property&&!n.documentation){let r=n.label;return typeof r!="string"&&(r=r.label),this.fetchPackageInfo(r,t).then(i=>i?(n.documentation=this.getDocumentation(i.description,i.version,i.time,i.homepage,i.installedVersion),n):null)}return null}isValidNPMName(t){if(!t||t.length>214||t.match(/^[-_.\s]/))return!1;let n=t.match(/^(?:@([^/~\s)('!*]+?)[/])?([^/~)('!*\s]+?)$/);if(n){let r=n[1];if(r&&encodeURIComponent(r)!==r)return!1;let i=n[2];return encodeURIComponent(i)===i}return!1}async fetchPackageInfo(t,n){if(!this.isValidNPMName(t))return;let r,i;return this.npmCommandPath&&([r,i]=await Promise.all([this.npmView(this.npmCommandPath,t,n),this.npmListInstalledVersion(this.npmCommandPath,t,n)])),!r&&this.onlineEnabled()&&(r=await this.npmjsView(t)),i&&(r=r??{description:""},r.installedVersion=i),r}async runNpmCommand(t,n,r){let i=await import("child_process");return new Promise((o,s)=>{let a=r&&r.scheme==="file"?(0,Kr.dirname)(r.fsPath):void 0,u={...process.env,COREPACK_ENABLE_AUTO_PIN:"0",COREPACK_ENABLE_PROJECT_SPEC:"0"},l={cwd:a,env:u},c=t;process.platform==="win32"&&(l={cwd:a,env:u,shell:!0},c=`"${t}"`),i.execFile(c,n,l,(p,f)=>{o(p?void 0:f.toString())})})}async npmView(t,n,r){let i=["view","--json","--",`${n}@latest`,"description","homepage","version","time"],o=await this.runNpmCommand(t,i,r);if(o)try{let s=JSON.parse(o),a=s.version;return{description:s.description,version:s.version,time:a?s.time?.[a]:void 0,homepage:s.homepage}}catch{}}async npmjsView(t){let n="https://registry.npmjs.org/"+encodeURIComponent(t);try{let r=await this.xhr({url:n,headers:{agent:Fn}}),i=JSON.parse(r.responseText),o=i["dist-tags"]?.latest||Object.keys(i.versions).pop()||"";return{description:i.description||"",version:o,time:i.time?.[o],homepage:i.homepage||""}}catch{}}async npmListInstalledVersion(t,n,r){let i=["ls","--json","--depth=0","--",n],o=await this.runNpmCommand(t,i,r);if(o)try{let a=JSON.parse(o)?.dependencies?.[n]?.version;return typeof a=="string"?a:void 0}catch{}}getInfoContribution(t,n){if(!this.isEnabled())return null;if(n.matches(["dependencies","*"])||n.matches(["devDependencies","*"])||n.matches(["optionalDependencies","*"])||n.matches(["peerDependencies","*"])){let r=n.path[n.path.length-1];if(typeof r=="string")return this.fetchPackageInfo(r,t).then(i=>i?[this.getDocumentation(i.description,i.version,i.time,i.homepage,i.installedVersion)]:null)}return null}processPackage(t,n,r,i){if(t&&t.name){let o=t.name,s=new V.SnippetString().appendText(JSON.stringify(o));n&&(s.appendText(': "'),t.version?s.appendVariable("version",t.version):s.appendTabstop(),s.appendText('"'),r||s.appendText(","));let a=new V.CompletionItem(o);a.kind=V.CompletionItemKind.Property,a.insertText=s,a.filterText=JSON.stringify(o),a.documentation=this.getDocumentation(t.description,t.version,void 0,t?.links?.homepage,void 0),i.add(a)}}};var ve=require("vscode");function Jr(e,t){let n=[new Gt(e,t)],r=[];return n.forEach(i=>{let o=i.getDocumentSelector();r.push(ve.languages.registerCompletionItemProvider(o,new Dn(i),'"',":")),r.push(ve.languages.registerHoverProvider(o,new Mn(i)))}),ve.Disposable.from(...r)}var Mn=class{constructor(t){this.jsonContribution=t}provideHover(t,n,r){let i=t.offsetAt(n),o=Pn(t.getText(),i);if(!o.previousNode)return null;let s=o.previousNode;if(s&&s.offset<=i&&i<=s.offset+s.length){let a=this.jsonContribution.getInfoContribution(t.uri,o);if(a)return a.then(u=>{let l=new ve.Range(t.positionAt(s.offset),t.positionAt(s.offset+s.length));return{contents:u||[],range:l}})}return null}},Dn=class{constructor(t){this.jsonContribution=t}lastResource;resolveCompletionItem(t,n){if(this.jsonContribution.resolveSuggestion){let r=this.jsonContribution.resolveSuggestion(this.lastResource,t);if(r)return r}return Promise.resolve(t)}provideCompletionItems(t,n,r){this.lastResource=t.uri;let i=this.getCurrentWord(t,n),o,s=[],a=!1,u=t.offsetAt(n),l=Pn(t.getText(),u),c=l.previousNode;c&&c.offset<=u&&u<=c.offset+c.length&&(c.type==="property"||c.type==="string"||c.type==="number"||c.type==="boolean"||c.type==="null")?o=new ve.Range(t.positionAt(c.offset),t.positionAt(c.offset+c.length)):o=new ve.Range(t.positionAt(u-i.length),n);let p={},f={add:h=>{let y=typeof h.label=="string"?h.label:h.label.label;p[y]||(p[y]=!0,h.range={replacing:o,inserting:new ve.Range(o.start,o.start)},s.push(h))},setAsIncomplete:()=>a=!0,error:h=>console.error(h),log:h=>console.log(h)},m=null;if(l.isAtPropertyKey){let h=Br(t.getText(),!0),y=!l.previousNode||!this.hasColonAfter(h,l.previousNode.offset+l.previousNode.length),k=this.isLast(h,t.offsetAt(n));m=this.jsonContribution.collectPropertySuggestions(t.uri,l,i,y,k,f)}else l.path.length===0?m=this.jsonContribution.collectDefaultSuggestions(t.uri,f):m=this.jsonContribution.collectValueSuggestions(t.uri,l,f);return m?m.then(()=>s.length>0||a?new ve.CompletionList(s,a):null):null}getCurrentWord(t,n){let r=n.character-1,i=t.lineAt(n.line).text;for(;r>=0&&` 	
\r\v":{[,`.indexOf(i.charAt(r))===-1;)r--;return i.substring(r+1,n.character)}isLast(t,n){t.setPosition(n);let r=t.scan();return r===He.StringLiteral&&t.getTokenError()===Bt.UnexpectedEndOfString&&(r=t.scan()),r===He.CloseBraceToken||r===He.EOF}hasColonAfter(t,n){return t.setPosition(n),t.scan()===He.ColonToken}};var Pe=me(require("vscode"));var $=require("vscode"),mt=me(require("path")),lu=me(require("fs")),fu=me(mi());var yi;(()=>{"use strict";var e={470:i=>{function o(u){if(typeof u!="string")throw new TypeError("Path must be a string. Received "+JSON.stringify(u))}function s(u,l){for(var c,p="",f=0,m=-1,h=0,y=0;y<=u.length;++y){if(y<u.length)c=u.charCodeAt(y);else{if(c===47)break;c=47}if(c===47){if(!(m===y-1||h===1))if(m!==y-1&&h===2){if(p.length<2||f!==2||p.charCodeAt(p.length-1)!==46||p.charCodeAt(p.length-2)!==46){if(p.length>2){var k=p.lastIndexOf("/");if(k!==p.length-1){k===-1?(p="",f=0):f=(p=p.slice(0,k)).length-1-p.lastIndexOf("/"),m=y,h=0;continue}}else if(p.length===2||p.length===1){p="",f=0,m=y,h=0;continue}}l&&(p.length>0?p+="/..":p="..",f=2)}else p.length>0?p+="/"+u.slice(m+1,y):p=u.slice(m+1,y),f=y-m-1;m=y,h=0}else c===46&&h!==-1?++h:h=-1}return p}var a={resolve:function(){for(var u,l="",c=!1,p=arguments.length-1;p>=-1&&!c;p--){var f;p>=0?f=arguments[p]:(u===void 0&&(u=process.cwd()),f=u),o(f),f.length!==0&&(l=f+"/"+l,c=f.charCodeAt(0)===47)}return l=s(l,!c),c?l.length>0?"/"+l:"/":l.length>0?l:"."},normalize:function(u){if(o(u),u.length===0)return".";var l=u.charCodeAt(0)===47,c=u.charCodeAt(u.length-1)===47;return(u=s(u,!l)).length!==0||l||(u="."),u.length>0&&c&&(u+="/"),l?"/"+u:u},isAbsolute:function(u){return o(u),u.length>0&&u.charCodeAt(0)===47},join:function(){if(arguments.length===0)return".";for(var u,l=0;l<arguments.length;++l){var c=arguments[l];o(c),c.length>0&&(u===void 0?u=c:u+="/"+c)}return u===void 0?".":a.normalize(u)},relative:function(u,l){if(o(u),o(l),u===l||(u=a.resolve(u))===(l=a.resolve(l)))return"";for(var c=1;c<u.length&&u.charCodeAt(c)===47;++c);for(var p=u.length,f=p-c,m=1;m<l.length&&l.charCodeAt(m)===47;++m);for(var h=l.length-m,y=f<h?f:h,k=-1,C=0;C<=y;++C){if(C===y){if(h>y){if(l.charCodeAt(m+C)===47)return l.slice(m+C+1);if(C===0)return l.slice(m+C)}else f>y&&(u.charCodeAt(c+C)===47?k=C:C===0&&(k=0));break}var R=u.charCodeAt(c+C);if(R!==l.charCodeAt(m+C))break;R===47&&(k=C)}var E="";for(C=c+k+1;C<=p;++C)C!==p&&u.charCodeAt(C)!==47||(E.length===0?E+="..":E+="/..");return E.length>0?E+l.slice(m+k):(m+=k,l.charCodeAt(m)===47&&++m,l.slice(m))},_makeLong:function(u){return u},dirname:function(u){if(o(u),u.length===0)return".";for(var l=u.charCodeAt(0),c=l===47,p=-1,f=!0,m=u.length-1;m>=1;--m)if((l=u.charCodeAt(m))===47){if(!f){p=m;break}}else f=!1;return p===-1?c?"/":".":c&&p===1?"//":u.slice(0,p)},basename:function(u,l){if(l!==void 0&&typeof l!="string")throw new TypeError('"ext" argument must be a string');o(u);var c,p=0,f=-1,m=!0;if(l!==void 0&&l.length>0&&l.length<=u.length){if(l.length===u.length&&l===u)return"";var h=l.length-1,y=-1;for(c=u.length-1;c>=0;--c){var k=u.charCodeAt(c);if(k===47){if(!m){p=c+1;break}}else y===-1&&(m=!1,y=c+1),h>=0&&(k===l.charCodeAt(h)?--h==-1&&(f=c):(h=-1,f=y))}return p===f?f=y:f===-1&&(f=u.length),u.slice(p,f)}for(c=u.length-1;c>=0;--c)if(u.charCodeAt(c)===47){if(!m){p=c+1;break}}else f===-1&&(m=!1,f=c+1);return f===-1?"":u.slice(p,f)},extname:function(u){o(u);for(var l=-1,c=0,p=-1,f=!0,m=0,h=u.length-1;h>=0;--h){var y=u.charCodeAt(h);if(y!==47)p===-1&&(f=!1,p=h+1),y===46?l===-1?l=h:m!==1&&(m=1):l!==-1&&(m=-1);else if(!f){c=h+1;break}}return l===-1||p===-1||m===0||m===1&&l===p-1&&l===c+1?"":u.slice(l,p)},format:function(u){if(u===null||typeof u!="object")throw new TypeError('The "pathObject" argument must be of type Object. Received type '+typeof u);return(function(l,c){var p=c.dir||c.root,f=c.base||(c.name||"")+(c.ext||"");return p?p===c.root?p+f:p+"/"+f:f})(0,u)},parse:function(u){o(u);var l={root:"",dir:"",base:"",ext:"",name:""};if(u.length===0)return l;var c,p=u.charCodeAt(0),f=p===47;f?(l.root="/",c=1):c=0;for(var m=-1,h=0,y=-1,k=!0,C=u.length-1,R=0;C>=c;--C)if((p=u.charCodeAt(C))!==47)y===-1&&(k=!1,y=C+1),p===46?m===-1?m=C:R!==1&&(R=1):m!==-1&&(R=-1);else if(!k){h=C+1;break}return m===-1||y===-1||R===0||R===1&&m===y-1&&m===h+1?y!==-1&&(l.base=l.name=h===0&&f?u.slice(1,y):u.slice(h,y)):(h===0&&f?(l.name=u.slice(1,m),l.base=u.slice(1,y)):(l.name=u.slice(h,m),l.base=u.slice(h,y)),l.ext=u.slice(m,y)),h>0?l.dir=u.slice(0,h-1):f&&(l.dir="/"),l},sep:"/",delimiter:":",win32:null,posix:null};a.posix=a,i.exports=a}},t={};function n(i){var o=t[i];if(o!==void 0)return o.exports;var s=t[i]={exports:{}};return e[i](s,s.exports,n),s.exports}n.d=(i,o)=>{for(var s in o)n.o(o,s)&&!n.o(i,s)&&Object.defineProperty(i,s,{enumerable:!0,get:o[s]})},n.o=(i,o)=>Object.prototype.hasOwnProperty.call(i,o),n.r=i=>{typeof Symbol<"u"&&Symbol.toStringTag&&Object.defineProperty(i,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(i,"__esModule",{value:!0})};var r={};(()=>{let i;n.r(r),n.d(r,{URI:()=>f,Utils:()=>O}),typeof process=="object"?i=process.platform==="win32":typeof navigator=="object"&&(i=navigator.userAgent.indexOf("Windows")>=0);let o=/^\w[\w\d+.-]*$/,s=/^\//,a=/^\/\//;function u(d,g){if(!d.scheme&&g)throw new Error(`[UriError]: Scheme is missing: {scheme: "", authority: "${d.authority}", path: "${d.path}", query: "${d.query}", fragment: "${d.fragment}"}`);if(d.scheme&&!o.test(d.scheme))throw new Error("[UriError]: Scheme contains illegal characters.");if(d.path){if(d.authority){if(!s.test(d.path))throw new Error('[UriError]: If a URI contains an authority component, then the path component must either be empty or begin with a slash ("/") character')}else if(a.test(d.path))throw new Error('[UriError]: If a URI does not contain an authority component, then the path cannot begin with two slash characters ("//")')}}let l="",c="/",p=/^(([^:/?#]+?):)?(\/\/([^/?#]*))?([^?#]*)(\?([^#]*))?(#(.*))?/;class f{static isUri(g){return g instanceof f||!!g&&typeof g.authority=="string"&&typeof g.fragment=="string"&&typeof g.path=="string"&&typeof g.query=="string"&&typeof g.scheme=="string"&&typeof g.fsPath=="string"&&typeof g.with=="function"&&typeof g.toString=="function"}scheme;authority;path;query;fragment;constructor(g,A,T,x,w,F=!1){typeof g=="object"?(this.scheme=g.scheme||l,this.authority=g.authority||l,this.path=g.path||l,this.query=g.query||l,this.fragment=g.fragment||l):(this.scheme=(function(D,H){return D||H?D:"file"})(g,F),this.authority=A||l,this.path=(function(D,H){switch(D){case"https":case"http":case"file":H?H[0]!==c&&(H=c+H):H=c}return H})(this.scheme,T||l),this.query=x||l,this.fragment=w||l,u(this,F))}get fsPath(){return R(this,!1)}with(g){if(!g)return this;let{scheme:A,authority:T,path:x,query:w,fragment:F}=g;return A===void 0?A=this.scheme:A===null&&(A=l),T===void 0?T=this.authority:T===null&&(T=l),x===void 0?x=this.path:x===null&&(x=l),w===void 0?w=this.query:w===null&&(w=l),F===void 0?F=this.fragment:F===null&&(F=l),A===this.scheme&&T===this.authority&&x===this.path&&w===this.query&&F===this.fragment?this:new h(A,T,x,w,F)}static parse(g,A=!1){let T=p.exec(g);return T?new h(T[2]||l,L(T[4]||l),L(T[5]||l),L(T[7]||l),L(T[9]||l),A):new h(l,l,l,l,l)}static file(g){let A=l;if(i&&(g=g.replace(/\\/g,c)),g[0]===c&&g[1]===c){let T=g.indexOf(c,2);T===-1?(A=g.substring(2),g=c):(A=g.substring(2,T),g=g.substring(T)||c)}return new h("file",A,g,l,l)}static from(g){let A=new h(g.scheme,g.authority,g.path,g.query,g.fragment);return u(A,!0),A}toString(g=!1){return E(this,g)}toJSON(){return this}static revive(g){if(g){if(g instanceof f)return g;{let A=new h(g);return A._formatted=g.external,A._fsPath=g._sep===m?g.fsPath:null,A}}return g}}let m=i?1:void 0;class h extends f{_formatted=null;_fsPath=null;get fsPath(){return this._fsPath||(this._fsPath=R(this,!1)),this._fsPath}toString(g=!1){return g?E(this,!0):(this._formatted||(this._formatted=E(this,!1)),this._formatted)}toJSON(){let g={$mid:1};return this._fsPath&&(g.fsPath=this._fsPath,g._sep=m),this._formatted&&(g.external=this._formatted),this.path&&(g.path=this.path),this.scheme&&(g.scheme=this.scheme),this.authority&&(g.authority=this.authority),this.query&&(g.query=this.query),this.fragment&&(g.fragment=this.fragment),g}}let y={58:"%3A",47:"%2F",63:"%3F",35:"%23",91:"%5B",93:"%5D",64:"%40",33:"%21",36:"%24",38:"%26",39:"%27",40:"%28",41:"%29",42:"%2A",43:"%2B",44:"%2C",59:"%3B",61:"%3D",32:"%20"};function k(d,g,A){let T,x=-1;for(let w=0;w<d.length;w++){let F=d.charCodeAt(w);if(F>=97&&F<=122||F>=65&&F<=90||F>=48&&F<=57||F===45||F===46||F===95||F===126||g&&F===47||A&&F===91||A&&F===93||A&&F===58)x!==-1&&(T+=encodeURIComponent(d.substring(x,w)),x=-1),T!==void 0&&(T+=d.charAt(w));else{T===void 0&&(T=d.substr(0,w));let D=y[F];D!==void 0?(x!==-1&&(T+=encodeURIComponent(d.substring(x,w)),x=-1),T+=D):x===-1&&(x=w)}}return x!==-1&&(T+=encodeURIComponent(d.substring(x))),T!==void 0?T:d}function C(d){let g;for(let A=0;A<d.length;A++){let T=d.charCodeAt(A);T===35||T===63?(g===void 0&&(g=d.substr(0,A)),g+=y[T]):g!==void 0&&(g+=d[A])}return g!==void 0?g:d}function R(d,g){let A;return A=d.authority&&d.path.length>1&&d.scheme==="file"?`//${d.authority}${d.path}`:d.path.charCodeAt(0)===47&&(d.path.charCodeAt(1)>=65&&d.path.charCodeAt(1)<=90||d.path.charCodeAt(1)>=97&&d.path.charCodeAt(1)<=122)&&d.path.charCodeAt(2)===58?g?d.path.substr(1):d.path[1].toLowerCase()+d.path.substr(2):d.path,i&&(A=A.replace(/\//g,"\\")),A}function E(d,g){let A=g?C:k,T="",{scheme:x,authority:w,path:F,query:D,fragment:H}=d;if(x&&(T+=x,T+=":"),(w||x==="file")&&(T+=c,T+=c),w){let j=w.indexOf("@");if(j!==-1){let B=w.substr(0,j);w=w.substr(j+1),j=B.lastIndexOf(":"),j===-1?T+=A(B,!1,!1):(T+=A(B.substr(0,j),!1,!1),T+=":",T+=A(B.substr(j+1),!1,!0)),T+="@"}w=w.toLowerCase(),j=w.lastIndexOf(":"),j===-1?T+=A(w,!1,!0):(T+=A(w.substr(0,j),!1,!0),T+=w.substr(j))}if(F){if(F.length>=3&&F.charCodeAt(0)===47&&F.charCodeAt(2)===58){let j=F.charCodeAt(1);j>=65&&j<=90&&(F=`/${String.fromCharCode(j+32)}:${F.substr(3)}`)}else if(F.length>=2&&F.charCodeAt(1)===58){let j=F.charCodeAt(0);j>=65&&j<=90&&(F=`${String.fromCharCode(j+32)}:${F.substr(2)}`)}T+=A(F,!0,!1)}return D&&(T+="?",T+=A(D,!1,!1)),H&&(T+="#",T+=g?H:k(H,!1,!1)),T}function _(d){try{return decodeURIComponent(d)}catch{return d.length>3?d.substr(0,3)+_(d.substr(3)):d}}let P=/(%[0-9A-Za-z][0-9A-Za-z])+/g;function L(d){return d.match(P)?d.replace(P,(g=>_(g))):d}var S=n(470);let v=S.posix||S,b="/";var O;(function(d){d.joinPath=function(g,...A){return g.with({path:v.join(g.path,...A)})},d.resolvePath=function(g,...A){let T=g.path,x=!1;T[0]!==b&&(T=b+T,x=!0);let w=v.resolve(T,...A);return x&&w[0]===b&&!g.authority&&(w=w.substring(1)),g.with({path:w})},d.dirname=function(g){if(g.path.length===0||g.path===b)return g;let A=v.dirname(g.path);return A.length===1&&A.charCodeAt(0)===46&&(A=""),g.with({path:A})},d.basename=function(g){return v.basename(g.path)},d.extname=function(g){return v.extname(g.path)}})(O||(O={}))})(),yi=r})();var{URI:Ng,Utils:Wn}=yi;var su=me(Ii()),Je=me(require("path")),au=me(Ys()),mn=require("vscode"),rd=ou();async function dt(e){try{await mn.workspace.fs.stat(mn.Uri.file(e))}catch{return!1}return!0}async function id(e){return await dt(Je.join(e,"bun.lockb"))?{isPreferred:!0,hasLockfile:!0}:await dt(Je.join(e,"bun.lock"))?{isPreferred:!0,hasLockfile:!0}:{isPreferred:!1,hasLockfile:!1}}async function od(e){return await dt(Je.join(e,"pnpm-lock.yaml"))?{isPreferred:!0,hasLockfile:!0}:await dt(Je.join(e,"shrinkwrap.yaml"))?{isPreferred:!0,hasLockfile:!0}:await(0,su.default)("pnpm-lock.yaml",{cwd:e})?{isPreferred:!0,hasLockfile:!0}:{isPreferred:!1,hasLockfile:!1}}async function sd(e){if(await dt(Je.join(e,"yarn.lock")))return{isPreferred:!0,hasLockfile:!0};try{if(typeof rd(e)=="string")return{isPreferred:!0,hasLockfile:!1}}catch{}return{isPreferred:!1,hasLockfile:!1}}async function ad(e){let t=await dt(Je.join(e,"package-lock.json"));return{isPreferred:t,hasLockfile:t}}async function uu(e){let t=[],n=[],r=await ad(e);r.isPreferred&&(t.push("npm"),n.push(r));let i=await od(e);i.isPreferred&&(t.push("pnpm"),n.push(i));let o=await sd(e);o.isPreferred&&(t.push("yarn"),n.push(o));let s=await id(e);s.isPreferred&&(t.push("bun"),n.push(s));let a=await(0,au.default)(e);a&&!t.includes(a.name)&&(t.push(a.name),n.push({isPreferred:!0,hasLockfile:!1}));let u=0;return n.forEach(l=>u+=l.hasLockfile?1:0),{name:t[0]||"npm",multipleLockFilesDetected:u>1}}var gt=require("vscode"),Ce=(e,t=e.getText())=>{let n,r,i=!1,o,s=0,a=[];if(Gr(t,{onError(){},onObjectBegin(){s++},onObjectEnd(l){i&&(r=e.positionAt(l),i=!1),s--},onLiteralValue(l,c,p){o&&typeof l=="string"&&(a.push({...o,value:l,valueRange:new gt.Range(e.positionAt(c),e.positionAt(c+p))}),o=void 0)},onObjectProperty(l,c,p){s===1&&l==="scripts"?(i=!0,n=e.positionAt(c)):i&&(o={name:l,nameRange:new gt.Range(e.positionAt(c),e.positionAt(c+p))})}}),n!==void 0)return{location:new gt.Location(e.uri,new gt.Range(n,r??n)),scripts:a}};var pu=new RegExp("^(node_modules|.vscode-test)$","i"),yn,ze="install",xn=class{constructor(t){this.context=t}get tasksWithLocation(){return cu(this.context,!1)}async provideTasks(){return(await cu(this.context,!0)).map(n=>n.task)}async resolveTask(t){if(t.definition.script){let r=t.definition,i;if(t.scope===void 0||t.scope===$.TaskScope.Global||t.scope===$.TaskScope.Workspace)return;r.path?i=t.scope.uri.with({path:t.scope.uri.path+"/"+r.path+`${r.path.endsWith("/")?"":"/"}package.json`}):i=t.scope.uri.with({path:t.scope.uri.path+"/package.json"});let o;return r.script===ze?o=await wn(this.context,t.scope,i):o=await Ht(this.context,r.script,t.scope,i),o.definition=r,o}}};function Pr(){yn=void 0}var ud=["build","compile","watch"];function cd(e){for(let t of ud)if(e.indexOf(t)!==-1)return!0;return!1}var ld=["test"];function fd(e){for(let t of ld)if(e===t)return!0;return!1}var pd=new Set(["install","pack","pack","publish","restart","shrinkwrap","stop","test","uninstall","version"]),hd=new Set(["install","pack","pack","publish","publishOnly","restart","shrinkwrap","stop","test","uninstall","version"]);function dd(e){return pd.has(e)||hd.has(e)}function hu(e){return e&&typeof e!="number"}async function Lr(e,t,n){let r=$.workspace.getConfiguration("npm",e).get("scriptRunner","npm");return r==="auto"&&(r=await vn(e,t,n)),r}async function Ir(e,t,n){let r=$.workspace.getConfiguration("npm",e).get("packageManager","npm");return r==="auto"&&(r=await vn(e,t,n)),r}async function vn(e,t,n=!1){let{name:r,multipleLockFilesDetected:i}=await uu(e.fsPath),o="npm.multiplePMWarning.neverShow";if(n&&i&&t&&!t.globalState.get(o)){let s=$.l10n.t(`Using {0} as the preferred package manager. Found multiple lockfiles for {1}.  To resolve this issue, delete the lockfiles that don't match your preferred package manager or change the setting "npm.packageManager" to a value other than "auto".`,r,e.fsPath),a=$.l10n.t("Do not show again"),u=$.l10n.t("Learn more");$.window.showInformationMessage(s,u,a).then(l=>{switch(l){case a:t.globalState.update(o,!0);break;case u:$.env.openExternal($.Uri.parse("https://docs.npmjs.com/cli/v9/configuring-npm/package-lock-json"))}})}return r}async function*gd(){let e=new Set,t=$.workspace.workspaceFolders;if(t){for(let n of t)if(Nr(n)&&!pu.test(Wn.basename(n.uri))){let r=new $.RelativePattern(n,"**/package.json"),i=await $.workspace.findFiles(r,"**/{node_modules,.vscode-test}/**");for(let o of i)!md(n,o)&&!e.has(o.fsPath)&&(yield o,e.add(o.fsPath))}}}async function du(e,t){let n=[];if(pu.test(Wn.basename(t)))return n;let r=new $.RelativePattern(t.fsPath,"**/package.json"),i=await $.workspace.findFiles(r,"**/node_modules/**"),o=new Set;for(let s of i)if(!o.has(s.fsPath)){let a=await gu(e,s,!0);o.add(s.fsPath),n.push(...a.map(u=>({label:u.task.name,task:u.task})))}return n}async function cu(e,t){if(!yn){let n=[];for await(let r of gd()){let i=await gu(e,r,t);n.push(...i)}yn=n}return yn}function Nr(e){return $.workspace.getConfiguration("npm",e?.uri).get("autoDetect")==="on"}function md(e,t){function n(o,s){return(0,fu.default)(o,s,{dot:!0})}let r=$.workspace.getConfiguration("npm",e.uri).get("exclude"),i=mt.dirname(t.fsPath);if(r){if(Array.isArray(r)){for(let o of r)if(n(i,o))return!0}else if(n(i,r))return!0}return!1}function yd(e){return e.match(/--(inspect|debug)(-brk)?(=((\[[0-9a-fA-F:]*\]|[0-9]+\.[0-9]+\.[0-9]+\.[0-9]+|[a-zA-Z0-9\.]*):)?(\d+))?/)!==null}async function gu(e,t,n){let r=[],i=$.workspace.getWorkspaceFolder(t);if(!i)return r;let o=await bd(t);if(!o)return r;let s=[];for(let{name:a,value:u,nameRange:l}of o.scripts){let c=await Ht(e,a,i,t,u,n);s.push({task:c,location:new $.Location(t,l)})}return $.workspace.getConfiguration("npm",i).get("scriptExplorerExclude",[]).find(a=>a.includes(ze))||s.push({task:await wn(e,i,t,"install dependencies from package",n)}),s}function Dt(e,t){return t&&t.length?`${e} - ${t.substring(0,t.length-1)}`:e}function mu(e){return e.map(t=>/\s/.test(t)?{value:t,quoting:t.includes("--")?$.ShellQuoting.Weak:$.ShellQuoting.Strong}:t)}function yu(e,t){return t.path.substring(0,t.path.length-12).substring(e.path.length+1)}async function bn(e,t,n,r=!0){let i=await Lr(t,n,r);if(i==="node")return["node","--run",e];{let o=[i,"run"];return $.workspace.getConfiguration("npm",t).get("runSilent")&&o.push("--silent"),o.push(e),o}}async function Ht(e,t,n,r,i,o){let s={type:"npm",script:t},a=yu(n.uri,r);a.length&&!s.path&&(s.path=a.substring(0,a.length-1));let u=Dt(t,a),l=mt.dirname(r.fsPath),c=await bn(t,n.uri,e,o),p=c.shift(),f=new $.Task(s,n,u,"npm",new $.ShellExecution(p,mu(c),{cwd:l}));f.detail=i;let m=t.toLowerCase();return cd(m)?f.group=$.TaskGroup.Build:fd(m)?f.group=$.TaskGroup.Test:dd(m)?f.group=$.TaskGroup.Clean:i&&yd(i)&&(f.group=$.TaskGroup.Rebuild),f}async function xd(e,t,n=!0){let i=[await Ir(e,t,n),ze];return $.workspace.getConfiguration("npm",e).get("runSilent")&&i.push("--silent"),i}async function wn(e,t,n,r,i){let o={type:"npm",script:ze},s=yu(t.uri,n);s.length&&!o.path&&(o.path=s.substring(0,s.length-1));let a=Dt(ze,s),u=mt.dirname(n.fsPath),l=await xd(t.uri,e,i),c=l.shift(),p=new $.Task(o,t,a,"npm",new $.ShellExecution(c,mu(l),{cwd:u}));return p.detail=r,p.group=$.TaskGroup.Clean,p}async function xu(){if(await vd())return!0;let e=new $.CancellationTokenSource,t=setTimeout(()=>e.cancel(),1e3),n=await $.workspace.findFiles("**/package.json",void 0,1,e.token);return clearTimeout(t),n.length>0}async function vd(){let e=$.workspace.workspaceFolders;if(!e)return!1;for(let t of e)if(t.uri.scheme==="file"){let n=mt.join(t.uri.fsPath,"package.json");if(await vu(n))return!0}return!1}async function vu(e){return new Promise((t,n)=>{lu.exists(e,r=>{t(r)})})}async function bu(e,t,n){let r=n.uri,i=$.workspace.getWorkspaceFolder(r);if(i){let o=await Ht(e,t,i,r);$.tasks.executeTask(o)}}async function An(e,t,n,r){let i=await bn(t,r.uri,e,!0);$.commands.executeCommand("extension.js-debug.createDebuggerTerminal",i.join(" "),r,{cwd:n})}function wu(e,t,n){let r=Ce(e,t);if(r){for(let i of r.scripts)if(i.nameRange.start.isBeforeOrEqual(n)&&i.valueRange.end.isAfterOrEqual(n))return i.name}}async function bd(e){if(e.scheme!=="file")return;let t=e.fsPath;if(await vu(t))try{let n=await $.workspace.openTextDocument(e);return Ce(n)}catch{let r=$.l10n.t("Npm task detection: failed to parse the file {0}",e.fsPath);throw new Error(r)}}function Au(e){let t=Pe.window.activeTextEditor;if(!t)return;let n=t.document,r=n.getText(),i=wu(t.document,r,t.selection.anchor);if(i)bu(e,i,n);else{let o=Pe.l10n.t("Could not find a valid npm script at the selection.");Pe.window.showErrorMessage(o)}}async function Su(e,t){if(t.length===0)return;let n=t[0],r=await du(e,n);if(r&&r.length>0){let i=Pe.window.createQuickPick();i.placeholder="Select an npm script to run in folder",i.items=r;let o=[],s=new Promise(u=>{o.push(i.onDidAccept(()=>{o.forEach(l=>l.dispose()),u(i.selectedItems[0])})),o.push(i.onDidHide(()=>{o.forEach(l=>l.dispose()),u(void 0)}))});i.show();let a=await s;i.dispose(),a&&Pe.tasks.executeTask(a.task)}else Pe.window.showInformationMessage(`No npm scripts found in ${n.fsPath}`,{modal:!0})}var Ze=me(require("path")),G=require("vscode");var jt=class extends G.TreeItem{packages=[];workspaceFolder;constructor(t){super(t.name,G.TreeItemCollapsibleState.Expanded),this.contextValue="folder",this.resourceUri=t.uri,this.workspaceFolder=t,this.iconPath=G.ThemeIcon.Folder}addPackage(t){this.packages.push(t)}},Sn="package.json",Qe=class e extends G.TreeItem{path;folder;scripts=[];static getLabel(t){return t.length>0?Ze.join(t,Sn):Sn}constructor(t,n){super(e.getLabel(n),G.TreeItemCollapsibleState.Expanded),this.folder=t,this.path=n,this.contextValue="packageJSON",n?this.resourceUri=G.Uri.file(Ze.join(t.resourceUri.fsPath,n,Sn)):this.resourceUri=G.Uri.file(Ze.join(t.resourceUri.fsPath,Sn)),this.iconPath=G.ThemeIcon.File}addScript(t){this.scripts.push(t)}},Xe=class extends G.TreeItem{task;package;taskLocation;constructor(t,n,r){let i=n.path.length>0?r.task.name.substring(0,r.task.name.length-n.path.length-2):r.task.name;super(i,G.TreeItemCollapsibleState.None),this.taskLocation=r.location;let o=i===`${ze} `?"run":G.workspace.getConfiguration("npm").get("scriptExplorerAction")||"open",s={open:{title:"Edit Script",command:"vscode.open",arguments:[this.taskLocation?.uri,this.taskLocation?{selection:new G.Range(this.taskLocation.range.start,this.taskLocation.range.start)}:void 0]},run:{title:"Run Script",command:"npm.runScript",arguments:[this]}};this.contextValue="script",this.package=n,this.task=r.task,this.command=s[o],this.task.group&&this.task.group===G.TaskGroup.Clean?this.iconPath=new G.ThemeIcon("wrench-subaction"):this.iconPath=new G.ThemeIcon("wrench"),this.task.detail&&(this.tooltip=this.task.detail,this.description=this.task.detail)}getFolder(){return this.package.folder.workspaceFolder}},$t=class extends G.TreeItem{constructor(t){super(t,G.TreeItemCollapsibleState.None),this.contextValue="noscripts"}},En=class{constructor(t,n){this.context=t;this.taskProvider=n;let r=t.subscriptions;this.extensionContext=t,r.push(G.commands.registerCommand("npm.runScript",this.runScript,this)),r.push(G.commands.registerCommand("npm.debugScript",this.debugScript,this)),r.push(G.commands.registerCommand("npm.openScript",this.openScript,this)),r.push(G.commands.registerCommand("npm.runInstall",this.runInstall,this))}taskTree=null;extensionContext;_onDidChangeTreeData=new G.EventEmitter;onDidChangeTreeData=this._onDidChangeTreeData.event;async runScript(t){await vn(t.getFolder().uri,this.context,!0),G.tasks.executeTask(t.task)}async debugScript(t){An(this.extensionContext,t.task.definition.script,Ze.dirname(t.package.resourceUri.fsPath),t.getFolder())}findScriptPosition(t,n){let r=Ce(t);return r?n?r.scripts.find(o=>Dt(o.name,n.task.definition.path)===n.task.name)?.nameRange.start:r.location.range.start:void 0}async runInstall(t){let n;if(t instanceof Qe&&(n=t.resourceUri),!n)return;let r=await wn(this.context,t.folder.workspaceFolder,n);G.tasks.executeTask(r)}async openScript(t){let n;if(t instanceof Qe?n=t.resourceUri:t instanceof Xe&&(n=t.package.resourceUri),!n)return;let r=await G.workspace.openTextDocument(n),i=this.findScriptPosition(r,t instanceof Xe?t:void 0)||new G.Position(0,0);await G.window.showTextDocument(r,{preserveFocus:!0,selection:new G.Selection(i,i)})}refresh(){this.taskTree=null,this._onDidChangeTreeData.fire(null)}getTreeItem(t){return t}getParent(t){return t instanceof jt?null:t instanceof Qe?t.folder:t instanceof Xe?t.package:(t instanceof $t,null)}async getChildren(t){if(!this.taskTree){let n=await this.taskProvider.tasksWithLocation;if(n){let r=this.buildTaskTree(n);if(this.taskTree=this.sortTaskTree(r),this.taskTree.length===0){let i=G.l10n.t("No scripts found.");Nr()||(i=G.l10n.t('The setting "npm.autoDetect" is "off".')),this.taskTree=[new $t(i)]}}}return t instanceof jt?t.packages:t instanceof Qe?t.scripts:t instanceof Xe?[]:t instanceof $t?[]:!t&&this.taskTree?this.taskTree:[]}isInstallTask(t){return Dt("install",t.definition.path)===t.name}getTaskTreeItemLabel(t){return t===void 0?"":typeof t=="string"?t:t.label}sortTaskTree(t){return t.sort((n,r)=>{let i=this.getTaskTreeItemLabel(n.label),o=this.getTaskTreeItemLabel(r.label);return i.localeCompare(o)})}buildTaskTree(t){let n=new Map,r=new Map,i=null,o=null,s=new Map;return t.forEach(a=>{let u=a.location;if(u&&!s.has(u.uri.toString())){let c=G.workspace.getConfiguration("npm",u.uri).get("scriptExplorerExclude",[]);s.set(u.uri.toString(),c?.map(p=>RegExp(p)))}let l=u&&s.has(u.uri.toString())?s.get(u.uri.toString()):void 0;if(!(l&&l.some(c=>a.task.definition.script.match(c)))&&hu(a.task.scope)&&!this.isInstallTask(a.task)){i=n.get(a.task.scope.name),i||(i=new jt(a.task.scope),n.set(a.task.scope.name,i));let c=a.task.definition,p=c.path?c.path:"",f=Ze.join(a.task.scope.name,p);o=r.get(f),o||(o=new Qe(i,p),i.addPackage(o),r.set(f,o));let m=new Xe(this.extensionContext,o,a);o.addScript(m)}}),n.size===1?[...r.values()]:[...n.values()]}};var ku=require("path"),re=require("vscode");var yt,Eu;function Fr(e){if(!e){yt=void 0;return}e.uri===yt&&(yt=void 0)}var kn=class{constructor(t){this.context=t;t.subscriptions.push(re.commands.registerCommand("npm.runScriptFromHover",this.runScriptFromHover,this)),t.subscriptions.push(re.commands.registerCommand("npm.debugScriptFromHover",this.debugScriptFromHover,this)),t.subscriptions.push(re.workspace.onDidChangeTextDocument(r=>{Fr(r.document)}));let n=()=>re.workspace.getConfiguration("npm").get("scriptHover",!0);this.enabled=n(),t.subscriptions.push(re.workspace.onDidChangeConfiguration(r=>{r.affectsConfiguration("npm.scriptHover")&&(this.enabled=n())}))}enabled;provideHover(t,n,r){if(!this.enabled)return;let i;return(!yt||yt.fsPath!==t.uri.fsPath)&&(Eu=Ce(t),yt=t.uri),Eu?.scripts.forEach(({name:o,nameRange:s})=>{if(s.contains(n)){let a=new re.MarkdownString;a.isTrusted=!0,a.appendMarkdown(this.createRunScriptMarkdown(o,t.uri)),a.appendMarkdown(this.createDebugScriptMarkdown(o,t.uri)),i=new re.Hover(a)}}),i}createRunScriptMarkdown(t,n){let r={documentUri:n,script:t};return this.createMarkdownLink(re.l10n.t("Run Script"),"npm.runScriptFromHover",r,re.l10n.t("Run the script as a task"))}createDebugScriptMarkdown(t,n){let r={documentUri:n,script:t};return this.createMarkdownLink(re.l10n.t("Debug Script"),"npm.debugScriptFromHover",r,re.l10n.t("Runs the script under the debugger"),"|")}createMarkdownLink(t,n,r,i,o){let s=encodeURIComponent(JSON.stringify(r)),a="";return o&&(a=` ${o} `),`${a}[${t}](command:${n}?${s} "${i}")`}async runScriptFromHover(t){let n=t.script,r=t.documentUri,i=re.workspace.getWorkspaceFolder(r);if(i){let o=await Ht(this.context,n,i,r);await re.tasks.executeTask(o)}}debugScriptFromHover(t){let n=t.script,r=t.documentUri,i=re.workspace.getWorkspaceFolder(r);i&&An(this.context,n,(0,ku.dirname)(r.fsPath),i)}};var Tu=me(require("path")),pe=require("vscode");var _u=()=>pe.workspace.getConfiguration().get("debug.javascript.codelens.npmScripts"),_n=class{lensLocation=_u();changeEmitter=new pe.EventEmitter;subscriptions=[];onDidChangeCodeLenses=this.changeEmitter.event;constructor(){this.subscriptions.push(this.changeEmitter,pe.workspace.onDidChangeConfiguration(t=>{t.affectsConfiguration("debug.javascript.codelens.npmScripts")&&(this.lensLocation=_u(),this.changeEmitter.fire())}),pe.languages.registerCodeLensProvider({language:"json",pattern:"**/package.json"},this))}async provideCodeLenses(t){if(this.lensLocation==="never")return[];let n=Ce(t);if(!n)return[];let r="$(debug-start) "+pe.l10n.t("Debug"),i=Tu.dirname(t.uri.fsPath);if(this.lensLocation==="top")return[new pe.CodeLens(n.location.range,{title:r,command:"extension.js-debug.npmScript",arguments:[i]})];if(this.lensLocation==="all"){let o=pe.Uri.joinPath(t.uri,"..");return Promise.all(n.scripts.map(async({name:s,nameRange:a})=>{let u=await bn(s,o);return new pe.CodeLens(a,{title:r,command:"extension.js-debug.createDebuggerTerminal",arguments:[u.join(" "),pe.workspace.getWorkspaceFolder(t.uri),{cwd:i}]})}))}return[]}dispose(){this.subscriptions.forEach(t=>t.dispose())}};var Qu=me(Ju()),et;function qt(){Fr(),Pr(),et&&et.refresh()}async function $d(e){zu(),e.subscriptions.push(z.workspace.onDidChangeConfiguration(n=>{(n.affectsConfiguration("http.proxy")||n.affectsConfiguration("http.proxyStrictSSL"))&&zu()}));let t=await qd();e.subscriptions.push(Jr(Tn.xhr,t)),Bd(e),et=Gd(e),e.subscriptions.push(z.workspace.onDidChangeConfiguration(n=>{(n.affectsConfiguration("npm.exclude")||n.affectsConfiguration("npm.autoDetect")||n.affectsConfiguration("npm.scriptExplorerExclude")||n.affectsConfiguration("npm.runSilent")||n.affectsConfiguration("npm.packageManager")||n.affectsConfiguration("npm.scriptRunner"))&&(Pr(),et&&et.refresh()),n.affectsConfiguration("npm.scriptExplorerAction")&&et&&et.refresh()})),Wd(e),e.subscriptions.push(z.commands.registerCommand("npm.runSelectedScript",Au)),await xu()&&z.commands.executeCommand("setContext","npm:showScriptExplorer",!0),e.subscriptions.push(z.commands.registerCommand("npm.runScriptFromFolder",Su)),e.subscriptions.push(z.commands.registerCommand("npm.refresh",()=>{qt()})),e.subscriptions.push(z.commands.registerCommand("npm.scriptRunner",n=>n instanceof z.Uri?Lr(n,e,!0):"")),e.subscriptions.push(z.commands.registerCommand("npm.packageManager",n=>n instanceof z.Uri?Ir(n,e,!0):"")),e.subscriptions.push(new _n),e.subscriptions.push(z.window.registerTerminalQuickFixProvider("ms-vscode.npm-command",{provideTerminalQuickFixes({outputMatch:n}){if(!n)return;let r=n.regexMatch[1],i=[];for(let o of r.split(`
`)){let s=o.indexOf("npm",1);if(s===-1)continue;let a=o.lastIndexOf("#");i.push({terminalCommand:o.slice(s,a===-1?void 0:a-1)})}return i}}))}async function qd(){if(z.workspace.isTrusted&&Ud())try{return await(0,Qu.default)(process.platform==="win32"?"npm.cmd":"npm")}catch{return}}function Ud(){return z.workspace.workspaceFolders?z.workspace.workspaceFolders.some(e=>e.uri.scheme==="file"):!1}var Mr;function Bd(e){if(z.workspace.workspaceFolders){let t=z.workspace.createFileSystemWatcher("**/package.json");t.onDidChange(i=>qt()),t.onDidDelete(i=>qt()),t.onDidCreate(i=>qt()),e.subscriptions.push(t);let n=z.workspace.onDidChangeWorkspaceFolders(i=>qt());e.subscriptions.push(n),Mr=new xn(e);let r=z.tasks.registerTaskProvider("npm",Mr);return e.subscriptions.push(r),r}}function Gd(e){if(z.workspace.workspaceFolders){let t=new En(e,Mr),n=z.window.createTreeView("npm",{treeDataProvider:t,showCollapseAll:!0});return e.subscriptions.push(n),t}}function Wd(e){if(z.workspace.workspaceFolders){let t={language:"json",scheme:"file",pattern:"**/package.json"},n=new kn(e);return e.subscriptions.push(z.languages.registerHoverProvider(t,n)),n}}function zu(){let e=z.workspace.getConfiguration("http");Tn.configure(e.get("proxy",""),e.get("proxyStrictSSL",!0))}function Yd(){}0&&(module.exports={activate,deactivate});
/*! Bundled license information:

is-number/index.js:
  (*!
   * is-number <https://github.com/jonschlinkert/is-number>
   *
   * Copyright (c) 2014-present, Jon Schlinkert.
   * Released under the MIT License.
   *)

to-regex-range/index.js:
  (*!
   * to-regex-range <https://github.com/micromatch/to-regex-range>
   *
   * Copyright (c) 2015-present, Jon Schlinkert.
   * Released under the MIT License.
   *)

fill-range/index.js:
  (*!
   * fill-range <https://github.com/jonschlinkert/fill-range>
   *
   * Copyright (c) 2014-present, Jon Schlinkert.
   * Licensed under the MIT License.
   *)
*/
//# sourceMappingURL=npmMain.js.map
